;========================================================================================
;@***h* Daily OLR CDR/intercal_boxcar_batch2_beta3c.pro
;
; NAME
;   intercal_boxcar_batch2_beta3c.pro
;
; PURPOSE
;   Perform Imager OLR calibration, temporal interpolation, and daily integral
;
; DESCRIPTION
;   This routine performs blending processes for HIRS/Imager OLR over a 7-day boxcar
;   on the grid-by-grid basis. It returns the daily mean OLR fields.
;   Current setup is for batch annual processing for the specified year
; 
; INPUTS
;   kyyyy0 - Target year to be processed
;   Intersat_Adjustment_Ed2.7.dat - file contains inter-satellite adjustments for HIRS
;   OLR_hourly_mean_N??_'+hstamp+'.dat' - HIRS hrly 1deg OLR fields
;   Gridsat_OLR_'+gstamp+'??.dat - Gridsat 3-hrly 1deg OLR fields
;
; OUTPUT
;   data_daily_OLR - directory holds output daily OLR data
;   data_daily_OLR_flag - directory holds flag fields for daily OLR data
;   save_daily_OLR - directory holds auxiliary information for daily OLR data
;
; AUTHOR
;   Hai-Tien Lee
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
;   TO USERS.
;
; HISTORY
;   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
;
; USAGE
;   > .rn intercal_boxcar_batch2_beta3c
;   > 1995
;
;@*****
;========================================================================================

; intercal_boxcar_batch2_beta3c.pro

; case study purpose

; use boxcar to smooth out calibration

; examine grid box i,j on yyyy yday

; 2014.2.21
; Beta3c feature
; 0. QC Gridsat: use [100,500] bounds for valid data check. This eliminates many low value bad data. (Need to check gridsat OLR retrieval to root out these data!)
; 1. Do not perform hourly interpolation if Gridsat has a gap > 6 hr (ie., two consecutive missing)
; 2. Use all HIRS and the Adjusted Gridsat data to form final time series for the linearly adjusted g2, the offset shifted g3, and the ratio scaled g1.
; 3. Then use linear interpolation to obtain hourly values
; 4. daily mean is linear average of the 24-hour bins
; 5. HIRS only a. linear interpolation to the day if more than 2 obs; b. otherwise, linear average of all HIRS in boxcar
; 6. implement bilinear interpolation to fill the missing
; 7. implement daily_HIRS_only_integrator subroutine
; 8. Flags re-defined according to new HIRS only integration scheme

; Bad data removed
; HIRS - 1980d062-063.

; ==========================================
data_drive='/Volumes/Gridsat_OLR3'
version='beta3c_reference'

; User setting
; yyyy0=1995
kyyyy0='1979'
yday0=1

read,kyyyy0
kyyyy0=fix(kyyyy0)
yyyy0=kyyyy0
print,kyyyy0

; yday0=1

plot_flag=0
; ==========================================
; environment setting
nx=360L
ny=180L
missing=0.

file_mkdir,version+'/data_daily_OLR'
file_mkdir,version+'/data_daily_OLR_flag'
file_mkdir,version+'/save_daily_OLR'

loadct,39
tvlct,rr,gg,bb,/get
tvlct,rr,gg,bb

; -------------------------------------
; Flag Definitions

; Grid has no data
flag_grid_missing=0
; Linear fit cali
flag_calib_linear=1
; Offset cali
flag_calib_offset=2

; HIRS Only integral
; Scenario 1.0
flag_HIRS_only_10=10
; Scenario 2.0
flag_HIRS_only_20=20
; Scenario 3.0
flag_HIRS_only_30=30
; Scenario 3.1
flag_HIRS_only_31=31

; Grid is filled by bilinear interpolation
flag_grid_filled=100

; -------------------------------------
; Scenarios
; 1.0: Less than 2 in the boxcar
;    nkg < 2
;    ==> assign grid missing
;    ==> flag_HIRS_only_10
; 2.0: target day is surrounded with neighbors 
;    nkg >= 2 and nk0 >= 2
;    ==> Linearly interpolate through 24 hours, with obs neighboring days
;    ==> flag_HIRS_only_20
; 3.0: Neighbors missing on either one or both sides but at least one obs in target day
;    neighbor_missing and nk0 >= 1 
;    ==> Linearly interpolate through 24 hours, with obs neighboring days
;        Extend obs to the boundary when neighbor missing
;    ==> flag_HIRS_only_30
; 3.1 Neighbors missing either one or both sides and no obs in target day
;    neighbor_missing ne 0 and nk0=0
;    ==> assign grid missing
;    ==> flag_HIRS_only_31


; ==========================================
; Define HIRS OLR intersat adjustment using intercal v2.7
satids=[5,6,7,8,9,10,11,12,14,15,16,17,18,19,20,21]
satids='N'+string(satids,form='(i2.2)')
nsatid=n_elements(satids)
intercal=fltarr(nsatid)
; read in intersat calibration adjustment
openr,1,'Intersat_Adjustment_Ed2.7.dat'
readf,1,intercal
close,1

; ==========================================
; Looping through days until it is the day 1 of the next year
first_day_flag=1
; ===================
; ===================
While not (yyyy0 eq kyyyy0+1  and yday0 eq 1) do begin

syyyy0=string(yyyy0,form='(i4.4)')
syday0=string(yday0,form='(i3.3)')

; skip the days that have been done
hstamp0=syyyy0+'d'+syday0
daily_out=version+'/data_daily_OLR/'+syyyy0+'/OLR_daily_'+hstamp0+'.dat'
daily_out_info=file_info(daily_out)
; if daily_out_info.exists eq 1 and daily_out_info.size eq 259200 then goto,skip_day

file_mkdir,version+'/data_daily_OLR/'+syyyy0
file_mkdir,version+'/data_daily_OLR_flag/'+syyyy0
file_mkdir,version+'/save_daily_OLR/'+syyyy0

; Choose boxcar size, e.g., 3 days (must be an odd number)
nboxcar=7

; kt0 = index for the 24 hours of the target day within the boxcar
kt0=indgen(24)+nboxcar/2*24

suffix='boxcar'+strtrim(nboxcar,2)+'_'+string(yyyy0,form='(i4.4)')+'d'+string(yday0,form='(i3.3)')
graphdir=version+'/graph_intercal_check/'+syyyy0+'/graph_intercal_'+suffix

; ==================================================================================
; for first_day_flag=1 case
if first_day_flag eq 1 then begin
first_day_flag=0
olr_g=fltarr(nx,ny,8,nboxcar)
olr_h=fltarr(nx,ny,24,nboxcar)

; set up time coordinates
tg=[indgen(8*nboxcar)*3]
th=[indgen(24*nboxcar)+0.5]

; Get moving boxcar time series
for iboxday=0,nboxcar-1 do begin

; boxcar date control
offset=-(nboxcar/2)+iboxday
spawn,'../Utility/cal_yday2date.sh '+string(yyyy0)+' '+string(yday0),date0 & date0=date0(0)
spawn,'../Utility/cal_date2.sh '+string(date0,form='(i8.8)')+' '+string(offset),date & date=date(0)
spawn,'../Utility/cal_julday2.sh '+string(date,form='(i8.8)'),yday & yday=yday(0)

yyyy=strmid(string(date,form='(i8.8)'),0,4)
mm=strmid(string(date,form='(i8.8)'),4,2)
dd=strmid(string(date,form='(i8.8)'),6,2)

syyyy=string(yyyy,form='(i4.4)')
syday=string(yday,form='(i3.3)')
smm=string(mm,form='(i2.2)')
sdd=string(dd,form='(i2.2)')
print,yyyy0,yday0,date0,offset,yyyy,yday,date,form='(10i9)'


; -------------------------------------------------------------------------------
; Get Gridsat 3-hourly OLR
gstamp=syyyy+smm+sdd

gfiles=file_search(data_drive+'/Gridsat_OLR_Retrieval_v3/output_v3/data_OLR/'+syyyy+'/Gridsat_OLR_'+gstamp+'??.dat',count=ngfile)
gfname=file_basename(gfiles)
hh=strmid(gfname,20,2)

for ifile=0,ngfile-1 do begin
file=gfiles(ifile)
fname=file_basename(file)
khr=hh(ifile)/3
olr_g(*,*,khr,iboxday)=read_binary(file,data_t=4,end='big')
endfor;ifile


; -------------------------------------------------------------------------------
; Get HIRS hourly OLR
hstamp=syyyy+'d'+syday
hstamp0=syyyy0+'d'+syday0

hfiles=file_search(data_drive+'/Daily_OLR_v01r02/Work/Hourly/'+syyyy+'/OLR_hourly_mean_N??_'+hstamp+'.dat',count=nhfile)
; OLR_hourly_mean_N07_1984d188.dat

; if HIRS missing for the day
if nhfile eq 0 then begin
olr_h(*,*,*,iboxday)=0
goto,skip_hirs1
endif ; nhfile eq 0

olr_h_sat=fltarr(nx,ny,24,nhfile)
; olr_h_sat_tmp=fltarr(nx,ny,24,3,nhfile) ; 3=ave,std,num

for ifile=0,nhfile-1 do begin
   file=hfiles(ifile)
   ; read in HIRS hourly data for each satellite
   olr_h_sat_tmp=read_binary(file,data_t=4,end='big')
   olr_h_sat(*,*,*,ifile)=olr_h_sat_tmp(0:nx*ny*24-1)

   ; Adjust HIRS OLR for intersat calibration referenced to NOAA-9
   fn=file_basename(file)
   ; OLR_hourly_mean_N07_1984d188.dat
   satid=strmid(fn,16,3)
   ksat=where(satids eq satid)
   adj=intercal(ksat)
   adj=adj(0)
   olr_h_sat_adjusted=olr_h_sat(*,*,*,ifile)
   k=where(olr_h_sat_adjusted gt 0)
   ; print,'first day',ifile,satid
   if k(0) ne -1 then olr_h_sat_adjusted(k)=olr_h_sat_adjusted(k)-adj
   olr_h_sat(*,*,*,ifile)=olr_h_sat_adjusted
endfor;ifile

; Blend HIRS (take average if more than two found on the same hour)
for j=0,ny-1 do for i=0,nx-1 do begin
   x=reform(olr_h_sat(i,j,*,*)) ; 24 x Nsat
   for ihr=0,23 do begin
   k=where(x(ihr,*) gt 0)
   if k(0) ne -1 then olr_h(i,j,ihr,iboxday)=mean(x(ihr,k))
   endfor ; ihr
   endfor ; i,j

   print,'Number of data files:',yyyy,'d',yday,' Gridsat: ',ngfile,' HIRS: ',nhfile

   skip_hirs1:
endfor ; iboxday

endif else begin 
; ==================================================================================
; for first_day_flag=0 cases
; saving reading time without re-read in olr_g and olr_h
; now shift the day, read the new day 
olr_g(*,*,*,0:nboxcar-2)=olr_g(*,*,*,1:nboxcar-1)
olr_h(*,*,*,0:nboxcar-2)=olr_h(*,*,*,1:nboxcar-1)
; re-initialize the array for the nboxcar-1 day
olr_g(*,*,*,nboxcar-1)=0.
olr_h(*,*,*,nboxcar-1)=0.

; set up time coordinates
tg=[indgen(8*nboxcar)*3]
th=[indgen(24*nboxcar)+0.5]

; Get moving boxcar time series
for iboxday=nboxcar-1,nboxcar-1 do begin

; boxcar date control
offset=-(nboxcar/2)+iboxday
spawn,'../Utility/cal_yday2date.sh '+string(yyyy0)+' '+string(yday0),date0
spawn,'../Utility/cal_date2.sh '+string(date0,form='(i8.8)')+' '+string(offset),date
spawn,'../Utility/cal_julday2.sh '+string(date,form='(i8.8)'),yday

yyyy=strmid(string(date,form='(i8.8)'),0,4)
mm=strmid(string(date,form='(i8.8)'),4,2)
dd=strmid(string(date,form='(i8.8)'),6,2)

syyyy=string(yyyy,form='(i4.4)')
syday=string(yday,form='(i3.3)')
smm=string(mm,form='(i2.2)')
sdd=string(dd,form='(i2.2)')
print,yyyy0,yday0,date0,offset,yyyy,yday,date,form='(10i9)'


; -------------------------------------------------------------------------------
; Get Gridsat 3-hourly OLR
gstamp=syyyy+smm+sdd

gfiles=file_search(data_drive+'/Gridsat_OLR_Retrieval_v3/output_v3/data_OLR/'+syyyy+'/Gridsat_OLR_'+gstamp+'??.dat',count=ngfile)
gfname=file_basename(gfiles)
hh=strmid(gfname,20,2)

for ifile=0,ngfile-1 do begin
   file=gfiles(ifile)
   fname=file_basename(file)
   khr=hh(ifile)/3
   olr_g(*,*,khr,iboxday)=read_binary(file,data_t=4,end='big')
endfor;ifile


; -------------------------------------------------------------------------------
; Get HIRS hourly OLR
hstamp=syyyy+'d'+syday
hstamp0=syyyy0+'d'+syday0

hfiles=file_search(data_drive+'/Daily_OLR_v01r02/Work/Hourly/'+syyyy+'/OLR_hourly_mean_N??_'+hstamp+'.dat',count=nhfile)

; if HIRS missing for the day
if nhfile eq 0 then begin
   olr_h(*,*,*,iboxday)=0
   goto,skip_hirs2
endif ; nhfile eq 0

olr_h_sat=fltarr(nx,ny,24,nhfile)
; olr_h_sat_tmp=fltarr(nx,ny,24,3,nhfile) ; 3=ave,std,num

for ifile=0,nhfile-1 do begin
   file=hfiles(ifile)
   ; read in HIRS hourly data for each satellite
   olr_h_sat_tmp=read_binary(file,data_t=4,end='big')
   olr_h_sat(*,*,*,ifile)=olr_h_sat_tmp(0:nx*ny*24-1)

   ; Adjust HIRS OLR for intersat calibration referenced to NOAA-9
   fn=file_basename(file)
   ; OLR_hourly_mean_N08_1983d358.dat
   satid=strmid(fn,16,3)
   ksat=where(satid eq satids)
   adj=intercal(ksat)
   adj=adj(0)
   olr_h_sat_adjusted=olr_h_sat(*,*,*,ifile)
   k=where(olr_h_sat_adjusted gt 0)
   ; print,'following days',ifile,satid
   if k(0) ne -1 then olr_h_sat_adjusted(k)=olr_h_sat_adjusted(k)-adj
   olr_h_sat(*,*,*,ifile)=olr_h_sat_adjusted
endfor;ifile

; Blend HIRS (take average if more than two found on the same hour)
for j=0,ny-1 do for i=0,nx-1 do begin
   x=reform(olr_h_sat(i,j,*,*)) ; 24 x Nsat, (0=ave,1=std,2=npt)
   for ihr=0,23 do begin
      k=where(x(ihr,*) gt 0)
      if k(0) ne -1 then olr_h(i,j,ihr,iboxday)=mean(x(ihr,k))
   endfor ; ihr
endfor ; i,j

print,'Number of data files:',yyyy,yday,ngfile,nhfile

skip_HIRS2:
endfor ; iboxday
endelse ; first_day_flag=0 case
; ==================================================================================

; QC HIRS and Gridsat boxcar hourly data, olr_h and olr_g
; k=where(olr_g le 50 or olr_g gt 500)
k=where(olr_g le 100 or olr_g gt 500)
if k(0) ne -1 then olr_g(k)=!values.f_nan
k=where(olr_h le 50 or olr_h gt 500)
if k(0) ne -1 then olr_h(k)=!values.f_nan


; ==================================================================================
; Perform Gridsat and HIRS intercalibration

; 1. Global tuning
; kg=where(finite(olr_g) eq 1 and finite(olr_h) eq 1)
; coef_global=linfit(olr_g(kg),olr_h(kg),sigma=sigma_coef_global)
; print,'coef_global=',coef_global,sigma_coef_global
; print,'global mean=',mean(olr_g(kg)),mean(olr_h(kg))

; 2. Grid-based tuning

; Define global arrays for data saving
; olr_c = calibrated hourly OLR
olr_c1=fltarr(nx,ny,24,nboxcar)
olr_c2=fltarr(nx,ny,24,nboxcar)
olr_c3=fltarr(nx,ny,24,nboxcar)
olr_daily_experiment=fltarr(6,nx,ny)
olr_daily=fltarr(nx,ny)
olr_daily_flag=intarr(nx,ny)

coef_global=fltarr(2,nx,ny)
ratio_global=fltarr(2, nx,ny) ; ave, std
offset_global=fltarr(2, nx,ny) ; ave, std
stat_global=fltarr(5,nx,ny) ; n, corr, hirs_var, gridsat_var, fit_rms

lon=indgen(nx)+0.5
lat=indgen(ny)+0.5-90.

; Looping through grid i,j =============================================================
for j=0,ny-1 do for i=0,nx-1 do begin

; interpolate gridsat to hourly (0.5,1.5,2.5,...,23.5) within the 9 3-hrly observations
olr_g_grid=reform(olr_g(i,j,*,*))
kg=where(finite(olr_g_grid) eq 1)

; Normally there are total 8*nboxcar gridsat points when no missing.
; Skip when gridsat has less than 4 points per day in average. 
nkg=n_elements(kg)
if kg(0) eq -1 then nkg=0

; denote negative ncali for cases without gridsat
ncali=-1
stat_global(0,i,j)=ncali

; ==================== too few geo
if nkg lt 4*nboxcar then begin
   ; print,'Number of Gridsat 3-hourly obs=',nkg

   ; When not enough points in Gridsat, derive daily mean use HIRS only

; call HIRS only integrator
   olr_h_grid=reform(olr_h(i,j,*,*))
   target_day=3 ; target_day=[0,6], middle is 3.
   olr_boxcar=olr_h_grid
   t_boxcar=th
   daily_HIRS_only_integrator2,missing,nboxcar,t_boxcar,olr_boxcar,target_day, daily,daily_flag    
;     if i eq 351 and j eq 178 then stop
;      if i eq 56 and j eq 106 then stop
   ;  if i eq 45 and j eq 68 then stop
;    if daily_flag eq flag_HIRS_only_30 and abs(j-90) le 30 then stop
   
; Pro daily_HIRS_only_integrator,nboxcar,th,olr_boxcar,target_day,daily,daily_flag,daily_experiment
   olr_daily(i,j)=daily
   olr_daily_flag(i,j)=daily_flag
   olr_daily_experiment(*,i,j)=0

; the following skip can be modified by the nkg if statment with else block
   goto,skip_no_gridsat
   ; goto,skip_grid

endif ; if nkg lt 4*nboxcar
; ==================== too few geo

; ==================== normal case
; establish gridsat hourly olr baseline time series within the nday boxcar
olr_g_grid_hourly=interpol(olr_g_grid(kg),tg(kg),th,/sp)

; ===== 2014.2.21
; Handle missing 3-hrly data
; if the gap between 3-hrly data is more than 6 hours, do not use any of the hourly interpolations.
; kg is where 3-hrly is valid, check the gap between the data
for ikg=0,n_elements(kg)-2 do begin
dt=tg(kg(ikg+1))-tg(kg(ikg))
; print,ikg,tg(ikg),dt
if abs(dt) gt 6 then begin
t1=tg(kg(ikg))+1 ; one hour after tg(ikg)
t2=tg(kg(ikg+1))-1 ; one hour before tg(ikag+1)-1
t_bad_hrly=indgen(t2-t1+1)+t1
; print,ikg,tg(kg(ikg)),tg(kg(ikg+1)),t1,t2,t_bad_hrly
olr_g_grid_hourly(t_bad_hrly)=!values.f_nan
endif ; gap handling
endfor ; ikg
; =====

; set olr_g_grid_hourly(k)=0 to exclude the extrapolated data in gridsat hourly 
k=where(th lt min(tg(kg)) or th gt max(tg(kg))) ; outside the available gridsat observations
olr_g_grid_hourly(k)=!values.f_nan

; obtain calibrating subset Gc and Hc, at time Tc
olr_h_grid=reform(olr_h(i,j,*,*))
kg=where(finite(olr_g_grid_hourly) eq 1 and finite(olr_h_grid) eq 1)

; if kg(0) eq -1 then begin
if n_elements(kg) le 3 then begin
   ; print,'Not enough calibrating points',i,j,kg
   ; print,olr_g_grid_hourly
   ; print,olr_h_grid
   olr_daily(i,j)=missing
   goto,skip_grid
endif
; window,2,xs=600,ys=500
gc=olr_g_grid_hourly(kg)
hc=olr_h_grid(kg)
tc=th(kg)
; plot,gc,hc,ps=2,/yn
; h0=mean(hc) ; HIRS linear average for valid data in all days

; ================
; Outlier removal (currently iteration=1)
no_outlier=1
repeat begin

coef=regress(gc,hc,yfit=yfit,chisq=chisq,sigma=sigma_coef,const=c0)
coef=[c0,coef]
fit_rms0=stddev(hc-yfit)

; print,'Fit rms error original=',fit_rms0
; print,'yfit-h=',yfit-hc
; print,'g-h=',gc-hc
; print,'Goodness of fit',fitgoodness
; print,'Sigma=',sigma_coef
; define threshold
fit_deviation_threshold=20
bias_threshold=30
bias_limit=40
koutlier=where((abs(yfit-hc) ge fit_deviation_threshold and abs(gc-hc) ge bias_threshold) $
or (abs(gc-hc) ge bias_limit),comp=kg)

if koutlier(0) ne -1 and n_elements(kg) ge 2 then begin
; print,'Number of outliers=',n_elements(koutlier)
gc=gc(kg)
hc=hc(kg)
tc=tc(kg)
endif

; for now, only doing  outlier removal iteration once. Comment the "break" if iteration is desired.
break

endrep until no_outlier
; ================ outlier removal end
; plot final calibration points in red diamond
; oplot,gc,hc,col=250,ps=4,syms=3

; data point variances and stats
ncali=n_elements(hc)

; skip when number of point is less than 2 per day in average
; if ncali lt 2*nboxcar then begin
; print,'Too few calibrating point',i,j,ncali
; pause
; goto,skip_grid
; endif

hirs_var=stddev(hc)
gridsat_var=stddev(gc)
ratio_ave=mean(hc/gc)
ratio_std=stddev(hc/gc)
offset_ave=mean(hc-gc)
offset_std=stddev(hc-gc)
corr=correlate(gc,hc)

; Linear fitting 1=standard regression, 2=normal minimization regression
coef=regress(gc,hc,yfit=yfit,chisq=chisq,sigma=sigma_coef,const=c0)
coef=[c0,coef]
fit_rms=stddev(hc-yfit)
std_hc=stddev(hc)

; selective cases for graphical check
; if yday0 eq 180 or yday0 eq 1 then plot_flag=1
if i eq 351 and j eq 178 then plot_flag=1
; if i eq 154 then plot_flag=1
; if yday0 eq 62 then plot_flag=1

if plot_flag eq 1 then begin
   ; set up plotting
   set_plot,'Z',/copy
   Device, Set_Resolution=[1600,800], Z_Buffer=0
   Device, Decomposed=1, Set_Pixel_Depth=8
   tv_tr_value=0
   !p.background=255
   !p.color=0
   erase
   ; -------------------

   ; Time series plot
   ; window,3,xp=0,yp=0
   ; window,6
   min_all=min([min(olr_g_grid,/na),min(olr_h_grid,/na)])
   max_all=max([max(olr_g_grid,/na),max(olr_h_grid,/na)])
   yran=[min_all/10*10-30,max_all/10*10+40]
   tit=hstamp0+' Grid ['+strtrim(i,2)+','+strtrim(j,2)+']'
   plot,[0],/nodata,xran=[0,nboxcar*24],xsty=1,yran=yran,tit=tit,xticks=nboxcar*4,xmin=6,$
   xtit='Time (hr, UT)',ytit='OLR (Wm!u-2!n)'
   oplot,th,olr_g_grid_hourly,ps=-1      ; Gridsat OLR hourly interpolated (black curve)
   oplot,tg,olr_g_grid,ps=2,syms=2,col=0 ; Gridsat OLR 3-hourly (large black asterisk)
   oplot,th,olr_h_grid,ps=4,col=250,syms=2      ; HIRS OLR observed (red asterisk)
endif 

; print,'Calibration data established',ncali
; print,gc
; print,hc
; print,gc-hc
; print,hc/gc

; Use Ratio
ratio=mean(hc/gc)
; g1=olr_g_grid_hourly*mean(hc/gc)
olr_g_grid_ratio=olr_g_grid*ratio
; print,coef
z=[reform(olr_h_grid,n_elements(olr_h_grid)),reform(olr_g_grid_ratio,n_elements(olr_g_grid_ratio))]
tz=[th,tg]
k=where(finite(z) eq 1)
z=z(k)
tz=tz(k)
s=sort(tz)
tz=tz(s)
z=z(s)
; and linearly interpolated g2 to hourly bins
g1=interpol(z,tz,th)
; nullify extrapolated values
k=where(th lt min(tz))
if k(0) ne -1 then g1(k)=!values.f_nan
k=where(th gt max(tz))
if k(0) ne -1 then g1(k)=!values.f_nan


; modify g2 by using all HIRS and the adjusted Gridsat 
;g2=coef(0)+olr_g_grid_hourly*coef(1)
olr_g_grid_adj=coef(0)+coef(1)*olr_g_grid
; print,coef
z=[reform(olr_h_grid,n_elements(olr_h_grid)),reform(olr_g_grid_adj,n_elements(olr_g_grid_adj))]
tz=[th,tg]
k=where(finite(z) eq 1)
z=z(k)
tz=tz(k)
s=sort(tz)
tz=tz(s)
z=z(s)
; and linearly interpolated g2 to hourly bins
g2=interpol(z,tz,th)
; nullify extrapolated values
k=where(th lt min(tz))
if k(0) ne -1 then g2(k)=!values.f_nan
k=where(th gt max(tz))
if k(0) ne -1 then g2(k)=!values.f_nan


; Use offset
offset=mean(hc-gc)
olr_g_grid_offset=olr_g_grid+offset
z=[reform(olr_h_grid,n_elements(olr_h_grid)),reform(olr_g_grid_offset,n_elements(olr_g_grid_offset))]
tz=[th,tg]
k=where(finite(z) eq 1)
z=z(k)
tz=tz(k)
s=sort(tz)
tz=tz(s)
z=z(s)
; and linearly interpolated g3 to hourly bins
g3=interpol(z,tz,th)
; nullify extrapolated values
k=where(th lt min(tz))
if k(0) ne -1 then g3(k)=!values.f_nan
k=where(th gt max(tz))
if k(0) ne -1 then g3(k)=!values.f_nan



; print,'RMS calibrated=',stddev(gc*ratio-hc),fit_rms,stddev(gc-hc)
if plot_flag eq 1 then oplot,th,g1,ps=0,thick=5,col=100             ; Scaling (cyan)
if plot_flag eq 1 then oplot,th,g3,ps=0,thick=5,col=50              ; Offset (blue)
if plot_flag eq 1 then oplot,th,g2,ps=0,thick=5,col=250,lines=lines ; Fitting (red curve)

; print,'Diurnal OLR'
; print,form='(24f6.1)',olr_g_grid_hourly
; print,form='(24f6.1)',olr_h_grid


; print,'Ratio=',ratio_ave,ratio_std,ncali
; print,'Offset=',offset_ave,offset_std,ncali
; print,'Coef=',coef,' Correlation=',corr
; 
; 
; print,'g0=',mean(olr_g_grid_hourly(kt0))
; print,'g1=',mean(g1(kt0))
; print,'g2=',mean(g2(kt0))
; print,'g3=',mean(g3(kt0))
; print,'g2-g1=',mean(g2(kt0))-mean(g1(kt0)) 
; print,'g3-g1=', mean(g3(kt0))-mean(g1(kt0))
; print,'g3-g2=', mean(g3(kt0))-mean(g2(kt0))
; print,'g2-g_hrly=',mean(g2(kt0))-mean(olr_g_grid_hourly(kt0))
; print,'g3-g_hrly=',mean(g3(kt0))-mean(olr_g_grid_hourly(kt0))
; print,'mean HIRS=',h0,' hc=',mean(hc)
; print,'g1-h=',mean(g1(kt0))-h0,mean(g1(kt0))-mean(hc)
; print,'g2-h=',mean(g2(kt0))-h0,mean(g2(kt0))-mean(hc)
; print,'g3-h=',mean(g3(kt0))-h0,mean(g3(kt0))-mean(hc)


if plot_flag eq 1 then begin
   ; sort time for plot
   oplot,tc,hc,ps=2,col=250,syms=2
   oplot,th,olr_h_grid,ps=4,col=250,syms=2
   oplot,tg,olr_g_grid_adj,ps=4,col=50,syms=2

   ; plot yday0 partition lines
   yday0_start=nboxcar/2*24
   yday0_end=nboxcar/2*24+24
   if plot_flag eq 1 then oplot,[yday0_start,yday0_start],[0,500],lines=0,col=180
   if plot_flag eq 1 then oplot,[yday0_end,yday0_end],    [0,500],lines=0,col=180

   xpo=185
   ypo=740
   yinc=-26
   legend='HIRS='+string(coef(0),form='(f7.1)')+'+'+string(coef(1),form='(f7.3)')+'*Gridsat'+'  Scaling='+string(ratio,form='(f6.4)')+'  Offset='+string(offset,form='(f6.2)')
   if coef(1) lt 0 then $
   legend='HIRS='+string(coef(0),form='(f7.1)')+'-'+string(-coef(1),form='(f7.3)')+'*Gridsat'+'  Scaling='+string(ratio,form='(f6.4)')+'  Offset='+string(offset,form='(f6.2)')
   xyouts,/dev,xpo,ypo+yinc*1,legend
   legend='HIRS StdDev='+string(std_hc,form='(f5.1)')
   xyouts,/dev,xpo,ypo+yinc*2,legend
   legend='Expl Var='+string(corr*corr*100,form='(f5.1,"%")')
   xyouts,/dev,xpo+300,ypo+yinc*2,legend
   legend='RMS error='+string(fit_rms,form='(f5.1)')
   xyouts,/dev,xpo+550,ypo+yinc*2,legend
   legend='Num pairs='+string(n_elements(tc),form='(i2)')
   xyouts,/dev,xpo+800,ypo+yinc*2,legend
   legend='Daily OLR (Fitted)='+string(mean(g2(kt0)),form='(f5.1)')
   xyouts,/dev,xpo,ypo+yinc*3,legend
   legend='Daily OLR (Offset)='+string(mean(g3(kt0)),form='(f5.1)')
   xyouts,/dev,xpo,ypo+yinc*4,legend
   legend='Daily OLR (Scaled)='+string(mean(g1(kt0)),form='(f5.1)')
   xyouts,/dev,xpo,ypo+yinc*5,legend
   ; legend='Daily OLR Gridsat='+string(mean(olr_g_grid_hourly(kt0)),form='(f5.1)')
   ; xyouts,/dev,xpo,ypo+yinc*6,legend

   ; plot solar noon line
   t_noon=(12.-lon(i)/15.+24.) mod 24.
   for iday=0,nboxcar-1 do oplot,[t_noon+iday*24,t_noon+iday*24],[0,500],lines=2
   grid_index='x'+string(i,form='(i3.3)')+'.y'+string(j,form='(i3.3)')
   png=graphdir+'/'+hstamp0+'_'+grid_index+'.png'
   file_mkdir,graphdir
   write_png,png,tvrd(tr=tv_tr_value),rr,gg,bb
endif ; plot_flag
; ------------------------------------

; Collect variables into global arrays
olr_c1(i,j,*,*)=g1
olr_c2(i,j,*,*)=g2
olr_c3(i,j,*,*)=g3
coef_global(*,i,j)=coef


; stat_global=fltarr(6,nx,ny) ; n, corr, hirs_var, gridsat_var, fit_rms
stat_global(0,i,j)=ncali
stat_global(1,i,j)=corr
stat_global(2,i,j)=hirs_var
stat_global(3,i,j)=gridsat_var
stat_global(4,i,j)=fit_rms

ratio_global(0,i,j)=ratio_ave
ratio_global(1,i,j)=ratio_std

offset_global(0,i,j)=offset_ave
offset_global(1,i,j)=offset_std

; Derive daily mean for the target day(s)
; ktc = hour index for cali points within the target day for the cali arrays (hc, gc, tc)
ktc=where( tc ge min(th(kt0)) and tc le max(th(kt0)) )

; if n_elements(ktc) ge 2 then olr_daily_experiment(0,i,j)=mean(hc(ktc))  ; linear average of HIRS observed
olr_daily_experiment(1,i,j)=mean(olr_g_grid_hourly(kt0),/na) ; Gridsat hourly interpolated from observations
olr_daily_experiment(2,i,j)=mean(g1(kt0))  ; Fit hourly
olr_daily_experiment(3,i,j)=mean(g2(kt0))  ; Scaled hourly
olr_daily_experiment(4,i,j)=mean(g3(kt0))  ; Offset hourly
; olr_daily_experiment(5,i,j)=n_elements(ktc)

skip_no_gridsat:

skip_grid:

; reset plog_flag
plot_flag=0

endfor ; i,j
; End of looping of grid i,j =============================================================

; Define daily OLR
; changed (use fit when HIRS variance > 20 Wm-2. Otherwise use offset)
; use fit when explained variance 50%. Otherwise use offset
; use offset when 2<= ncali <= 7
x2=reform(olr_daily_experiment(2,*,*),nx*ny)
x4=reform(olr_daily_experiment(4,*,*),nx*ny)
exp_var=stat_global(1,*,*)*stat_global(1,*,*) ; explained variance for G/H calib
; k2=where(stat_global(2,*,*) ge 20 and x2 > 0)
; k4=where(stat_global(2,*,*) lt 20 and x4 > 0)
k2=where(exp_var ge 0.50 and x2 > 0)
k4=where(exp_var lt 0.50 and x4 > 0)
k5=where(stat_global(0,*,*) le 7 and stat_global(0,*,*) ge 2 and x4 > 0); ncali

olr_daily=reform(olr_daily,nx*ny)
if k2(0) ne -1 then begin
   olr_daily(k2)=x2(k2) ; Fit hourly
   olr_daily_flag(k2)=flag_calib_linear
endif
if k4(0) ne -1 then begin
   olr_daily(k4)=x4(k4) ; Offset hourly
   olr_daily_flag(k4)=flag_calib_offset
endif
if k5(0) ne -1 then begin
   olr_daily(k5)=x4(k5) ; Offset hourly
   olr_daily_flag(k4)=flag_calib_offset
endif

;------------------------------------
; Fill missing, Use Bilinear for the moment
tmp1=reform(olr_daily,nx,ny)
tmp2=transpose(tmp1)
k=where(tmp1 eq missing,comp=ka)
if k(0) ne -1 and n_elements(ka) ge nx/2*ny/2 then begin
fill1=interpol(tmp1(ka),ka,k)
tmp1(k)=fill1
kfill=k
print,'No. of missing =',n_elements(kfill)

k=where(tmp2 eq missing,comp=ka)
fill2=interpol(tmp2(ka),ka,k)
tmp2(k)=fill2
tmp2=transpose(tmp2)
fill=(tmp1+tmp2)/2.
olr_daily(kfill)=fill(kfill)
endif

k=where(olr_daily eq missing)
print,'OLR_daily stat = ',stat(olr_daily)
;------------------------------------

; reform
olr_daily=reform(olr_daily,nx,ny)

; Average over North and South polar zones
k=where(olr_daily(*,0) gt 0)
if k(0) ne -1 then olr_daily(*,0)=mean(olr_daily(k,0))
k=where(olr_daily(*,ny-1) gt 0)
if k(0) ne -1 then olr_daily(*,ny-1)=mean(olr_daily(k,ny-1))

; Save diagnostic data
; save,file=version+'/save_daily_OLR/'+syyyy0+'/intercal_test_'+hstamp0+'_boxcar'+strtrim(nboxcar,2)+'.save',$
; yyyy0,yday0,olr_c1,olr_c2,olr_c3,olr_daily_experiment,$
; coef_global,ratio_global,offset_global,stat_global,$
; olr_daily,olr_daily_flag

openw,1,version+'/data_daily_OLR/'+syyyy0+'/OLR_daily_'+hstamp0+'.dat'
writeu,1,olr_daily
close,1
openw,1,version+'/data_daily_OLR_flag/'+syyyy0+'/'+hstamp0+'.dat'
writeu,1,olr_daily_flag
close,1

skip_day:

; Advance one day
spawn,'../Utility/cal_date2.sh '+string(date0,form='(i8.8)')+' 1',datenew & datenew=datenew(0)
spawn,'../Utility/cal_julday2.sh '+string(datenew,form='(i8.8)'),ydaynew & ydaynew=ydaynew(0)
yyyy0=fix(strmid(string(datenew,form='(i8.8)'),0,4))
yday0=fix(ydaynew)
; print,'datenew=',datenew
; print,'ydaynew=',ydaynew
; print,'yyyy0 yday0=',yyyy0, yday0


endwhile ; yyyy0 and yday0 final day test
; ===================
; ===================

end

