!========================================================================================
!@***h* Daily OLR CDR/grid_olr_1deg_hrly.f90
! 
! NAME         
!   grid_olr_1deg_hrly.f90
!
! LOCATION         
!   Codes/Gridder_2b
!
! PURPOSE
!   Grid OLR fov retrievals into 1x1 deg hourly maps
!
! DESCRIPTION
!   HIRS OLR retrievals are produced at each field of view (FOV). They are gridded
!	 into 1x1 deg hourly maps (360x180x24)
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!   gridder_1deg_hrly.f90
!
! INPUTS
! 	 FILENAME = File name that contain OLR retrievals
! 	 OLR_fov = OLR FOV retrievals (Wm-2 (cm-1 sr)-1)
! 	 LON_fov = Longitudes corresponding to OLR_fov (degrees)
! 	 LAT_fov = Latitudes corresponding to OLR_fov (degrees)
! 	 Time_fov = Time (UT) corresponding to OLR_fov (seconds)
!
! OUTPUTS
!   OLR_ave_map = OLR hourly maps (360x180x24), mean values
!   OLR_std_map = OLR hourly maps (360x180x24), STD values
!   Num_fov_map_all = counter for number of fov retrievals in each grid
!   ECT = equator crossing time. Local hour in real number.

! Working variables
!   OLR_sum_map = OLR hourly maps (360x180x24), sum, tally over a day
!   OLR_var_map = OLR hourly maps (360x180x24), variances, tally over a day
!   Missing_map = Mask map (360x180x24) indicating missing grids. 
!	      		 0=good data; 1=assigned missing.
!		 			 Currently Missing is only QC'ed by number of observations.
! HISTORY
!   2013-09-12   Hai-Tien Lee Modified for 1-degree hourly gridding
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================



		Program grid_olr_1deg_hrly
		IMPLICIT NONE
		
!		integer, PARAMETER :: MAX_NUM_FOV = 1000000
		character(256) :: FILENAME
		INTEGER :: NUM_FILES
		REAL, DIMENSION(:), ALLOCATABLE :: OLR_fov
		REAL, DIMENSION(:), ALLOCATABLE :: LON_fov
		REAL, DIMENSION(:), ALLOCATABLE :: LAT_fov
		REAL, DIMENSION(:), ALLOCATABLE :: TIME_fov
		REAL, DIMENSION(:), ALLOCATABLE :: LZA_fov
		INTEGER :: NUM_fov
		
		integer, PARAMETER :: nx = 360, ny = 180, nt = 24
		real, PARAMETER :: grid_x = 1.0, grid_y = 1.0
		DOUBLE PRECISION :: olr_sum_map(nx,ny,nt)
		DOUBLE PRECISION :: olr_sum_map_all(nx,ny,nt)
		DOUBLE PRECISION :: olr_var_map(nx,ny,nt)
		DOUBLE PRECISION :: olr_var_map_all(nx,ny,nt)
		integer :: num_fov_map(nx,ny,nt)
		integer :: num_fov_map_all(nx,ny,nt)
		logical :: Missing_map(nx,ny,nt)
		real :: lon_grid(nx), lat_grid(ny)
		real :: ECT
		
		real :: olr_ave_map(nx,ny,nt)
		real :: olr_std_map(nx,ny,nt)
		real, dimension(:), allocatable :: ECT_day

! working variables
		INTEGER :: IOS, LUN2=21
		INTEGER :: LUN3=51, LUN4=52
		real record_fov(5)
		integer :: i, j, ifile 

! Initialize tally variables
		OLR_sum_map_all = 0.
		olr_var_map_all = 0.
		num_fov_map_all = 0

! Establish grids Eastward [0,360], northbound [-90,90]
		do i=1,nx
			lon_grid(i) = (i-1)*grid_x + grid_x/2. +  0.
		enddo
		do j=1,ny
			lat_grid(j) = (j-1)*grid_y + grid_y/2. - 90.
		enddo
		
!		print *,lon_grid
!		print *,lat_grid
		
! 2013-09-13 hard code NUM_FILES=1
		NUM_FILES=1
		ALLOCATE (ECT_day(NUM_FILES))
		
		DO IFILE = 1, NUM_FILES
		
! 2013-09-13 read fov file name and number of record from terminal input
			read(5,'(a)') FILENAME
			read(5,*) NUM_FOV
			print *, 'Filename=',trim(filename)
			print *, 'Num of record=',NUM_FOV

			open(LUN2,file=trim(filename),&
				form='unformatted',access='direct',recl=20)
! Test reading
!			read(lun2,rec=1) record_fov
!			print *,'Sample reocrd:'
!			print *,record_fov
			
! Allocate FOV arrays			
			ALLOCATE(OLR_fov(num_fov))
            ALLOCATE(LON_fov(num_fov))
            ALLOCATE(LAT_fov(num_fov))
            ALLOCATE(TIME_fov(num_fov))
            ALLOCATE(LZA_fov(num_fov))
 			
! Read in OLR Fov retrievals, Assign to each fov variables.
			do i=1,num_fov
				read(LUN2, rec=i, IOSTAT = IOS) record_fov
! NEED GRACEFUL EXIT HERE
				IF (IOS /= 0) then
					print *,'grid_olr_1deg_hrly.f90: OLR_FOV Read error at record number',IOS,i
				ENDIF
				LAT_fov(i) = record_fov(1)
				LON_fov(i) = record_fov(2)
				OLR_fov(i) = record_fov(3)
				TIME_fov(i)= record_fov(4)/3600. ! change from seconds to hours
				LZA_fov(i) = record_fov(5)
			end do
			close(lun2)
				
! Call gridder to grid maps for the day
			CALL GRIDDER(Num_fov,OLR_fov,lon_fov,lat_fov,time_fov,lza_fov, &
				OLR_sum_map,OLR_var_map,Num_fov_map,ECT)

! Tally maps			
			OLR_sum_map_all = OLR_sum_map_all + OLR_sum_map
			OLR_var_map_all = OLR_var_map_all + OLR_var_map
			Num_fov_map_all = Num_fov_map_all + Num_fov_map

! Collect ECT
			ECT_day(ifile)=ECT
			
! Deallocate variables
   	  	DEALLOCATE(OLR_fov)
   	    DEALLOCATE(LON_fov)
        DEALLOCATE(LAT_fov)
      	DEALLOCATE(TIME_fov)
      	DEALLOCATE(LZA_fov)
			
		END DO ! ifile

! Determine missing grids where number of observations is less than 1 for averaging
		WHERE ( NUM_fov_map_all < 1 ) Missing_map = .true.

! Calculate mean and std OLR maps
		WHERE (.not. Missing_map)
			olr_ave_map = olr_sum_map_all / num_fov_map_all
		ELSEWHERE
			olr_ave_map = 0.
		END WHERE

! Determine missing grids where number of observations is less than 3 for stddev
		WHERE ( NUM_fov_map_all < 3 ) Missing_map = .true.

! Calculate mean and std OLR maps
		WHERE (.not. Missing_map)
			olr_std_map = sqrt( OLR_var_map_all/(num_fov_map_all-1)- &
				num_fov_map_all/(num_fov_map_all-1)*olr_ave_map*olr_ave_map)
		ELSEWHERE
			olr_std_map = 0.
		END WHERE
		print *,'Average full map coverage', (1.*nx*ny*nt-count(missing_map(:,:,:)) )/nx/ny/nt
		
! Output gridded OLR maps
! Record length might be compiler dependent. Change accordingly.
		open(lun3,file='OLR_hourly_mean.dat',form='unformatted',access='direct',recl=nx*ny*nt*4)
		write(lun3,rec=1) OLR_ave_map
		write(lun3,rec=2) OLR_std_map
		write(lun3,rec=3) real(num_fov_map_all)
		close(lun3)

! Take average ECT to represent the ECT for the day		
!		ECT=sum(ECT_DAY)/num_files
! 20110414 Handle missing ECT (=-1).
		ECT=sum(ECT_DAY, mask=(ect_day .ge. 0.))/count(ect_day .ge. 0.)
		print *, ect_day
		print *, count(ect_day .ge. -10.), count(ect_day .ge. 0.), ect
		open(lun4,file='ECT_hourly_mean.dat')
		write(lun4,*) ECT,(1.*nx*ny*nt-count(missing_map(:,:,:)) )/nx/ny/nt
		close(lun4)
		print *,'Mean ECT=',ECT
		
! House keeping
   	DEALLOCATE(ECT_day)

END program grid_olr_1deg_hrly

