!========================================================================================
!@***h* Daily OLR CDR/gridder_1deg_hrly.f90
! 
! NAME         
!   gridder_1deg_hrly.f90
!
! LOCATION         
!   Codes/Gridder_2b/
!
! PURPOSE
!   Grid OLR fov retrievals into 1x1 deg hourly maps
!
! DESCRIPTION
!   HIRS OLR retrievals are produced at each field of view (FOV). They are gridded
!	 into 1x1 deg maps for 24 hourly bins. (360x180x24)
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!
! INPUTS
! 	 OLR_fov = OLR FOV retrievals (Wm-2 (cm-1 sr)-1)
! 	 LON_fov = Longitudes corresponding to OLR_fov (degrees)
! 	 LAT_fov = Latitudes corresponding to OLR_fov (degrees)
! 	 Time_fov = Time (UT) corresponding to OLR_fov (seconds)
!
! OUTPUTS
!   OLR_sum_map = tally of OLR values (360x180x2)
!   OLR_var_map = tally of OLR variances values (360x180x2)
!   Num_fov_map_all = counter for number of fov retrievals in each grid (360x180x2)
!   ECT = equator crossing time. Local hour in real number.
!
! Working variables
!   OLR_sum_map = OLR monthly maps (144x72x2), sum, over a day, returned from GRIDDER
!   OLR_sum_map_all = OLR monthly maps (144x72x2), sum, tally over a month
!   OLR_var_map = OLR monthly maps (144x72x2), variances, over a day, returned from GRIDDER
!   OLR_var_map_all = OLR monthly maps (144x72x2), variances, tally over a month
!   Missing_map = Mask map (144x72x2) indicating missing grids. 
!	      		 0=good data; 1=assigned missing.
!		 			 Currently Missing is only QC'ed by number of observations.
!
! HISTORY
!   2011-02-22   Hai-Tien Lee Created
!   2011-02-28   Hai-Tien Lee for NCDC HIRS OLR CDR Production Pacakge
!   2011-04-14   Hai-Tien Lee Change handling of missing ECT from STOP to RETURN.
!   2013-09-25   Hai-Tien Lee Modified for 1-deg hourly gridding
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================


       SUBROUTINE GRIDDER(Num_fov,OLR_fov,lon_fov,lat_fov,time_fov,lza_fov, &
		OLR_sum_map,OLR_var_map,Num_fov_map,ECT)

       IMPLICIT NONE
      
      integer, PARAMETER :: nx = 360, ny = 180, nt = 24
      real, PARAMETER :: grid_x = 1., grid_y = 1.

      integer, INTENT(IN) :: Num_fov
      REAL, INTENT(IN) :: OLR_fov(Num_fov)
      REAL, INTENT(INOUT) :: LON_fov(Num_fov)
      REAL, INTENT(IN) :: LAT_fov(Num_fov)
      REAL, INTENT(IN) :: TIME_fov(Num_fov)
      REAL, INTENT(IN) :: LZA_fov(Num_fov)
     
      double precision, INTENT(OUT) :: olr_sum_map(nx,ny,nt)
      double precision, INTENT(OUT) :: olr_var_map(nx,ny,nt)
      integer, INTENT(OUT):: num_fov_map(nx,ny,nt)
      real, INTENT(OUT) :: ECT

! local variables
      INTEGER, ALLOCATABLE :: ki(:), kj(:)
      REAL, ALLOCATABLE :: TIME_fov_loc(:) 
      INTEGER, ALLOCATABLE :: HOUR_box_fov(:)
      LOGICAL, ALLOCATABLE  :: TRP_fov(:)
      LOGICAL, ALLOCATABLE  :: Bad_fov(:)
      INTEGER :: IOS
      integer :: i 
      REAL :: a, b

! Initial
		olr_sum_map = 0.
		olr_var_map = 0.
		num_fov_map = 0
		
! Allocate working variables
      ALLOCATE (TIME_fov_loc(NUM_FOV))
      ALLOCATE (HOUR_box_fov(NUM_FOV))
      ALLOCATE (TRP_fov(NUM_FOV))
      ALLOCATE (Bad_fov(NUM_FOV))

! Rearrange longitude to from 0 to 360
      WHERE (LON_fov .lt. 0) LON_fov = LON_fov + 360.

! FOV QC
		bad_fov = .false.
		WHERE (OLR_fov .lt. 50 .or. OLR_fov .gt. 500) bad_fov = .true.

! Determine grid indecies KI and KJ for the given lon_fov and lat_fov
      ALLOCATE (KI(NUM_FOV))
      ALLOCATE (KJ(NUM_FOV))

      KI = FLOOR( (LON_fov - 0.00) / grid_x )  + 1
      KJ = FLOOR( (LAT_fov +90.00) / grid_y )  + 1

! Safety check
      WHERE (KI .lt. 1) KI = 1
      WHERE (KI .gt. nx) KI = nx
      WHERE (KJ .lt. 1) KJ = 1
      WHERE (KJ .gt. ny) KJ = ny

! Convert UT TIME_fov to local time TIME_fov_loc. 
      TIME_fov_loc = MOD ( (TIME_fov + LON_fov/15. + 24.), 24.)

! Find equator crossing time from ascending observations 
! a = sum of ECT of near nadir equator obs
! b = num of near nadir equator obs
! ECT = averaged ECT (local time)
       TRP_fov = .false.
       WHERE (ABS(LAT_FOV) .le. 2 .and. abs(LZA_FOV) .le. 5 .and. TIME_fov_loc .ge. 12.)
          TRP_fov = .true.
       END WHERE

		b = count (trp_fov,1)
		if (b .ge. 3) then
    		a = sum (TIME_FOV_LOC, 1, trp_fov)
    		ECT = a/b
    	else
			ECT = -1.
			print *, 'ECT cannot be determined. Returned with missing ECT=-1.'
			return
    	endif

! Determine Hour box values for hourly bins: bin1 = [00:00-00:59], bin2= [01:00-01:59],..,bin24=[23:00-23:59]
       HOUR_BOX_fov=FLOOR(time_fov)+1
       

! Fill the maps, looping through all fov 
		DO i=1,num_fov

! Perform QC. Skip bad retrievals.
		   IF (bad_fov(i)) CYCLE

! For good retrievals, summing over the map variables
			olr_sum_map(ki(i),kj(i),hour_box_fov(i))= &
			olr_sum_map(ki(i),kj(i),hour_box_fov(i)) + OLR_fov(i)
			olr_var_map(ki(i),kj(i),hour_box_fov(i))= &
			olr_var_map(ki(i),kj(i),hour_box_fov(i)) + OLR_fov(i)*OLR_fov(i)
			num_fov_map(ki(i),kj(i),hour_box_fov(i))= &
			num_fov_map(ki(i),kj(i),hour_box_fov(i)) + 1
		END DO

! Deallocate KI and KJ
		DEALLOCATE(KI)
		DEALLOCATE(KJ)
		DEALLOCATE(TIME_fov_loc)
		DEALLOCATE(HOUR_box_fov)
		DEALLOCATE(TRP_fov)
		DEALLOCATE(Bad_fov)
 		
END SUBROUTINE gridder

