!========================================================================================
!@***h* Daily OLR CDR/Gridsat_OLR_retrieval_v3.f90
! 
! NAME         
!   Gridsat_OLR_retrieval_v3.f90
!
! LOCATION         
!   Gridsat_OLR_retrieval_v3.f90
!
! PURPOSE
!   Read Gridsat NetCDF4 file and extract IRWIN and IRWVP data. 
!
! DESCRIPTION
!   Retrieval OLR for Gridsat 3-hrly data (5120x2000) on 1deg resolution (360x180)
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! Dependencies
!   none
!
! INPUTS
!   Gridsat_input.nc = hard-wired file name that is a symbolic link to Gridsat data file
!
! NetCDF working variables
!   nid = netcdf file id
!   stat = error status return
!   irwin = IRWIN brightness temperature (packed)
!   irwvp = IRWVP brightness temperature (packed)
! Variables
!   Tf = Flux temperature (deg K)
!   OLR = outgoing longwave radiation (Wm-2)
!   coef_one_channel = OLR model coefficients for one channel configuration
!   coef_two_channel = OLR model coefficients for two channel configuration
!   coef = OLR model coefficients (buffer)
!   irwin_1x1 = IRWIN brightness temperature (in 1x1 grid)
!   irwvp_1x1 = IRWVP brightness temperature (in 1x1 grid)
!
! OUTPUTS
!   File "Gridsat_irwin_irwvp.out" - binary output of irwin and irwvp data
!
!   
! HISTORY
!   2013-10-02   Hai-Tien Lee Created
!   2014-01-24   Hai-Tien Lee Revised to OLR model v3, use flux temperature
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

  program Gridsat_OLR_retrieval
      use netcdf
! error status return
      integer stat
! netCDF ncid
      integer  ncid

! dimension lengths
      integer lat_len
      parameter (lat_len = 2000)
      integer lon_len
      parameter (lon_len = 5143)
      integer nx
      parameter (nx = 360)
      integer ny
      parameter (ny = 180)
 
! variable ids
      integer irwin_id
      integer irwvp_id
 
! rank (number of dimensions) for each variable
      integer*2 irwin_rank
      parameter (irwin_rank = 2)
      integer*2 irwvp_rank
      parameter (irwvp_rank = 2)

! variable shapes
      integer*2 irwin_dims(irwin_rank)
      integer*2 irwvp_dims(irwvp_rank)

      integer*2, dimension(:,:), allocatable :: irwin_packed
      integer*2, dimension(:,:), allocatable :: irwvp_packed
      real, dimension(:,:), allocatable :: irwin
      real, dimension(:,:), allocatable :: irwvp
      
!      integer, PARAMETER :: nx = 360, ny = 180
      real coef(4),coef_two_channel(4),coef_one_channel(4)
!      real ave_map(nx,ny),std_map(nx,ny)
!      real irwin_1x1(nx,ny),irwvp_1x1(nx,ny)
!      real Tf(nx,ny),OLR(nx,ny)

      real, dimension(:,:), allocatable :: ave_map
      real, dimension(:,:), allocatable :: std_map
      real, dimension(:,:), allocatable :: irwin_1x1
      real, dimension(:,:), allocatable :: irwvp_1x1
      real, dimension(:,:), allocatable :: Tf
      real, dimension(:,:), allocatable :: OLR

! OLR regression coefficients for N14 Tb at nadir, quadratic form: [T8, T12, T8^2, T12^2]
! Model v3
! Two channel [T8, T8^2, T12, T12^2]
      data coef_two_channel/0., 8.58339e-4, 1.06098, -1.126670e-3/
! One channel [T8, T8^2, T12, T12^2]
      data coef_one_channel/1.24522, -0.00117847, 0., 0./
      
!		open(50,file='Gridsat_output.dat',access='direct',recl=lat_len*lon_len*2)
!		open(51,file='Gridsat_output_1x1.dat',access='direct',recl=nx*ny*4)
		open(52,file='Gridsat_OLR.dat',access='direct',recl=nx*ny*4)

		allocate(irwin_packed(lon_len,lat_len))
		allocate(irwvp_packed(lon_len,lat_len))
		allocate(irwin(lon_len,lat_len))
		allocate(irwvp(lon_len,lat_len))
		
		allocate(ave_map(nx,ny))
		allocate(std_map(nx,ny))
		allocate(irwin_1x1(nx,ny))
		allocate(irwvp_1x1(nx,ny))
		allocate(Tf(nx,ny))
		allocate(OLR(nx,ny))
		
!netCDF dataset is:
!NF90_OPEN ! open existing netCDF dataset
      stat = nf90_open(path='Gridsat_input.nc', mode=NF90_NOWRITE, ncid=ncid)
      call check_err(stat)

!NF90_INQ_DIMID ! get dimension IDs

!NF90_INQ_VARID ! get variable IDs
		status = nf90_inq_varid(ncid, "irwin_cdr", irwin_id)
		status = nf90_inq_varid(ncid, "irwvp", irwvp_id)
!      print *,'IRWIN ID=',irwin_id, 'IRWVP ID=',irwvp_id
! IRWIN=17, IRWVP=20

!NF90_GET_ATT ! get attribute values

!NF90_GET_VAR ! get values of variables
      stat = nf90_get_var(ncid,irwin_id,irwin_packed)
      stat = nf90_get_var(ncid,irwvp_id,irwvp_packed) 
!NF90_CLOSE ! close netCDF dataset
      stat = nf90_close(ncid)
      call check_err(stat)
! output original packed integer for checking
!		write(50,rec=1) irwin_packed
!		write(50,rec=2) irwvp_packed
!		write(6,*) 'irwin_packed range:',minval(irwin_packed),maxval(irwin_packed)
!		write(6,*) 'irwvp_packed range:',minval(irwvp_packed),maxval(irwvp_packed)

! Scale back to brightness temperatures. 
! Scaling factor=0.01; Offset=200
		WHERE (irwin_packed .ne. -31999) irwin=irwin_packed*0.01+200.
		WHERE (irwvp_packed .ne. -31999) irwvp=irwvp_packed*0.01+200.
!		write(6,*) 'irwin Tb range:',minval(irwin),maxval(irwin)
!		write(6,*) 'irwvp Tb range:',minval(irwvp),maxval(irwvp)

! Grid to 1x1
		call grid_Gridsat_1deg(irwin,ave_map,std_map)
		irwin_1x1=ave_map

		call grid_Gridsat_1deg(irwvp,ave_map,std_map)
		irwvp_1x1=ave_map

!		write(51,rec=1) irwin_1x1
!		write(51,rec=2) irwvp_1x1
!		write(6,*) 'irwin 1x1 Tb range:',minval(irwin_1x1),maxval(irwin_1x1)
!		write(6,*) 'irwvp 1x1 Tb range:',minval(irwvp_1x1),maxval(irwvp_1x1)

! Derive OLR
		Tf=0.

! Two-channel model
		coef=coef_two_channel
		WHERE (irwin_1x1 .gt. 0 .and. irwvp_1x1 .gt. 0) &
			Tf=coef(1)*irwin_1x1 + coef(2)*irwin_1x1*irwin_1x1 &
			  +coef(3)*irwvp_1x1 + coef(4)*irwvp_1x1*irwvp_1x1
			  
! One-channel model
		coef=coef_one_channel
		WHERE (irwin_1x1 .gt. 0 .and. irwvp_1x1 .eq. 0) &
			Tf=coef(1)*irwin_1x1 + coef(2)*irwin_1x1*irwin_1x1 &
			  +coef(3)*irwvp_1x1 + coef(4)*irwvp_1x1*irwvp_1x1
			
		OLR = 5.67e-8 * Tf**4

!		do i=1,nx
!		do j=1,ny
!	!		write(60,'(10g13.5)') olr(i,j),irwin_1x1(i,j),irwvp_1x1(i,j)
!		enddo
!		enddo
!		write(6,*) 'OLR range:',minval(olr),maxval(olr)

		write(52,rec=1) OLR


! deallocate      
      deallocate(irwin_packed)
      deallocate(irwvp_packed)
      deallocate(irwin)
      deallocate(irwvp)
		deallocate(ave_map)
		deallocate(std_map)
		deallocate(irwin_1x1)
		deallocate(irwvp_1x1)
		deallocate(Tf)
		deallocate(OLR)

      end



!==============================================================================================
      subroutine check_err(stat)
      use netcdf
      integer stat
      if (stat .ne. nf90_NOERR) then
      print *, 'Program stopped. read_Gridsat.f90 error=',nf90_strerror(stat)
      stop
      endif
      end
      
      
!==================================================================================================
! NAME         
!   grid_Gridsat_1deg.f90
!
! LOCATION         
!   Codes/Gridsat/grid_Gridsat_1deg.f90
!
! PURPOSE
!   Grid Gridsat Tb into 1x1 deg maps
!
! DESCRIPTION
!   Gridsat v2.1 data are 5143x2000 originally. The IRWIN and IRWVP Tb data are gridded
!	 into 1x1 deg maps. (360x180x2)
!
! AUTHOR
!   Hai-Tien Lee
!
! CREATION DATE
!   2013-10-02
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! Dependencies
!   gridder subroutine (in this file)
!
! INPUTS
! 	 input_map = 5143x2000 map
! 	 lon = Longitude coordinates in 0.07 degree resolution
! 	 lat = Latitude coordinates in 0.07 degree resolution between [-70,70]
!
! OUTPUTS
!   ave_map = mean values (360x180)
!   std_map = STD values (360x180)

! Working variables

! HISTORY
!   2013-10-02   Hai-Tien Lee 1-degree gridder for GridSat CDR data
!
!==================================================================================================



		Subroutine grid_Gridsat_1deg(input_map,ave_map,std_map)
		IMPLICIT NONE
		
		integer, PARAMETER :: nx0 = 5143, ny0 = 2000, num=nx0*ny0
      REAL, INTENT(IN) :: input_map(nx0,ny0)

		integer, PARAMETER :: nx = 360, ny = 180
		real, PARAMETER :: grid_x = 1.0, grid_y = 1.0
		DOUBLE PRECISION :: sum_map(nx,ny)
		DOUBLE PRECISION :: var_map(nx,ny)
		integer :: num_map(nx,ny)
		logical :: Missing_map(nx,ny)
		real :: lon_grid(nx), lat_grid(ny)
		
		real,intent(out) :: ave_map(nx,ny)
		real,intent(out) :: std_map(nx,ny)

		real :: lon0(nx0),lat0(ny0)
		real :: fov(num),lon(num),lat(num)

		integer :: i, j, k

      INTEGER, ALLOCATABLE :: ki(:), kj(:)
      LOGICAL, ALLOCATABLE  :: Bad(:)

      ALLOCATE (KI(NUM))
      ALLOCATE (KJ(NUM))
      ALLOCATE (Bad(NUM))

		sum_map=0.
		var_map=0.
		num_map=0
		
! Define input coordinates for 5143x2000 map (0.07 deg resolution)
		do i=1,nx0 
			lon0(i)=-180.+(i-1)*0.07
		enddo
		do j=1,ny0
			lat0(j)=-70+(j-1)*0.07
		enddo

! Rearrange longitude to from 0 to 360
      WHERE (LON0 .lt. 0) LON0 = LON0 + 360.

! Assign input arrays
		do i=1,nx0 
		do j=1,ny0
			k=j*nx0+i
			fov(k)=input_map(i,j)
			lon(k)=lon0(i)
			lat(k)=lat0(j)
		enddo
		enddo		

! Tb range QC, according to Gridsat v02r01 netcdf header
		bad = .false.
		WHERE (fov .lt. 140 .or. fov .gt. 375) bad = .true.

! Determine grid indecies KI and KJ for the given lon and lat
      KI = FLOOR( (LON - 0.00) / grid_x )  + 1
      KJ = FLOOR( (LAT +90.00) / grid_y )  + 1

! Safety check
      WHERE (KI .lt. 1) KI = 1
      WHERE (KI .gt. nx) KI = nx
      WHERE (KJ .lt. 1) KJ = 1
      WHERE (KJ .gt. ny) KJ = ny

! Fill the maps, looping through all fov 
		DO i=1,num

! Perform QC. Skip bad retrievals.
		   IF (bad(i)) CYCLE

! For good retrievals, summing over the map variables
			sum_map(ki(i),kj(i))= &
			sum_map(ki(i),kj(i)) + fov(i)
			var_map(ki(i),kj(i))= &
			var_map(ki(i),kj(i)) + fov(i)*fov(i)
			num_map(ki(i),kj(i))= &
			num_map(ki(i),kj(i)) + 1
		END DO
		
! Determine missing grids where number of observations is less than 1 for averaging
		Missing_map = .false.
		WHERE ( NUM_map < 1 ) Missing_map = .true.

! Calculate mean and std OLR maps
		WHERE (.not. Missing_map)
			ave_map = sum_map / num_map
		ELSEWHERE
			ave_map = 0.
		END WHERE

! Determine missing grids where number of observations is less than 3 for stddev
		WHERE ( NUM_map < 3 ) Missing_map = .true.

! Calculate mean and std maps
		WHERE (.not. Missing_map)
			std_map = sqrt( var_map/(num_map-1)- &
				num_map/(num_map-1)*ave_map*ave_map)
		ELSEWHERE
			std_map = 0.
		END WHERE

		WHERE ( ave_map == 0 ) Missing_map = .true.
!		print *,'Percent of data coverage = ', (1.*nx*ny-count(missing_map) )/nx/ny
		
      DEALLOCATE (KI)
      DEALLOCATE (KJ)
      DEALLOCATE (Bad)

END Subroutine grid_Gridsat_1deg
!==============================================================================================


