;========================================================================================
;@***h* Daily OLR CDR/calc_Gridsat_OLR.pro
;
; NAME
;   calc_Gridsat_OLR.pro
;
; PURPOSE
;   Derive Imager OLR from Gridsat CDR brightness temperature data
;
; DESCRIPTION
;   This is a driver IDL routine that calls the FORTRAN program 
;   Gridsat_OLR_retrieval_v3.f90 which extracts brightness temperature data from Gridsat 
;   CDR product and calculates Imager OLR.
; 
; INPUTS
;   kyyyy0 - Target year to be processed
;   gridsat_v02r01/'+syyyy+'/GRIDSAT-B1.'+syyyy+'.'+smm+'.'+sdd+'.'+shr+'.v02r01.nc' - 
;   Gridsat CDR product files
;   Range of processing years is hardcoded, e.g., "for yyyy=2000,2012 do begin"
;
; OUTPUT
;   data_OLR - directory holds output 3-hrly Imager OLR fields
;   graph_hrly_OLR - directory holds diagnostic plots
;
; AUTHOR
;   Hai-Tien Lee
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
;   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
;   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
;   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
;   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
;   TO USERS.
;
; HISTORY
;   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
;
; DEPENDENCIES
;   Gridsat_OLR_retrieval_v3.f90
;   OLR
; 
; USAGE
;   > .rn calc_Gridsat_OLR
;
;@*****
;========================================================================================

; calc_Gridsat_OLR.pro

; read Gridsat netcdf data
; extract irwin and irwvp brightness temperatures

; skip_done=1 skips days Gridsat OLR has already been derived. Otherwise, no skip.
skip_done=0

close,/a
openw,1,'calc_Gridsat_OLR.log'

loadct,39
tvlct,rr,gg,bb,/get
set_plot,'Z',/copy
Device, Set_Resolution=[1000,600], Z_Buffer=0
Device, Decomposed=0, Set_Pixel_Depth=24

erase
tvlct,rr,gg,bb
;window,xs=1000,ys=600
lon_1x1=indgen(360)+0.5
lat_1x1=indgen(180)+0.5-90.


for yyyy=2000,2012 do begin

syyyy=string(yyyy,form='(i4.4)')
; file_mkdir,'graph_hrly_irwin/'+syyyy
; file_mkdir,'graph_hrly_irwvp/'+syyyy
file_mkdir,'graph_hrly_OLR/'+syyyy
file_mkdir,'data_OLR/'+syyyy

yday_end=julday(1,1,yyyy+1)-julday(1,1,yyyy)
nday=yday_end
stat=fltarr(4,8,nday)

for iday=0,nday-1 do for ihr=0,7 do begin
yday=iday+1
hr=ihr*3

yday2date,yday,yyyy,mm,dd
smm=string(mm,form='(i2.2)')
sdd=string(dd,form='(i2.2)')
shr=string(hr,form='(i2.2)')
stamp=syyyy+smm+sdd+shr

;file='data/GRIDSAT-B1.2000.01.01.00.v02r01.nc'
file='gridsat_v02r01/'+syyyy+'/GRIDSAT-B1.'+syyyy+'.'+smm+'.'+sdd+'.'+shr+'.v02r01.nc'
;file='data1/'+syyyy+'/GRIDSAT-B1.'+syyyy+'.'+smm+'.'+sdd+'.'+shr+'.v02r01.nc'
status=file_test(file,/read)
if status eq 0 then goto,skip_yday

OLR_output='data_OLR/'+syyyy+'/Gridsat_OLR_'+stamp+'.dat'

if skip_done eq 1 then begin
status=file_test(OLR_output,/read)
print,OLR_output+' already done. Skipping ....'
if status eq 1 then goto,skip_yday
endif

print,'Stamp=',stamp
print,file

cmd='rm Gridsat_input.nc'
spawn,cmd
cmd='ln -s '+file+' Gridsat_input.nc'
spawn,cmd

cmd='read_Gridsat.exe'
spawn,cmd

x=read_binary('Gridsat_OLR.dat',data_t=4,end='big')
kg=where(x gt 0)
if kg(0) eq -1 then begin
print, 'No valid data in ',file,' ',stamp
printf,1,'skip '+stamp+' '+file
goto,skip_yday
endif

; print,range(x(kg))
print,stamp+' ',mean(x(kg)),min(x(kg)),max(x(kg)),n_elements(kg)
stat(0,ihr,iday)=mean(x(kg))
stat(1,ihr,iday)=min(x(kg))
stat(2,ihr,iday)=max(x(kg))
stat(3,ihr,iday)=n_elements(kg)


olr=reform(x,360,180)

cmd='mv Gridsat_OLR.dat '+OLR_output
spawn,cmd

tit_stamp=syyyy+'.'+smm+'.'+sdd+' '+shr+'Z'
map_set,0,180.,/cont,/grid,tit='Gridsat OLR '+tit_stamp
lev=indgen(31)*10+50
contour,OLR < lev(n_elements(lev)-1)-0.1,lon_1x1,lat_1x1,lev=lev,/over,/cell
map_continents,col=20
map_continents,col=20
png=stamp+'.png'
write_png,'graph_hrly_OLR/'+syyyy+'/'+png,tvrd(tr=1)

skip_yday:
endfor ; yday, hr
endfor ; yyyy

fmt='(i10,1x,3(f10.3,1x),i6)
printf,1,form=fmt,stamp,stat
close,/a

end

