!========================================================================================
!@***h* Daily OLR CDR/OLR_CDR_nc4_batch.f90
! 
! NAME         
!   OLR_CDR_nc4_batch.f90
!
! LOCATION         
!   Codes/Packer/OLR_CDR_nc4_batch.f90
!
! PURPOSE
!   Pack OLR CDR data into a NetCDF4 data file. 
!
! DESCRIPTION
!   Giving monthly mean OLR data (144x72xNMON), nmon=num of months, this program packs
!   the OLR CDR time series data into NetCDF4 data file
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!   none
!
! INPUTS
!   time_len = number of month of monthly mean OLR data
!   olr = monthly mean OLR data, 144x72xtime_len
!   version = global attribute: version
!   history = global attribute: history
!   comment = global attribute: comment
!   time_template = pre-calculated monthly time stamp for 720 months in 'days since 1979.01.01' unit
!
! NetCDF working variables
!   nid = netcdf file id
!   stat = error status return
!   lat = latitude
!   lon = longitude
!   lat_len = 72, parameter to define lat dimension
!   lon_len = 144, parameter to define lon dimension
!   bnds_len = 2, parameter to define bnds dimension
!
! OUTPUTS
!   File "OLR_CDR_output.nc" - NetCDF4 product file containing time series of OLR monthly mean fields
!
!   
! HISTORY
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

  program OLR_CDR_nc4_batch
      use netcdf
! error status return
      integer stat
! netCDF ncid
      integer  ncid

! dimension lengths
      integer lat_len
      parameter (lat_len = 72)
      integer lon_len
      parameter (lon_len = 144)
      integer time_len
!      parameter (time_len = 384 )
      integer bnds_len
      parameter (bnds_len = 2)
 
! dimension ids
      integer lat_dim
      integer lon_dim
      integer time_dim
      integer bnds_dim
 
! variable ids
      integer olr_id
      integer lon_id
      integer lat_id
      integer time_id
      integer lon_bounds_id
      integer lat_bounds_id
      integer time_bounds_id
 
! rank (number of dimensions) for each variable
      integer olr_rank
      parameter (olr_rank = 3)
      integer lon_rank
      parameter (lon_rank = 1)
      integer lat_rank
      parameter (lat_rank = 1)
      integer time_rank
      parameter (time_rank = 1)
      integer lon_bounds_rank
      parameter (lon_bounds_rank = 2)
      integer lat_bounds_rank
      parameter (lat_bounds_rank = 2)
      integer time_bounds_rank
      parameter (time_bounds_rank = 2)

! variable shapes
      integer olr_dims(olr_rank)
      integer lon_dims(lon_rank)
      integer lat_dims(lat_rank)
      integer time_dims(time_rank)
      integer lon_bounds_dims(lon_bounds_rank)
      integer lat_bounds_dims(lat_bounds_rank)
      integer time_bounds_dims(time_bounds_rank)

! variable declarations
      real  lon(lon_len)
      real  lat(lat_len)
      real  lon_bounds(bnds_len,lon_len)
      real  lat_bounds(bnds_len,lat_len)
      
! a static time stamp for 720 months since 1979.01 is pre-calculated. Good till 2038. 
      real, dimension(7,720) :: time_template
      real, dimension(:), allocatable :: time
      real, dimension(:,:), allocatable :: time_bounds
      real, dimension(:,:,:), allocatable :: olr
      real olr_one_month(lon_len,lat_len)
      integer i, yyyy, mm, kmon

! Global attribute variables
		character(1024) :: conventions
		character(1024) :: title
		character(1024) :: source
		character(1024) :: reference
		character(1024) :: history
		character(1024) :: comment
		character(1024) :: Metadata_Conventions
		character(1024) :: standard_name_vocabulary
		character(1024) :: id
		character(1024) :: naming_authority
		character(1024) :: date_created
		character(1024) :: date_modified
		character(1024) :: license
		character(1024) :: summary
		character(1024) :: keywords
		character(1024) :: keywords_vocabulary
		character(1024) :: cdm_data_type
		character(1024) :: project
		character(1024) :: processing_level
		character(1024) :: creator_name
		character(1024) :: creator_URL
		character(1024) :: creator_email
		character(1024) :: institution
		character(1024) :: geospatial_lat_min
		character(1024) :: geospatial_lat_max
		character(1024) :: geospatial_lon_min
		character(1024) :: geospatial_lon_max
		character(1024) :: geospatial_lat_units
		character(1024) :: geospatial_lat_resolution
		character(1024) :: geospatial_lon_units
		character(1024) :: geospatial_lon_resolution
		character(1024) :: time_coverage_start
		character(1024) :: time_coverage_end
		character(1024) :: time_coverage_duration
		character(1024) :: time_coverage_resolution
		character(1024) :: contributor_name
		character(1024) :: contributor_role
        character(1024) :: acknowledgment
		character(1024) :: cdr_program
		character(1024) :: cdr_variable
		character(1024) :: software_version_id
		character(1024) :: Metadata_Link
		character(1024) :: product_version
		character(1024) :: platform
		character(1024) :: sensor
		character(1024) :: spatial_resolution

! Read in OLR data and determine Time variable
! read time_len from script
		read(5,*) time_len
		allocate(time(time_len))
		allocate(time_bounds(bnds_len,time_len))
		allocate(olr(lon_len,lat_len,time_len))

! -----------------------------------------------------------------------------------
! Read in time template (up to 720 months)
      open(51,file='Time_template_720.dat')
      read(51,*) time_template
      close(51)
!      print *,time

! Read in OLR data
      open(52,file='OLR_CDR_ascii_input.dat')
		do i = 1, time_len
     		read(52,*) yyyy,mm
      	read(52,*) olr_one_month
      	kmon = (yyyy-1979)*12 + mm
      	time(i)=time_template(5,kmon)
      	time_bounds(1,i)=time_template(6,kmon)
      	time_bounds(2,i)=time_template(7,kmon)
      	olr(:,:,i)=olr_one_month
      enddo
      close(52)
!      print *,'Total ',time_len,' months'
! -----------------------------------------------------------------------------------

! enter define mode
! NetCDF-3 format
!      stat = nf90_create('OLR_CDR_output.nc', NF90_CLASSIC_MODEL, ncid);
! NetCDF-4 format
      stat = nf90_create('OLR_CDR_output.nc', NF90_HDF5, ncid);
      call check_err(stat)

! define dimensions
      stat = nf90_def_dim(ncid, 'time', time_len, time_dim);
      call check_err(stat)
      stat = nf90_def_dim(ncid, 'lat', lat_len, lat_dim);
      call check_err(stat)
      stat = nf90_def_dim(ncid, 'lon', lon_len, lon_dim);
      call check_err(stat)
      stat = nf90_def_dim(ncid, 'bnds', bnds_len, bnds_dim);
      call check_err(stat)

! define variables
      olr_dims(1) = lon_dim
      olr_dims(2) = lat_dim
      olr_dims(3) = time_dim
      stat = nf90_def_var(ncid, 'olr', nf90_float, olr_dims, olr_id);
      call check_err(stat)

      lon_dims(1) = lon_dim
      stat = nf90_def_var(ncid, 'lon', nf90_float, lon_dims, lon_id);
      call check_err(stat)

      lat_dims(1) = lat_dim
      stat = nf90_def_var(ncid, 'lat', nf90_float, lat_dims, lat_id);
      call check_err(stat)

      time_dims(1) = time_dim
      stat = nf90_def_var(ncid, 'time', nf90_float, time_dims, time_id);
      call check_err(stat)

      lon_bounds_dims(1) = bnds_dim
      lon_bounds_dims(2) = lon_dim
      stat = nf90_def_var(ncid, 'lon_bounds', nf90_float, lon_bounds_dims, lon_bounds_id);
      call check_err(stat)

      lat_bounds_dims(1) = bnds_dim
      lat_bounds_dims(2) = lat_dim
      stat = nf90_def_var(ncid, 'lat_bounds', nf90_float, lat_bounds_dims, lat_bounds_id);
      call check_err(stat)

      time_bounds_dims(1) = bnds_dim
      time_bounds_dims(2) = time_dim
      stat = nf90_def_var(ncid, 'time_bounds', nf90_float, time_bounds_dims, time_bounds_id);
      call check_err(stat)


! Assign Global Attributes
! Define conventions
       read(5,'(a)') conventions
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'conventions', trim(conventions))
       call check_err(stat)
! Define title
       read(5,'(a)') title
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'title', trim(title))
       call check_err(stat)
! Define source
       read(5,'(a)') source
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'source', trim(source))
       call check_err(stat)
! Define reference
       read(5,'(a)') reference
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'reference', trim(reference))
       call check_err(stat)
! Define history
       read(5,'(a)') history
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'history', trim(history))
       call check_err(stat)
! Define comment
       read(5,'(a)') comment
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'comment', trim(comment))
       call check_err(stat)
! Define Metadata_Conventions
       read(5,'(a)') Metadata_Conventions
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'Metadata_Conventions', trim(Metadata_Conventions))
       call check_err(stat)
! Define standard_name_vocabulary
       read(5,'(a)') standard_name_vocabulary
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'standard_name_vocabulary', trim(standard_name_vocabulary))
       call check_err(stat)
! Define id
       read(5,'(a)') id
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'id', trim(id))
       call check_err(stat)
! Define naming_authority
       read(5,'(a)') naming_authority
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'naming_authority', trim(naming_authority))
       call check_err(stat)
! Define date_created
       read(5,'(a)') date_created
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'date_created', trim(date_created))
       call check_err(stat)
! Define date_modified
       read(5,'(a)') date_modified
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'date_modified', trim(date_modified))
       call check_err(stat)
! Define license
       read(5,'(a)') license
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'license', trim(license))
       call check_err(stat)
! Define summary
       read(5,'(a)') summary
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'summary', trim(summary))
       call check_err(stat)
! Define keywords
       read(5,'(a)') keywords
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'keywords', trim(keywords))
       call check_err(stat)
! Define keywords_vocabulary
       read(5,'(a)') keywords_vocabulary
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'keywords_vocabulary', trim(keywords_vocabulary))
       call check_err(stat)
! Define cdm_data_type
       read(5,'(a)') cdm_data_type
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'cdm_data_type', trim(cdm_data_type))
       call check_err(stat)
! Define project
       read(5,'(a)') project
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'project', trim(project))
       call check_err(stat)
! Define processing_level
       read(5,'(a)') processing_level
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'processing_level', trim(processing_level))
       call check_err(stat)
! Define creator_name
       read(5,'(a)') creator_name
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'creator_name', trim(creator_name))
       call check_err(stat)
! Define creator_URL
       read(5,'(a)') creator_URL
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'creator_URL', trim(creator_URL))
       call check_err(stat)
! Define creator_email
       read(5,'(a)') creator_email
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'creator_email', trim(creator_email))
       call check_err(stat)
! Define institution
       read(5,'(a)') institution
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'institution', trim(institution))
       call check_err(stat)
! Define geospatial_lat_min
       read(5,'(a)') geospatial_lat_min
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'geospatial_lat_min', trim(geospatial_lat_min))
       call check_err(stat)
! Define geospatial_lat_max
       read(5,'(a)') geospatial_lat_max
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'geospatial_lat_max', trim(geospatial_lat_max))
       call check_err(stat)
! Define geospatial_lon_min
       read(5,'(a)') geospatial_lon_min
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'geospatial_lon_min', trim(geospatial_lon_min))
       call check_err(stat)
! Define geospatial_lon_max
       read(5,'(a)') geospatial_lon_max
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'geospatial_lon_max', trim(geospatial_lon_max))
       call check_err(stat)
! Define geospatial_lat_units
       read(5,'(a)') geospatial_lat_units
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'geospatial_lat_units', trim(geospatial_lat_units))
       call check_err(stat)
! Define geospatial_lat_resolution
       read(5,'(a)') geospatial_lat_resolution
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'geospatial_lat_resolution', trim(geospatial_lat_resolution))
       call check_err(stat)
! Define geospatial_lon_units
       read(5,'(a)') geospatial_lon_units
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'geospatial_lon_units', trim(geospatial_lon_units))
       call check_err(stat)
! Define geospatial_lon_resolution
       read(5,'(a)') geospatial_lon_resolution
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'geospatial_lon_resolution', trim(geospatial_lon_resolution))
       call check_err(stat)
! Define time_coverage_start
       read(5,'(a)') time_coverage_start
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'time_coverage_start', trim(time_coverage_start))
       call check_err(stat)
! Define time_coverage_end
       read(5,'(a)') time_coverage_end
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'time_coverage_end', trim(time_coverage_end))
       call check_err(stat)
! Define time_coverage_duration
       read(5,'(a)') time_coverage_duration
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'time_coverage_duration', trim(time_coverage_duration))
       call check_err(stat)
! Define time_coverage_resolution
       read(5,'(a)') time_coverage_resolution
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'time_coverage_resolution', trim(time_coverage_resolution))
       call check_err(stat)
! Define contributor_name
       read(5,'(a)') contributor_name
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'contributor_name', trim(contributor_name))
       call check_err(stat)
! Define contributor_role
       read(5,'(a)') contributor_role
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'contributor_role', trim(contributor_role))
       call check_err(stat)
! Define acknowledgment
       read(5,'(a)') acknowledgment
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'acknowledgment', trim(acknowledgment))
       call check_err(stat)
! Define cdr_program
       read(5,'(a)') cdr_program
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'cdr_program', trim(cdr_program))
       call check_err(stat)
! Define cdr_variable
       read(5,'(a)') cdr_variable
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'cdr_variable', trim(cdr_variable))
       call check_err(stat)
! Define software_version_id
       read(5,'(a)') software_version_id
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'software_version_id', trim(software_version_id))
       call check_err(stat)
! Define metadata_link
       read(5,'(a)') metadata_link
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'Metadata_Link', trim(Metadata_Link))
       call check_err(stat)
! Define product_version
       read(5,'(a)') product_version
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'product_version', trim(product_version))
       call check_err(stat)
! Define platform
       read(5,'(a)') platform
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'platform', trim(platform))
       call check_err(stat)
! Define sensor
       read(5,'(a)') sensor
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'sensor', trim(sensor))
       call check_err(stat)
! Define spatial_resolution
       read(5,'(a)') spatial_resolution
       stat = nf90_put_att(ncid, nf90_GLOBAL, 'spatial_resolution', trim(spatial_resolution))
       call check_err(stat)


! Assign per-variable attributes
! -------------------------------------------------------------------------------
! olr
! define long_name
      stat = nf90_put_att(ncid, olr_id, 'long_name', 'NOAA Climate Data Record of Monthly Mean Upward Longwave Flux at Top of the Atmosphere')
      call check_err(stat)
! define standard_name
      stat = nf90_put_att(ncid, olr_id, 'standard_name', 'toa_outgoing_longwave_flux')
      call check_err(stat)
! define units
      stat = nf90_put_att(ncid, olr_id, 'units', 'W m-2')
      call check_err(stat)
! define _FillValue
      stat = nf90_put_att(ncid, olr_id, '_FillValue', -999.0)
      call check_err(stat)
! define missing_value
      stat = nf90_put_att(ncid, olr_id, 'missing_value', -999.0)
      call check_err(stat)
! define coordinates
      stat = nf90_put_att(ncid, olr_id, 'coordinates', 'time lat lon')
      call check_err(stat)
! define cell_methods
      stat = nf90_put_att(ncid, olr_id, 'cell_methods', 'time: mean area: mean')
      call check_err(stat)
! define olr valid_min
      stat = nf90_put_att(ncid, olr_id, 'valid_min', 50.0)
      call check_err(stat)
! define olr valid_max
      stat = nf90_put_att(ncid, olr_id, 'valid_max', 500.0)
      call check_err(stat)

! -------------------------------------------------------------------------------
! lon
! define long_name
      stat = nf90_put_att(ncid, lon_id, 'long_name', 'longitude')
      call check_err(stat)
! define standard_name
      stat = nf90_put_att(ncid, lon_id, 'standard_name', 'longitude')
      call check_err(stat)
! define units
      stat = nf90_put_att(ncid, lon_id, 'units', 'degrees_east')
      call check_err(stat)
! define lon valid_min
      stat = nf90_put_att(ncid, lon_id, 'valid_min', 0.0)
      call check_err(stat)
! define lon valid_max
      stat = nf90_put_att(ncid, lon_id, 'valid_max', 360.0)
      call check_err(stat)
! define lon axis
      stat = nf90_put_att(ncid, lon_id, 'axis', 'X')
      call check_err(stat)
! define lon bounds
      stat = nf90_put_att(ncid, lon_id, 'bounds', 'lon_bounds')
      call check_err(stat)

! -------------------------------------------------------------------------------
! lat
! define long_name
      stat = nf90_put_att(ncid, lat_id, 'long_name', 'latitude')
      call check_err(stat)
! define standard_name
      stat = nf90_put_att(ncid, lat_id, 'standard_name', 'latitude')
      call check_err(stat)
! define units
      stat = nf90_put_att(ncid, lat_id, 'units', 'degrees_north')
      call check_err(stat)
! define lat valid_min
      stat = nf90_put_att(ncid, lat_id, 'valid_min', -90.0)
      call check_err(stat)
! define lat valid_max
      stat = nf90_put_att(ncid, lat_id, 'valid_max', 90.0)
      call check_err(stat)
! define lat axis
      stat = nf90_put_att(ncid, lat_id, 'axis', 'Y')
      call check_err(stat)
! define lat bounds
      stat = nf90_put_att(ncid, lat_id, 'bounds', 'lat_bounds')
      call check_err(stat)

! -------------------------------------------------------------------------------
! time
! define long_name
      stat = nf90_put_att(ncid, time_id, 'long_name', 'reference time')
      call check_err(stat)
! define standard_name
      stat = nf90_put_att(ncid, time_id, 'standard_name', 'time')
      call check_err(stat)
! define units
      stat = nf90_put_att(ncid, time_id, 'units', 'days since 1979-01-01 00:00:00')
      call check_err(stat)
! define time valid_min
      stat = nf90_put_att(ncid, time_id, 'valid_min', 0.)
      call check_err(stat)
! define time valid_max
      stat = nf90_put_att(ncid, time_id, 'valid_max', 21915.0)
      call check_err(stat)
! define lat axis
      stat = nf90_put_att(ncid, time_id, 'axis', 'T')
      call check_err(stat)
! define lat bounds
      stat = nf90_put_att(ncid, time_id, 'bounds', 'time_bounds')
      call check_err(stat)
! define calendar
      stat = nf90_put_att(ncid, time_id, 'calendar', 'standard')
      call check_err(stat)

! -------------------------------------------------------------------------------
! lon_bounds
! define valid_min
      stat = nf90_put_att(ncid, lon_bounds_id, 'valid_min', 0.)
      call check_err(stat)
! define valid_max
      stat = nf90_put_att(ncid, lon_bounds_id, 'valid_max', 360.)
      call check_err(stat)
! define coordinates
!      stat = nf90_put_att(ncid, lon_bounds_id, 'coordinates', 'lon bnds')
!      call check_err(stat)
! -------------------------------------------------------------------------------
! lat_bounds
! define valid_min
      stat = nf90_put_att(ncid, lat_bounds_id, 'valid_min', -90.)
      call check_err(stat)
! define valid_max
      stat = nf90_put_att(ncid, lat_bounds_id, 'valid_max', 90.)
      call check_err(stat)
! define coordinates
!      stat = nf90_put_att(ncid, lat_bounds_id, 'coordinates', 'lat bnds')
!      call check_err(stat)
! -------------------------------------------------------------------------------
! time_bounds
! define valid_min
      stat = nf90_put_att(ncid, time_bounds_id, 'valid_min', 0.)
      call check_err(stat)
! define valid_max
      stat = nf90_put_att(ncid, time_bounds_id, 'valid_max', 21915.0)
      call check_err(stat)
! define coordinates
!      stat = nf90_put_att(ncid, time_bounds_id, 'coordinates', 'time bnds')
!      call check_err(stat)
! -------------------------------------------------------------------------------


! leave define mode
      stat = nf90_enddef(ncid);
      call check_err(stat)
! assign scalar and fixed dimension variable data


! perform variable data writes
      call write_olr(ncid,olr_id,time_len,olr)
      call write_lon(ncid,lon_id,lon_bounds_id)
      call write_lat(ncid,lat_id,lat_bounds_id)
      call write_time(ncid,time_id,time_len,time)
      call write_time_bounds(ncid,time_bounds_id,time_len,time_bounds)

      stat = nf90_close(ncid)
      call check_err(stat)

! deallocate      
      deallocate(time)
      deallocate(time_bounds)
      deallocate(olr)

      end


      subroutine write_olr(ncid,olr_id,time_len,olr)
      use netcdf
      integer ncid
      integer olr_id
      integer stat

      integer olr_start(3)
      integer olr_count(3)
      
		integer time_len
      real  olr(144,72,time_len)

      olr_start(1) = 1
      olr_start(2) = 1
      olr_start(3) = 1
      olr_count(1) = 144
      olr_count(2) = 72
      olr_count(3) = time_len
      stat = nf90_put_var(ncid, olr_id, olr, olr_start, olr_count)
      call check_err(stat)
      end

      subroutine write_lon(ncid,lon_id,lon_bounds_id)
      use netcdf
      integer ncid
      integer lon_id,lon_bounds_id
      integer stat

      integer lon_start(1)
      integer lon_count(1)
      integer lon_bounds_start(2)
      integer lon_bounds_count(2)

      real lon(144), lon_bounds(2,144)
!      data lon /1.25, 3.75, 6.25, 8.75, 11.25, 13.75, 16.25, 18.75, 21.25, &
!      			23.75, 26.25, 28.75, 31.25, 33.75, 36.25, 38.75, 41.25, 43.75, &
!			      46.25, 48.75, 51.25, 53.75, 56.25, 58.75, 61.25, 63.75, 66.25, 68.75,  &
!			      71.25, 73.75, 76.25, 78.75, 81.25, 83.75, 86.25, 88.75, 91.25, &
!			      93.75, 96.25, 98.75, 101.25, 103.75, 106.25, 108.75, 111.25, 113.75,  &
!			      116.25, 118.75, 121.25, 123.75, 126.25, 128.75, 131.25, 133.75, &
!			      136.25, 138.75, 141.25, 143.75, 146.25, 148.75, 151.25, 153.75,  &
!			      156.25, 158.75, 161.25, 163.75, 166.25, 168.75, 171.25, 173.75,  &
!			      176.25, 178.75, 181.25, 183.75, 186.25, 188.75, 191.25, 193.75,  &
!			      196.25, 198.75, 201.25, 203.75, 206.25, 208.75, 211.25, 213.75,  &
!			      216.25, 218.75, 221.25, 223.75, 226.25, 228.75, 231.25, 233.75,  &
!			      236.25, 238.75, 241.25, 243.75, 246.25, 248.75, 251.25, 253.75,  &
!			      256.25, 258.75, 261.25, 263.75, 266.25, 268.75, 271.25, 273.75,  &
!			      276.25, 278.75, 281.25, 283.75, 286.25, 288.75, 291.25, 293.75,  &
!			      296.25, 298.75, 301.25, 303.75, 306.25, 308.75, 311.25, 313.75,  &
!			      316.25, 318.75, 321.25, 323.75, 326.25, 328.75, 331.25, 333.75,  &
!			      336.25, 338.75, 341.25, 343.75, 346.25, 348.75, 351.25, 353.75,  &
!			      356.25, 358.75/

! Calculating center and bounds
      do i=1,144 
         lon(i)=2.5*(i-1) + 1.25
         lon_bounds(1,i)=2.5*(i-1)
         lon_bounds(2,i)=2.5*(i-1)+2.5
      enddo
      lon_start(1) = 1
      lon_count(1) = 144
      stat = nf90_put_var(ncid, lon_id, lon, lon_start, lon_count)
      call check_err(stat)
      lon_bounds_start(1) = 1
      lon_bounds_start(2) = 1
      lon_bounds_count(1) = 2
      lon_bounds_count(2) = 144
      stat = nf90_put_var(ncid, lon_bounds_id, lon_bounds, lon_bounds_start, lon_bounds_count)
      call check_err(stat)
      end

      subroutine write_lat(ncid,lat_id,lat_bounds_id)
      use netcdf
      integer ncid
      integer lat_id,lat_bounds_id
      integer stat

      integer lat_start(1)
      integer lat_count(1)
      integer lat_bounds_start(2)
      integer lat_bounds_count(2)

      real  lat(72), lat_bounds(2,72)
!      data lat /-88.75, -86.25, -83.75, -81.25, -78.75, -76.25, -73.75,  &
!     		-71.25, -68.75, -66.25, -63.75, -61.25, -58.75, -56.25, -53.75,  &
!      	-51.25, -48.75, -46.25, -43.75, -41.25, -38.75, -36.25, -33.75, &
!     		-31.25, -28.75, -26.25, -23.75, -21.25, -18.75, -16.25, -13.75, &
!     		-11.25, -8.75, -6.25, -3.75, -1.25, 1.25, 3.75, 6.25, 8.75, 11.25,  &
!     		13.75, 16.25, 18.75, 21.25, 23.75, 26.25, 28.75, 31.25, 33.75, 36.25, &
!     		38.75, 41.25, 43.75, 46.25, 48.75, 51.25, 53.75, 56.25, 58.75, 61.25, &
!     		63.75, 66.25, 68.75, 71.25, 73.75, 76.25, 78.75, 81.25, 83.75,  &
!     		86.25, 88.75/ 

! Calculating center and bounds
      do i=1,72 
         lat(i)=2.5*(i-1) + 1.25 - 90.
         lat_bounds(1,i)=2.5*(i-1) - 90.
         lat_bounds(2,i)=2.5*(i-1)+2.5 - 90.
      enddo
      lat_start(1) = 1
      lat_count(1) = 72
      stat = nf90_put_var(ncid, lat_id, lat, lat_start, lat_count)
      call check_err(stat)
      lat_bounds_start(1) = 1
      lat_bounds_start(2) = 1
      lat_bounds_count(1) = 2
      lat_bounds_count(2) = 72
      stat = nf90_put_var(ncid, lat_bounds_id, lat_bounds, lat_bounds_start, lat_bounds_count)
      call check_err(stat)
      end

      subroutine write_time(ncid,time_id,time_len,time)
      use netcdf
      integer ncid
      integer time_id
      integer stat

      integer time_start(1)
      integer time_count(1)
      integer time_len
      real time(time_len)
      time_start(1) = 1
      time_count(1) = time_len
      stat = nf90_put_var(ncid, time_id, time, time_start, time_count)
      call check_err(stat)
      end

      subroutine write_time_bounds(ncid,time_bounds_id,time_len,time_bounds)
      use netcdf
      integer ncid
      integer time_bounds_id
      integer stat

      integer time__boudns_start(2)
      integer time_bounds_count(2)
      integer time_len
      real time_bounds(2,time_len)
      
      time__boudns_start(1) = 1
      time__boudns_start(2) = 1
      time_bounds_count(1) = 2
      time_bounds_count(2) = time_len
      stat = nf90_put_var(ncid, time_bounds_id, time_bounds, time__boudns_start, time_bounds_count)
      call check_err(stat)
      end

      subroutine check_err(stat)
      use netcdf
      integer stat
      if (stat .ne. nf90_NOERR) then
      print *, 'Program stopped. OLR_CDR_nc4_batch.f90 error=',nf90_strerror(stat)
      stop
      endif
      end
