!========================================================================================
!@***h* Daily OLR CDR/calc_lza.f90
! 
! NAME         
!   calc_lza.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx/, xx=05,06,07,08,09,10,11,12,14
!
! PURPOSE
!   Calculate LZA for each scan position given the LZA at the first spot and satellite
!   height.
!
! DESCRIPTION
!   Prior to N14, the LZA derivation is only done at the first spot of a scan line.
!   This program estimate the LZA at all scan positions assuming a constant 1.8 degree
!   satellite view angle step. See Lee et al., 2007 for detail.
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT 
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!   superdata.cmn.f90
!
! INPUTS
!
! OUTPUTS
!
! HISTORY
!   2003-08-08   Hai-Tien Lee Created
!   2011-03-30   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2012-04-09   Hai-Tien Lee Change LZA to carry signs to indicate direction of scans.
!   2012-04-09   Hai-Tien Lee Add sva_offset magnitude detection to handle wrong first spot  
!                             LZA values given by HIRS-1b data.
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

! 8/8/03 Hai-Tien Lee
! Calculate Local Zenith Angle 

subroutine calc_lza
! hirsrad(35,56,40) passed by common
  implicit none
  include 'superdata.cmn.f90'
  integer i,j,k
  
  real*4 lza(56,40),h(40),a2r,lat(56,40)
  real*4 a,f,c,e,r(56,40),sva(56),sva_offset,r_nadir
  real*4 scan_sign(56)
  
! precalculated satellite view angle sva=indgen(56)*1.8-49.5
  data sva/ &
       -49.5,-47.7,-45.9,-44.1,-42.3,-40.5,-38.7, &
       -36.9,-35.1,-33.3,-31.5,-29.7,-27.9,-26.1, &
       -24.3,-22.5,-20.7,-18.9,-17.1,-15.3,-13.5, &
       -11.7, -9.9, -8.1, -6.3, -4.5, -2.7, -0.9, &
         0.9,  2.7,  4.5,  6.3,  8.1,  9.9, 11.7, &
        13.5, 15.3, 17.1, 18.9, 20.7, 22.5, 24.3, &
        26.1, 27.9, 29.7, 31.5, 33.3, 35.1, 36.9, &
        38.7, 40.5, 42.3, 44.1, 45.9, 47.7, 49.5/

  a2r=3.141592741013/180.
  lat=hirsdat(2,:,:)*a2r
  h=hirsdat(7,1,:)
  lza=hirsdat(8,:,:)
  scan_sign=sva/abs(sva)

! Using NESDIS/IPD definition of earth radius
  a=6378.135 ! radius (km) at equator
  f=1/298.25 ! flatness
  c=a*(1-f) ! radisu at pole
  e=sqrt(1-c/a*c/a) ! ellipticity
! earth's radius (km) as functin of latitude
  r=a*(1.-f)/sqrt(1-e*e*cos(lat)*cos(lat)) 

  do k=1,40
     if (abs(lat(1,k)) .le. 90 .and. lza(1,k) .ge. 0 &
          .and. h(k) .gt. 0.) then
        r_nadir=(r(28,k)+r(29,k))/2. 
        sva_offset=-asin(r(1,k)/(h(k)+r_nadir)*sin(lza(1,k)*a2r))/a2r-sva(1)

! 20120409 Hai-Tien Added LZA sign and Offset detection. 
        if (abs(sva_offset) .gt. 0.1) then
           sva_offset=0.
        endif 
        
        do j=1,56
           lza(j,k)=abs(asin((r_nadir+h(k))/r(j,k)* &
                sin((sva(j)+sva_offset)*a2r) )/a2r) * scan_sign(j)
!           write(89,'(10f10.3)') lza(1,k),r(j,k),h(k),lza(j,k),sva_offset,sva(j)
        enddo
     else
        lza(:,k)=99
     endif
  enddo
  hirsdat(8,:,:)=lza
  return
  end 


