!========================================================================================
!@***h* Daily OLR CDR/get_hirs_HIRS2.f90
! 
! NAME         
!   get_hirs_HIRS2.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx, xx=05,06,07,08,09,10,11,12,14
!
! PURPOSE
!   Performs HIRS radiance calibration
!
! DESCRIPTION
!   This F90 subroutine reads in HIRS Level-1b data, performs HIRS radiance calibration
!	using McMillin method (NOAA POES Users Guide, 1998).
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!  type_def.f90
!	superdata.cmn.f90
!	instrument.cmn.f90
!	hirs_cali.f90
!
! INPUTS
!   onehir - one superswath of HIRS level 1b data passed in through common block
!
! OUTPUTS
!   hirsdat(35,56,40) - containing calibrated radiance and geolocation, lza, & timing info
!
! HISTORY
!   2003-01-01   Original Code (atovmain.f) obtained from L. McMillin
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

      subroutine  get_hirs
!    
! ***This version is for big endian platforms!!
! If used on little endian machine, need some switch on
! variables associated with equivalence.
!*******************************************************************
!    This subroutine calculates the HIRS BT for 
!    one superswath of data                        010912
!    called by:   tvoprn.f, hirsbt.f     
!    modified, add some check                       010918
!    modified for deal with 40 line superswath      011003
!    Add some filter for space & warm BD count data 011018
!    Add channel 20 into process ans hirsdat        011023
!    Change to handle bad superswath, let irfail=1 return  011101
!    modified the adjustment with calculated coefficients 38-40     
!
!******************************************************************* 
!***************************************************************
!   key local parameters-
!      variable             type       function
!      --------             ----       --------
!       bandc               real        Temperature correction coeff
!                                        the attached is NOAA12's
!       iord                int*2       The order of channels in Level 1b data
!        mfq                logical*1   Quality info of spot data
!       onehir              int*2       One scanline of 1b data
!     mclcf,nrmcf           int*2       Original calibration info saved in Level 1b data          
!     clcfh,rmcfh           real*4      Calibration coefficient from  mclcf,nrmcf              

!     pslope, pintcpt       real*4      New calibration coeff for a superswath                                     
!                  
!***************************************************************
!*
      implicit none
      include 'superdata.cmn.f90'
      include 'instrument.cmn.f90'
!      include 'toohi.cmn.f90'

!      logical*1 mfq(56) 
      character*1 mfq(56)
      integer*4 iyr,idy,ihr,imn,isec,msec
      integer*2 onehir(2128) 
      integer*4 mclcf(3,20),nrmcf(3,20)
      real*4 clcfh(3,20),rmcfh(3,20)   
      real*4  pslope(43,19),pintcpt(43,19)
      real*4  pslp,picpt
      equivalence (mfq(1),onehir(1891))
      real*4 scale(3)
      integer*2 scanbit1(0:15),scanbit2(0:15)
      integer*2 ifill
      data ifill/Z'7FFF'/
      integer*2 I, J, K, IS, IM, IMFQ, C, CC, M
      real*4 R, TEMP

      data scale/4.194304e6,1.0737418e9,1.7592186e13/
!lee  these equivalence are not correct for little endian machines!
      equivalence (mclcf(1,1),onehir(129)),(nrmcf(1,1),onehir(249))

!C first get the calibration *********************************

      call newhirscali(pslope,pintcpt)

!C init the output array of hirs data
      do k=1,40
         do j=1,56
            do i=1,35
               hirsdat(i,j,k)=-9999.9
            enddo
            hirsdat(1,j,k)=-1.0 !flags
            hirsdat(33,j,k)=1.0 !Cali flags
         enddo
      enddo
      do 120 is=1,40            !40 scanlines 
         do i=1,2128
            onehir(i)=suphirs(i,is)
         enddo
!     ! first check the scan quality
         call extract_bit_int2(onehir(5),scanbit1)
!lee Check Fatal flag (byte 9, bit 7)
         if (scanbit1(15) .eq. 1) goto 120
         call extract_year(onehir(2),iyr)
         call extract_jday(onehir(2),idy)
         call extract_msec(onehir(3),onehir(4),msec,ihr,imn,isec)
!lee         print *,'hirs time',iyr,idy,ihr,imn,isec

!     ! pull the original calibration info out of the dataset
!     ! If little endian platform, do switching bytes
!     !      do ik=1,180 
!     !         ntrans=onehir(8+ik*2)
!     !         onehir(8+ik*2)=onehir(8+ik*2-1)
!     !         onehir(8+ik*2-1)=ntrans
!     !      enddo
!     !      print *, 'cali info from data:'
         do  j=1,20
!...  find the corresponding radiometric channel number
            k=iord(j)
            do  im=1,3
               rmcfh(im,j)=nrmcf(im,k)/scale(im)
            enddo
!     !      print*,(rmcfh(im,j),im=1,3)
         enddo
         do j=1,20
            k=iord(j)
            do im=1,3
               clcfh(im,j)=mclcf(im,k)/scale(4-im)
            enddo
!     !      PRINT *,(clcfh(im,j),im=1,3)
         enddo
!     ! Since we only need ch20's info, ignore the correction of 
!     ! calibration for chan 1&2
!     ! 
!     =====================================================
!...  loop thru 56 spots in HIRS line
!     for each spot check for mirror sequence error,
!     then loop through 20 channels and extract data.
!     convert the data to radiances and then to temps.
! =====================================================
         do 110 i=1,56
!...  check mirror sequence error flag
            imfq=ichar(mfq(i))
            if (btest(imfq,2)) go to 90
!...  loop thru 20 channels for each spot
            do 80 k=1,19
!...  find corresponding radiometric channel number
               m=iord(k)
               j=484+(i-1)*22+m
!...  check for missing data
               if (onehir(j).eq.ifill) go to 90
!...  calculate radiance
               c=onehir(j)
               pslp=pslope(is,k)
               picpt=pintcpt(is,k)
!     !      print *,'slope&intecept', is, k,pslp,picpt
               r=c*pslp+picpt
               if (is .eq. 1) then
                  temp=r        ! save radiance instead of BT for space view 
                  go to 80
               endif
!     !      if (is .gt. 3) print *, 'is,k,r',is,k,r
               if (r .le. 0. ) go to 90
!lee commented out temp calulation and temp limit check
!lee               temp=brightn(r,k)
!lee               temp =(temp-bandc(1,k))/bandc(2,k)

!     !      if (is .gt. 3) print *, 'BT from HIRS:',temp
!     !  check the bt with limits
!lee               if(temp.lt.tooloh(k).or.temp.gt.toohih(k)) go to 90
!     !    assign temperature to the output array
!               hirsdat(8+k,i,is)=temp
!lee assign radiance to output array instead
               hirsdat(8+k,i,is)=r
 80         continue

!     ! ADD channel 20's processing here, use original calibration data
!     ! calculate chan 20 albedo
            m=iord(20)
            j=484+(i-1)*22+m
!...  check for missing data
            if (onehir(j).eq.ifill) go to 110 !bad of ch20 will not affect other channel
!...  calculate radiance
            cc=onehir(j)
!     !      print *, 'chan20 cc',i,cc
            c=rmcfh(1,20)+cc*(rmcfh(2,20)+cc*rmcfh(3,20))
            r=c*(clcfh(1,20)*c+clcfh(2,20))+clcfh(3,20)
!     print *, 'chan20 r',i,r,clcfh(1,20),clcfh(2,20),clcfh(3,20)
            if (r.lt.0.) r=0. 
            hirsdat(8+20,i,is)=r
!CCCC ch20 added
!     !  assign different flags according to view
            if( is .eq. 1) then
               hirsdat(1,i,is)=2.0
            else if( is .eq. 2) then
               hirsdat(1,i,is)=3.0
            else if( is .eq. 3) then
               hirsdat(1,i,is)=4.0
            else
               hirsdat(1,i,is)=1.0
            endif
            hirsdat(2,i,is)=onehir(369+i*2)/128. !lat
            hirsdat(3,i,is)=onehir(370+i*2)/128. !lon
            hirsdat(4,i,is)=iyr !yrar
            hirsdat(5,i,is)=idy !day
            hirsdat(6,i,is)=msec !utc time
            hirsdat(7,i,is)=onehir(369) !height
            hirsdat(8,i,is)=onehir(370)/128. !local zenith angle
            goto 110     
 90         do k=1,20           ! if a channel is bad, every channel bad, including previous
               hirsdat(8+k,i,is)=-9999.0
            enddo
 110     continue
 120  continue
!     ! may do some output here?
      end
