!========================================================================================
!@***h* Daily OLR CDR/hirs_cali_HIRS2.f90
! 
! NAME         
!   hirs_cali_HIRS2.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx, xx=05,06, ...,14
!
! PURPOSE
!   Derive radiance calibration coefficients following McMillin method
!
! DESCRIPTION
!   Given a HIRS superswath, the calibration coefficients (intercept and gain) are derived
!  	following McMillin method.
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!  type_def.f90
!	superdata.cmn.f90
!	instrument.cmn.f90
!	phys_const.cmn.f90
!
! INPUTS
!	suphirs - superswath of 43 lines (1-3,41-43 calibration scans,4-40 earthview)
!	satid - satellite id
!	olr_coeff - static data
!	crec - record number for direct access binary output file
!
! OUTPUTS
!   pslope(42,19) - radiance calibration coefficient, slope term 
!	pintcpt(42,19) - radiance calibration coefficient, intercept term
!
! HISTORY
!   2003-08-01   Hai-Tien Lee Created
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

     subroutine  newhirscali(pslope,pintcpt)
!*************************************************************************
! This subroutine inputs a superswath of the HIRS Level 1b data, outputs
! the calibration coefficients for channels 1-19
!*************************************************************************
! Description of variables:
!
!  suphirs : input superswath, 43 lines (1-3, 41-43 calibration scans, 4-40 earthview)
!  pslope  : output slope
!  pintcpt : output intercept
!  
!  bandc : HIRS/2 band correction coefficients
!  cofw : coefficients for warm blackbody brightness temperature
!  coslope : coefficients for predicting slope
!  cointcpt: coefficients for predicting intercepts
!  iord    : order of each channel's location in the data set 
!  irfail  : flag: 0: good calibration; 1: bad calibration
!  mfq     : quality info for each spot
!  nslope  : calculated slope at two ends
!  nintcpt : calculated intercept at two ends
!  onehir  : one scan line of HIRS data
!  prtw    : warm blackbody temperature 
!  prtrad  : radiance from the warm blackbody
!  scount  : space view counts
!  wcount  : warm blackbody view counts
!  warmt   : warm blackbody temperature counts
!  sinst   : space scan instrument temperatures (counts)
!  winst   : warm blackbody scan instrument temperatures (counts)
!  tstar   : band corrected warm blackbody temperature
!  
!*************************************************************************
		implicit none
		include 'superdata.cmn.f90'
	  	include 'instrument.cmn.f90'
		include 'phys_const.cmn.f90'
	  	
		real*4   pslope(43,19),pintcpt(43,19)
		real*4   prtw(4)
		real*4   difslope(2,19),difintcpt(2,19)
		real*4   ainst(8)
		integer*2 sinst(8),winst(8)
		integer*2 scount(56,20),wcount(56,20),warmt(20)              
		integer*2 onehir(2128) 
		integer*2 scanbit1(0:15),scanbit2(0:15)
		integer*4 ind(2)
!  logical*1 mfq(56) 
	  	integer*2 imfq
		character*1 mfq(56)
		real*4  tstar(19),prtrad(19)   
		real*4  nslope(2,19),nintcpt(2,19),c,awarmc,tprtw,wsum,s1,s2
		real*8 ismean,iwmean,ismean2,iwmean2,smean(19),wmean(19)
		equivalence (mfq(1),onehir(1891))
      integer i,j,k,iii,m,kk,nums,numw,it,js,jl,is
		data ind/1,41/ 


!lee initialize irfail=0
		irfail=0

! initialize the slope and intercept array
		do i=1,43
			do j=1,19
				pslope(i,j)= 0.0
				pintcpt(i,j)= 0.0
			enddo
		enddo

! First get the calibration coeff for both ends of the superswath
      do 100 iii=1,2     ! for two ends

! initialize counts
			do i=1,56
				do j=1,20
					scount(i,j)=-9999
					wcount(i,j)=-9999
				enddo
			enddo

! assign space scan to onehir
			do i=1,2128
				onehir(i)=suphirs(i,ind(iii))
			enddo

!lee Check that it is really a space view, otherwise return and abolish this superswath
			call extract_bit_int2(onehir(5),scanbit1)
			if (scanbit1(8) .eq. 1 .and. scanbit1(9) .eq. 0) then
				continue
			else
!         write(58,*) 'not a cold view',nrec
				return
			endif

			do k=1,20   !20 channels                    
				m = iord(k)     
				do 110 i = 1,56                                                    
					imfq=ichar(mfq(i))
!               print *,'here',k,i,btest(imfq,2),imfq
					if(btest(imfq,2)) goto 110
					j = 484 + (i-1) * 22 + m 
					scount(i,k)=onehir(j)
!                   write(55,*) scount(i,k),i,k
110  			continue
			enddo                 ! k=1,20
! instrument temp count
			do it=1,8
				sinst(it)=onehir(484 + (62*22)+it)
			enddo
! now the warm target count

! assign warm target scan to onehir
			do i=1,2128
				onehir(i)=suphirs(i,ind(iii)+2)
			enddo
			
			awarmc = 0.0  
			
			do k=1,20                                                      
				m = iord(k)                                                       
				do 120 i = 1,56                                                    
					imfq=ichar(mfq(i))
					if(btest(imfq,2)) goto 120
					j = 484 + (i-1) * 22 + m                                          
					wcount(i,k)=onehir(j)     
 120  	   continue                                                          
			enddo! k=1,20

! Add sth here, warm BB temp and instrument temp
			do it=1,20
				warmt(it)=onehir(484 + (58*22)+it)
			enddo
			do it=1,8
				winst(it)=onehir(484 + (62*22)+it)
			enddo

! calculate the warm BB radiance according to temperature 
			tprtw = 0.0 
			do 130 i= 1,4
				wsum=0.0
				do 131 j=1,5 
					kk=(i-1)*5+j
					if (warmt(kk) .ne. -9999 .and. warmt(kk) .lt. 32760) then
						wsum=wsum+warmt(kk)
					endif
!       	      cofw(j,i)=cofw1((i-1)*5+j)
 131     	continue
				wsum=wsum/5.0
				prtw(i) = cofw(1,i) + cofw(2,i)*wsum + cofw(3,i)*wsum*wsum  & 
					  + cofw(4,i)*wsum*wsum*wsum + cofw(5,i)*wsum*wsum*wsum*wsum
				tprtw=tprtw + prtw(i)
 130  	continue
			tprtw=tprtw/4.0
			do k=1,19
				tstar(k)=tprtw * bandc(2,k) + bandc(1,k)
				s1 = c1*waven(k)*waven(k)*waven(k)
				s2 = exp( (c2* waven(k))/tstar(k)) -1
				prtrad(k) = s1/s2
			enddo  !k=1,19

! calculate the mean of the space count and warm count for spots 9-56
			do 140 k=1,19 
				smean(k)=0.0
				wmean(k)=0.0
				ismean=0.
				iwmean=0.
				ismean2=0.
				iwmean2=0.
				nums=0
				numw=0
				do i=9,56 
					if (scount(i,k) .ne. -9999 .and. scount(i,k) .lt. 32760) then
						ismean=ismean+scount(i,k)
						nums=nums+1
					endif
					if(wcount(i,k) .ne. -9999 .and. wcount(i,k) .lt. 32760 ) then 
						iwmean=iwmean+wcount(i,k)
						numw=numw+1
					endif
				enddo !i=9,56
				if (nums .gt. 0) then  
					ismean= ismean/nums 
				else 
!		         print *,'nums=',nums
					irfail=1
					return
				endif
				if (numw .gt. 0) then  
					iwmean = iwmean/numw 
				else 
!					print *,'numw',numw
					irfail=2
					return
				endif
				
! calculate standard deviation, sum diff squred
				do i=9,56 
					if (scount(i,k) .ne. -9999 .and. scount(i,k) .lt. 32760) then
						ismean2=ismean2+(scount(i,k)-ismean)*(scount(i,k)-ismean)
					endif
					if (wcount(i,k) .ne. -9999 .and. wcount(i,k) .lt. 32760) then
						iwmean2=iwmean2+(wcount(i,k)-iwmean)*(wcount(i,k)-iwmean)
					endif
				enddo
				ismean2=sqrt(ismean2/(nums-1.))
				iwmean2=sqrt(iwmean2/(numw-1.))

! Discard 3-sigma outliers (Hai-Tien 20101215)
				nums=0
				numw=0
				do i=9,56
					if (scount(i,k) .ne. -9999 .and. scount(i,k) .lt. 32760 .and. &
! 2011.3.30 Lee: correct 3*sigma bug in McMillin's original code
!						abs(scount(i,k)-ismean) .le. 3    ) then
						abs(scount(i,k)-ismean) .le. 3*ismean2    ) then
						smean(k)=smean(k)+scount(i,k)
						nums=nums+1
!               else
!                  write(6,*) 'outlie scount=',scount(i,k),ismean,i,k,nums
					endif
					if (wcount(i,k) .ne. -9999 .and. wcount(i,k) .lt. 32760 .and. &
!						abs(wcount(i,k)-iwmean) .le. 3 ) then 
						abs(wcount(i,k)-iwmean) .le. 3*iwmean2 ) then 
						wmean(k)=wmean(k)+wcount(i,k)
						numw=numw+1
					endif
				enddo ! i=9,56

				if (nums .gt. 0) then  
					smean(k)= smean(k)/float(nums) 
				else 
!               write(60,*) 
!               write(60,*) ismean
!               write(60,*) (scount(i,k),i=9,56)
!					print *,'nums=',nums,i,k
					irfail=3
					return
				endif

				if (numw .gt. 0) then  
					wmean(k) = wmean(k)/float(numw) 
				else 
!					print *,'numw',numw
					irfail=4
					return
				endif 

! Re-calculate standard deviation. This is for NEdN.
				do i=9,56 
					if (scount(i,k) .ne. -9999 .and. scount(i,k) .lt. 32760) then
						ismean2=ismean2+(scount(i,k)-smean(k))*(scount(i,k)-smean(k))
					endif
					if (wcount(i,k) .ne. -9999 .and. wcount(i,k) .lt. 32760) then
						iwmean2=iwmean2+(wcount(i,k)-wmean(k))*(wcount(i,k)-wmean(k))
					endif
				enddo
				ismean2=sqrt(ismean2/(nums-1.))
				iwmean2=sqrt(iwmean2/(numw-1.))

! If too many spots are thrown away, add a flag showing 
! that calibration coefficients may be suspicious
				if (nums .le. 41 .or. numw .le. 41) then
					print*,'Too many spots are thrown away during calibration!!'
					print*,'nums= ',nums,'numw=',numw
					do jl=1,40
						do js=1,56
							if(iii .eq. 1) then
								hirsdat(33,js,jl)=-1.0
							else 
								hirsdat(33,js,jl)=-2.0
							endif
						enddo
					enddo
				endif
 140   	continue ! k=1,19

! Calculate slope and intercept based on above results
			do k=1,19
	      	if ((smean(k)-wmean(k)) .gt. 0.1) then
					nslope(iii,k)= (0.0 - prtrad(k))/ (smean(k) - wmean(k))
					nintcpt(iii,k)= 0.0 - nslope(iii,k)*smean(k)
! 					print *,'slope&intcpt', k, nslope(iii,k),nintcpt(iii,k)
				else
					print *,'Sth wrong with warm BB counts or space-view counts!'
					irfail=5
					return
				endif
			enddo

!  Now predict the slope and intercept from instrument temperatures and
!  get the differences between calculated and predicted coefficients
			do i=1,8
				if(winst(i) .gt. 0 .and. winst(i) .lt. 32760 .and. &
					sinst(i) .gt. 0 .and. sinst(i) .lt. 32760) then
					ainst(i)=(winst(i)+sinst(i))/2.0
				else
					print *,'wsinst',winst(i),sinst(i)
					print *,'Sth wrong with instrument temperatures!'
					irfail=6
					return
				endif
			enddo
			
			do 150 k=1,19
!  slope
				pslope(iii,k)=coslope(1,k)+sum(coslope(2:9,k)*ainst(1:8))
				difslope(iii,k)=(nslope(iii,k)-pslope(iii,k))
!  intercept
				pintcpt(iii,k)=cointcpt(1,k)+sum(cointcpt(2:9,k)*ainst(1:8))
				difintcpt(iii,k)=(nintcpt(iii,k)-pintcpt(iii,k))
! 	  print *,'Calibrated coefficients',k,nslope(iii,k),nintcpt(iii,k)
!      print *,'Predicted',pslope(iii,k),pintcpt(iii,k),difslope(iii,k),difintcpt(iii,k)
 150 		continue

! old summing method for loop 150 above
!  slope
!				pslope(iii,k)=0
!				do j=1,8
!					pslope(iii,k)=pslope(iii,k)+ coslope(j+1,k)*ainst(j)
!				enddo
!				pslope(iii,k)=pslope(iii,k)+coslope(1,k)
! print *,'pslope',pslope(iii,k)
!				difslope(iii,k)=(nslope(iii,k)-pslope(iii,k))
! intercept
!				pintcpt(iii,k)=0
!				do j=1,8
!					pintcpt(iii,k)= pintcpt(iii,k)+cointcpt(j+1,k)*ainst(j)
!				enddo
!				pintcpt(iii,k) = pintcpt(iii,k)+ cointcpt(1,k)
!! print *,'pintcpt',pintcpt(iii,k)
!				difintcpt(iii,k)=(nintcpt(iii,k)-pintcpt(iii,k))

 100 	continue
!  End of calculate calibration at two ends of the Superswath

! Now get the calibration for all the scanlines
! First move the cali from 2 to 41
		do k=1,19
			pslope(41,k) = pslope(2,k)
			pintcpt(41,k) = pintcpt(2,k)
		enddo

		do 160 is=4,40           !  all 37 earth-view scans
			do i=1,2128
				onehir(i)=suphirs(i,is)
			enddo
! instrument temp count
			do it=1,8
				sinst(it)=onehir(484 + (62*22)+it)
!         print *,'sinst',it, sinst(it)
				if(sinst(it) .lt. 0 .or. sinst(it) .gt. 32760) then
					print *,'Something wrong with sinst! ', &
					  'Calibration coefficients for this scan will be zero!'
					goto 160
				endif
			enddo   !it=1,8
			do k=1,19
!  slope
!				pslope(is,k)=0.0
!				do j=1,8
!					pslope(is,k)=pslope(is,k)+ coslope(j+1,k)*sinst(j)
!				enddo
!				pslope(is,k)=pslope(is,k)+coslope(1,k)
				pslope(is,k)=coslope(1,k)+sum(coslope(2:9,k)*sinst(1:8))

! Calculate adjustment according to the difference at two ends
				pslope(is,k)=pslope(is,k)+difslope(1,k)
				pslope(is,k)=pslope(is,k)+(difslope(2,k)-difslope(1,k)) &
					*((is-2)/40.0)
!  intercept
!				pintcpt(is,k)=0.0
!				do j=1,8
!					pintcpt(is,k)= pintcpt(is,k)+cointcpt(j+1,k)*sinst(j)
!				enddo
!				pintcpt(is,k) = pintcpt(is,k)+ cointcpt(1,k)
				pintcpt(is,k)=cointcpt(1,k)+sum(cointcpt(2:9,k)*sinst(1:8))

! Calculate adjustment according to the difference at two ends
				pintcpt(is,k)=pintcpt(is,k)+difintcpt(1,k)
				pintcpt(is,k)=pintcpt(is,k)+(difintcpt(2,k)-difintcpt(1,k)) &
					*((is-2)/40.0)
					
!      print *,pslope(is,k),pintcpt(is,k)
      	enddo  ! k=1,19
 
 160 	continue

! Fill the calibration coeff. to calibration scan lines at the both ends of the superswath
		do k=1,19
			do is=2,3
				pslope(is,k)=pslope(1,k)
				pintcpt(is,k)=pintcpt(1,k)
			enddo
			do is=42,43
				pslope(is,k)=pslope(41,k)
				pintcpt(is,k)=pintcpt(41,k)
			enddo
		enddo

		end

!****************** end of calibration***************************
