!========================================================================================
!@***h* Daily OLR CDR/hirsrad2.f90
! 
! NAME         
!   hirsrad2.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx, xx=05,06,...,14
!
! PURPOSE
!   Performs HIRS radiance calibration and OLR retrieval
!
! DESCRIPTION
!   This F90 program reads in HIRS Level-1b data, performs HIRS radiance calibration
!	using McMillin method (NOAA POES Users Guide, 1998) and perform OLR retrieval 
!   using Ellingson et al. (1989, 1994) method.
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!	 brightn.f90
!	 calc_lza.f90
!	 calc_olr.f90
!	 extract_bit_int2.f90
!	 extract_msec.f90
!	 extract_year.f90
!	 get_hirs.f90
!	 i2move.f90
!	 newhirscali.f90
!	 rdhdr_1995.f90
!	 read_instru_para.f90
!	 swap_1995.f90
!   superdata.cmn.f90
!	 instrument.cmn.f90
!
! INPUTS
!
! OUTPUTS
!
! HISTORY
!   2003-01-01   Modieifed from hirsrad2.f from L. McMillin
!   2011-03-30   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

!200/11/7 Hai-Tien
!The original code has the following errors:
!1. ifill is used in gethirs subroutine but is declared and assigned in main program
!2. ifill valus assignment was wrong
!   it should be data ifill/Z'7FFF'/. (was ifill/'Z7FFF'/)
!3. mask1 value assignement was wrong
!   it should be mask1=Z'00F0' (was mask1='Z00F0')
!Error corrected in hirsrad2_1995.f90 for NOAA14 processing.

! 11/3/03 Hai-Tien
! Modified from hirsrad2.f90 to handle data after 1995/1/1.

! 8/26/03 Hai-Tien
! 1. Modified from hirsrad.f90. Create common block 'instrument', move instrument related
! parameters to be read in the main program and passed into hirscali subroutine.
! 2. Disabled 'temp' temperature calculations. 
! 3. Disable temerature limit check. Comment out 'call readlm'
! 4. Create phys_const.cmn.f90 common block for C1 and C2
! 5. Create read_instru_paraf90
!    Read pred_cali, waven, band, etc. in read_instru_para.f90

      program hirsrad2

!**************************************************************
! main program to get HIRS channels 1-19 brightness temperature and
! channel 20 albedo from HIRS Level1b data. Use a new calibration package
! newhirscali.f                            12/04/01
!
! This version is for big endian platforms!!
! If used on little endian machine, need some switch on
! variables associated with equivalence. 
!**************************************************************
!***************************************************************
!   key local parameters-
!      variable                type  function
!      --------                ----  --------
!       isexp                  int   expected next scan num
!       isact                  int   actual scan num
!       idiff                  int   isact-isexp
!       isup                   int   seq num of the contingent superswath
!       iirec                  int   the seq of recorded superswath
!       hunit                  int   input lun
!       hirsdat              real*4  output data for a superswath
!       filen                 char*  input data file
!       olr_unit                int   output lun
!       nameout               char*  output data file
!       nhirs                 int*2  one scan of Level 1b data
!        stid                  int   satellite id

!       suphirs                int*2 a superswath of Level 1b data
!
!   subprograms called - readlm, rdhdr, gethirs 
!
!   restrictions- none
!
!***************************************************************
!*
		implicit none
      include 'superdata.cmn.f90'
      include 'instrument.cmn.f90'
      integer, parameter:: nvar = 7
      integer*2 stid
      character*255 nameout,nameout_rad,filen

      integer*4 hunit,ounit,iirec,idiff,olr_unit
      integer*4 isup
      integer*2 nhirs(2128),isexp, isact
      integer, parameter:: reclen = 4256
      character xbuf(reclen)
      integer*2 scanbit1(0:15),scanbit2(0:15)
      integer*4 ioerr

      integer satid,funit
      real olr_coeff(nvar+1,6500)
      character*255 olr_coeff_file, data1b_list
      integer crec
      equivalence (nhirs,xbuf)
      integer*2 numsc,numdg,max_scanline
      integer*2 swap_flag
      integer iredtm(3), nrec, in, ir, idatps, numss, iswfal, mumss, iss, ipasct
      integer*2 yday_target

! Depending on the machine, swap_flag is defined accordingly.
! Swap_flag=1 for Little Endian machine; (Linux/Intel, Mac/Intel)
! Swap_flag=0 for Big Endian machine. (PPC, SGI)
		swap_flag=1
     
      crec=1
!
!llllllllllllllllllllllllllllllllllllllllllllllllllllllllllll
!     open HIRS & MSU Level 1b data , open geography, albedo, sft files
!lllllllllllllllllllllllllllllllllllllllllllllllllllllllllll
      funit=10
      hunit = 20
      ounit = 30
      olr_unit=334
!      olr_unit2=335
!==================================================================
!   read allowed limits on radiances in input data
!
! lee disable limit check
!      call readlm
!lllllllllllllllllllllllllllllllllllllllllllllllllllllllllllll
      iirec=0
      irfail=0
!      read(5,*) satid
!      read(5,'(a)') olr_coeff_file
!      read(5,'(a)') nameout
!      read(5,'(a)') nameout_rad
      
      read(5,*) satid
      read(5,'(a120)') data1b_list
      read(5,'(a120)') olr_coeff_file
      read(5,'(a120)') nameout
      read(5,*) yday_target
!      read(5,*) swap_flag
!      print *,'swap_flag=',swap_flag

      write(6,*) satid
      write(6,*) 'data1b_list is',data1b_list
      write(6,*) nameout
      write(6,*) 'Target yday=',yday_target

      open(funit,file=data1b_list,status='old')
!      open(ounit,file='hirsrad.out',form='formatted',status='unknown')

      open(25,file=olr_coeff_file, status='old')
      read(25,*) olr_coeff
      close(25)
      
! Record length is assumed in Bytes (5 real*4 variables = 5 * 4 = 20)
      open(olr_unit,file=nameout,status='unknown', &
           form='unformatted',access='direct',recl=20)
!      open(olr_unit2,file=nameout_rad,status='unknown', &
!           form='unformatted',access='direct',recl=16)

! lee, read instrument parameters
      call read_instru_para

! Loop through orbit files       
      do while (.true.) ! orbit file loop
         read(funit,'(a)',end=400) filen
!         write(58,*) filen
         Write(6,*) 'Processing file ',filen
         open(hunit,file=filen,form='unformatted', status='old' &
              ,access='direct',recl=reclen)
!lllllllllllllllllllllllllllllllllllllllllllllllllllllllllll
!     read HIRS header record
!lllllllllllllllllllllllllllllllllllllllllllllllllllllllllll
!
      call rdhdr(hunit,5,reclen,numsc,numdg,iredtm,'hirs',stid,swap_flag)

!c !try to read here 
!      read(hunit,rec=1,iostat=jstat) nhirs
!      print *,'hdr hirs'
		max_scanline=numsc
      print *,'Num of scanline=',max_scanline
!lllllllllllllllllllllllllllllllllllllllllllllllllllllllllll
!    construct a superswath, and goto 5100 try to find 
!    the start scanline of a superswath
!lllllllllllllllllllllllllllllllllllllllllllllllllllllllllll
! check whether start from space, if so 
! start the superswath, if else, go to find the start
      nrec=1

 5100 continue
 		isup=0
      read (hunit,rec=nrec,err=360,iostat=ioerr) xbuf
      if (swap_flag .eq. 1 ) then
         call swap(xbuf)
      endif
      nrec=nrec+1

   
!lee search for space view
      call extract_bit_int2(nhirs(5),scanbit1)
! mirror flag (not checked for now)
!      call extract_bit_int2(nhirs(6),scanbit2)
      if (scanbit1(8) .eq. 1 .and. scanbit1(9) .eq. 0) then
!         write(58,*) 'Space view found',nrec
         continue
      else
      	if (nhirs(1) .eq. max_scanline) goto 360
         goto 5100
      endif
      print *,'nrec=',nrec,scanbit1(9),scanbit1(8)
      print *,'have we entered?'
      print * , 'First scanline=', nhirs(1),nrec
      do in=1,2128
         suphirs(in,1)= nhirs(in)
      enddo
! suppose to read the cold and warm blackbody records
      do ir=1,2
         read (hunit,rec=nrec,err=360,iostat=ioerr) xbuf
         if (ioerr .ne. 0) goto 360
	      if (swap_flag .eq. 1 ) then
   	      call swap(xbuf)
      	endif
      	nrec=nrec+1

         call extract_bit_int2(nhirs(5),scanbit1)
         do in=1,2128
            suphirs(in,1+ir)= nhirs(in)
         enddo
      enddo
!lee
      call extract_bit_int2(nhirs(5),scanbit1)
      if (scanbit1(8) .eq. 1 .and. scanbit1(9) .eq. 1) then
         continue
      else
         print *, 'Not the warm blackbody scan!'
         if (nhirs(1) .eq. max_scanline) goto 360
         go to 5100
      endif
      isexp=nhirs(1)+1
! do loop 350 processes superswath 1 to 30 (usually #superswaths <26 in a file)
      do 350 idatps=1,30
         mumss=idatps
         ipasct=idatps
         iswfal=6
! if not the contingent superswath then assign the last superswath's
! last 3 line as the first 3 line of new swath
         if( isup .ne. 0) then 
            do in=1,2128
               suphirs(in,1)= suphirs(in,41)
               suphirs(in,2)= suphirs(in,42)
               suphirs(in,3)= suphirs(in,43)
            enddo
         endif
!...   do loop 330 processes 40 lines of the superswath
!
         idiff=0
         do 330 iss=4,40        !from first earth view to last earth view 
            if (idiff .gt.0) go to 320
 5500       continue
            read (hunit,rec=nrec,err=330,iostat=ioerr) xbuf
            if (ioerr .ne. 0) goto 360
 		      if (swap_flag .eq. 1 ) then
       		  call swap(xbuf)
      		endif
      		nrec=nrec+1

            print *,'The scanline #',nhirs(1)
            isact=nhirs(1)
!   check whether a gap in the data
            if (isact .gt. isexp) then
               print *, 'There is a gap between scan lines (1st)!' ,isact,isexp
               idiff=isact - isexp
					if (nhirs(1) .eq. max_scanline) goto 360
               if(idiff .gt. 10) go to 5100
!  still put the scan in the position
               do in=1,2128
                  suphirs(in,iss+idiff)= nhirs(in)
               enddo 
               go to 320
            else if (isact .lt. isexp) then
               if (nhirs(1) .eq. max_scanline) goto 360
               go  to 5500
            endif
            do in=1,2128
               suphirs(in,iss)= nhirs(in)
            enddo 
            goto 328
 320        do in=1,2128
               suphirs(in,iss)= -9999
            enddo
            idiff=idiff-1
 328        isexp = nhirs(1)+1
 330     continue
! continue to read the next calibration part
         read (hunit,rec=nrec,err=360,iostat=ioerr) xbuf
         if (ioerr .ne. 0) goto 360
	      if (swap_flag .eq. 1 ) then
   	      call swap(xbuf)
      	endif
      	nrec=nrec+1

         isact=nhirs(1)
!      print * , 'scanline=', nhirs(1)
!   check whether a gap in the data
         if (isact .ne. isexp) then
            print *, 'There is a gap between scan lines (2nd)!'
            print *, 'Pay attention to the flag of the scan!'
         endif
!lee search for space view
         call extract_bit_int2(nhirs(5),scanbit1)
         if (scanbit1(8) .eq. 1 .and. scanbit1(9) .eq. 0) then
!            write(58,*) 'next space found',nrec
            continue
         else
            print *, 'Not the space line? Go back for a new superswath!'
            if (nhirs(1) .eq. max_scanline) goto 360
            go to 5100
         endif
!   if really a space view 
         do in=1,2128
            suphirs(in,41)= nhirs(in)
         enddo
! suppose to read the cold and warm blackbody records
         do ir=1,2
            read (hunit, rec=nrec,err=360,iostat=ioerr) xbuf
            if (ioerr .ne. 0) goto 360
		      if (swap_flag .eq. 1 ) then
      		   call swap(xbuf)
      		endif
      		nrec=nrec+1

            do in=1,2128
               suphirs(in,41+ir)= nhirs(in)
            enddo
         enddo
         call extract_bit_int2(nhirs(5),scanbit1)
         if (scanbit1(8) .eq. 1 .and. scanbit1(9) .eq. 1) then
            continue
         else
!            write(58,'(4(4i2,2x),i5,"*** not warm, skip!")') &
!                 (scanbit1(i),i=0,15),nrec
            print *, 'Not warm blackbody! Not a valid superswath!'
            print *, 'Start to find a new super swath!'
				if (nhirs(1) .eq. max_scanline) goto 360
            go to 5100
         endif
! set a new isexp ........
         isexp=nhirs(1)+1
         isup=isup+1
!      print * , '#',isup, '   superswath'
!*************************************************************
! finished construction of a superswath
!*************************************************************
!
!...   process HIRS data
!
         call get_hirs
! if fail in processing the superswath, go to next
         if(irfail .ne. 0) then
            write(6,*) 'IR FAILED',irfail,isup
            go to 350
         endif
! output the result *************************
         iirec=iirec+1
         print *,iirec
!         write(ounit,*) iirec
!         write(ounit,900)(((hirsdat(i,j,k),i=1,35),j=1,56),k=1,40) 

         call calc_lza
         call calc_olr(satid,olr_coeff,crec,yday_target)

 900     format(7F12.3)
 350  continue
 360  continue
      close(hunit)
      enddo ! while loop
 400  continue ! while loop end escape
!      close(ounit)
      close(olr_unit)
      close(funit)
      end





