!========================================================================================
!@***h* Daily OLR CDR/rdhdr_1995.f90
! 
! NAME         
!   rdhdr_1995.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx, xx=11,12,14
!
! PURPOSE
!   Read header info from HIRS level-1b data
!
! DESCRIPTION
!   This F90 subroutine reads header info in HIRS Level-1b data.
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!  	swap.f90
!
! INPUTS
!   hdbuf - one header record of HIRS level 1b data read in from file unit 'in'.
!
! OUTPUTS
!  stid - satellite id
!	idttp -
!	numscan - number of scan lines in this orbit file
!	numrec - number of record in this orbit file
!	starty - beginning year
!	startd - beginning day of the year
!	startt - beginning time of the day (seconds)
!	endt - ending time of the day 
!	
! HISTORY
!   2003-01-01   Original Code (atovmain.f) obtained from L. McMillin
!   2013-03-30   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

      subroutine rdhdr(insdd,idtatp,len1b,numsc,numdg,iendtm,insprt,stid,swap_flag)                                                        
!                                                                       
!********************************************************************** 
!                                                                       
!   name- rdhdr                          expires- 12/31/99              
!                                                                       
!   language- fortran     type- subroutine                              
!                                                                       
!   version- 1.0    date- 11/22/82   programmer- frank carr (sasc)      
!                                                                       
!   function-*$sd30fc* This subroutine will read the HIRS, MSU, and SSU  
!        Level 1b dataset header records.  It will check the header record       
!        length, date, data type, and satellite id.  If any of the checks  
!        fail processing is returned to gthrd with iconfg set to less    
!        than 100.  This will eventually lead to a stop 4 execution      
!        terminate in the preprocessor.   If all of the checks pass, several 
!        data items from header are passed to the common area headrc.   
!                                                                       
!   parameters-                                                         
!      variable                type i/o function                        
!      --------                ---- --- --------                        
!      insdd                   i*4  i   the instrument 1b dataset ddname
!      idtatype                i*2  i   the instrument/satellite data   
!                                       type. hirs = 5. msu = 6. ssu = 7
!      len1b                   i*2  i   the length of the 1b dataset    
!                                       header record                   
!      numsc                   i*2  o   number of scan lines            
!      numdg                   i*2  o   number of data gaps             
!      iedtim                  i*2  o   the ending time of the header   
!                                       record                          
!      insprt                  l*4  i   the dataset name to be printed  
!                                       for error messages              
!      iextim                  i*4  i   the beginning execution time    
!                                       for mstat texec                 
!      icktim                  i*4  i   the check time for a current    
!                                       header record                   
!                                                                       
!   files-                                                              
!      dsn or descriptive title  i/o unit functional description        
!      ------------------------  --- ---- ----------------------        
!      (dynamically allocated)   i        HIRS 1b dataset                
!      (dynamically allocated)   i        MSU 1b dataset               
!      (dynamically allocated)   i        SSU  1b dataset               
!                                                                       
!   key local parameters-                                               
!      variable                type  function                           
!      --------                ----  --------                           
!      hdrbuf(2127)            i*2   buffer for storage of header record
!      len                     i*2   the length returned from ffget     
!      idate1,idate2,idate3    i*2   the 6 byte date from the header    
!                                    record                             
!      formhd                  i*2   the format of the date to be       
!                                    supplied to clue routine urdate    
!      mask1                   i*2   mask used to find instrument id    
!      numck                   i*2   number of scan lines in dataset    
!      numdg                   i*2   number of data gaps in dataset     
!      iendtm                  i*2   the ending time from the dataset   
!                                    header                             
!      iyr                     i*4   the year from tme1b                
!      idy,ihr                 i*4   the day and hour of day from tme1b 
!      ijuldt                  i*4   the julian date obtained by        
!                                    modifying the dates returned from  
!                                    tme1b                              
!      ichrdy(37)              i*4   the various form of the Christian  
!                                    day returned from urdate           
!      irc                     i*4   the return code from urdate        
!      ihdtm                   i*4   the hour date and time of the      
!                                    header record                      
!                                                                       
!   subprograms called- urdate,tme1b,fmove,frwnd                        
!                                                                       
!   exit states- returns to gthrd                                       
!                                                                       
!   common areas- conflg,inbuf,headrc,mstat                             
!                                                                       
!   block datas- units,printc                                           
!                                                                       
!********************************************************************** 
!                                                                       
!     rdhdr    version 1.0  fc   begun 11/22/82  completed 12/20/82     
!llllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllll
      logical*4 insprt                                                  
      integer*4 insdd,iyr,idy,ihr
!l      integer*4 insdd(2),iyr,idy,ihr,icktim,iextim                      
      integer*4 ihdtm,len1b,ijuldt                                  
      integer*4 jstat
      integer*2 hdrbuf(2128),idate1,idate2,idate3,idtatp         
      integer*2 mask1,numsc,numdg,iendtm(3),stid    
      integer, parameter:: reclen = 4253
      character xbuf(reclen)
      equivalence (hdrbuf,xbuf)

      integer*2 swap_flag

      mask1=Z'00F0'
!                                                                       
!*** initialize variables ***                                           
!                                                                       
      numsc = 0                                                         
      numdg = 0                                                         
      iendtm(1) = 0                                                     
      iendtm(2) = 0                                                     
      iendtm(3) = 0                                                     
!     
!      print *,'before reading....'
!lee      read(insdd,rec=1,iostat=jstat) hdrbuf
      read(insdd,rec=1,iostat=jstat) xbuf

      if (swap_flag .eq. 1) then
         call swap(xbuf)
      endif

!      print *, hdrbuf
!      print *,'head info'
!      print *,hdrbuf(0),hdrbuf(1),hdrbuf(2)
      numsc=hdrbuf(5)
!      print *,'num of scan line =',numsc
!llllllllllllllllllllllllllllllllllllllllllllllllllllllllllllll
!      call i2move(idate1,1,hdrbuf(2))
!      call i2move(idate2,1,hdrbuf(3))
!      call i2move(idate3,1,hdrbuf(4)) 
!lee (because the i2move subroutine is for array)
      idate1=hdrbuf(2)
      idate2=hdrbuf(3)
      idate3=hdrbuf(4)
!      write(6,*) 'idate',idate1,idate2,idate3
!l
!l      call i2move(idate1,2,hdrbuf(2))                                    
!l      call i2move(idate2,2,hdrbuf(3))                                    
!l      call i2move(idate3,2,hdrbuf(4))                                    
!                                                                       
!*** obtain the time from the header from subroutine tme1b ***          
!*** then convert this date into a julian date, then to a  ***          
!*** Christian date.                                       ***          
!                       
      print *, idate1
                                                
      call extract_year(idate1,iyr)
      call extract_jday(idate1,idy)

!      print *, iyr, idy

      call extract_msec(idate2,idate3,msec,ihr,imn,isec)
      print *,'HEAD time'
!      print *,iyr,idy,ihr,imn,isec,msec
!     pause
      ijuldt = (iyr*1000) + idy                                         
      ihdtm = (ijuldt*100) + ihr     
!      stid = hdrbuf(1)/256
!                                    
!                                                                       

 50   stid = hdrbuf(1)/256                                             
 100  return                                                            
      end         

