!========================================================================================
!@***h* Daily OLR CDR/hirs_cali_HIRS3.f90
! 
! NAME         
!   hirs_cali_HIRS3.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx, xx=15,16,17
!
! PURPOSE
!   Derive radiance calibration coefficients following McMillin method
!
! DESCRIPTION
!   Given a HIRS superswath, the calibration coefficients (intercept and gain) are derived
!  	following McMillin method.
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!  type_def.f90
!	superdata.cmn.f90
!	instrument.cmn.f90
!	phys_const.cmn.f90
!
! INPUTS
!	suphirs - superswath of 43 lines (1-3,41-43 calibration scans,4-40 earthview)
!	satid - satellite id
!	olr_coeff - static data
!	crec - record number for direct access binary output file
!
! OUTPUTS
!   pslope(42,19) - radiance calibration coefficient, slope term 
!	pintcpt(42,19) - radiance calibration coefficient, intercept term
!
! HISTORY
!   2003-08-01   Hai-Tien Lee Created
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

! Changes from N15
!The number of warm target changed from 4 to 5.
!'space(3)' becomes 'wtts5(5)'

!1. Change type of array of mean
!'hirs_cali.f90'

!1) integer*2 scount(56,20), wcount(56,20), warmt(20) ---> real*4 scount(56,20), wcount(56,20), warmt(25)

!2. Change number of warm count from 4 to 5
!'hirs_cali.f90'

!1) real*4 prtw(4)  --->  prtw(5)

!2) warmt(20)   --->   warmt(25)

!3) add line
!   warmt(21:25)  =  onehir%space3

!4) do 130 i=1,4   --->   do 130 i=1,5

!5) tprtw = tprtw / 4.0   --->   tprtw = tprtw / 5.0

!6) 'instrument.cmn.f90'
!real*4 cofw(5,4)   --->   real*4 cofw(5,5)

!7) 'read_intru_para.f90'
!do i=1,4   --->   do i=1,5

!3. number of data in 'prt.txt' changed.
!please check 'n18_prt.dat'
!2 more columns are added.
!Remove first two columns or modify 'read' line in 'read_instru_para.f90'

      subroutine  hirs_cali(pslope,pintcpt)
!C    

!C*************************************************************************
!C This subroutine input a superswath of the Hirs 1b data , output
!C the calibration coefficients for channel 1-19
!C*************************************************************************
!C Description of variables:
!
!  suphirs : input superscan,42 lines (1-2,41-42 calibration scans,3-40 earthview)
!  pslope  : output slope
!  pintcpt : output intercept
!  
!  band,bandc : Hirs/2 band correction coefficients
!  c1,c2   : parameters for calculating radiance 
!  cofw : coefficients for warm blackbody brightness temperature
!  coslope : coefficients for predicting slope
!  cointcpt: coefficients for predicting intercepte
!  iord    : order of each channel's location in the data set 
!  irfail  : flag: 0: good calibration; 1: bad calibration
!  mfq     : quqlity info for each spot
!  nflags  : flags for each scan line
!  nslope  : calculated slope at two ends
!  nintcpt : calculated intercept at two ends
!  onehir  : one scaline of Hirs data
!  prtw    : warm blackbody temperature 
!  prtrad  : radiance from the warm blackbody
!  scount  : space view counts
!  wcount  : warm blackbody view counts
!  warmt   : warm blackbody temperature counts
!  sinst   : space scan instrument temperatures (counts)
!  winst   : warm blackbody scan instrument temperatures (counts)
!  tstar   : band corrected warm blackbody temperature
!  
!*************************************************************************
      USE type_def
      implicit none
      include 'superdata.cmn.f90'
      include 'instrument.cmn.f90'
      include 'phys_const.cmn.f90'
      
      real*4   pslope(42,19),pintcpt(42,19)
      real*4   prtw(4)
      real*4   difslope(2,19),difintcpt(2,19)
      real*4   ainst(8)
      integer*2 sinst(8),winst(8)
      real*4   scount(56,20),wcount(56,20),warmt(20)              
      Type(struc_1b) onehir 
      integer*4 ind(2)
      character imfq
      real*4  tstar(19),prtrad(19)   
      real*4  nslope(2,19),nintcpt(2,19),c,awarmc,tprtw,wsum,s1,s2
      integer i,j,k,iii,m,kk,nums,numw,it,js,jl,is
	   real*8 ismean,iwmean,ismean2,iwmean2,smean(19),wmean(19)
      data ind/1,41/


!lee initialize irfail=0
		irfail=0

!C initialize the slope and intcpt array
		do i=1,43
			do j=1,19
				pslope(i,j)= 0.0
				pintcpt(i,j)= 0.0
			enddo
		enddo  
   
!C First get the calibration coeff for both ends of the sup swath

      do 100 iii=1,2     ! for two ends

!C initialize counts
         do i=1,56
            do j=1,20
               scount(i,j)=-9999
               wcount(i,j)=-9999
            enddo
         enddo   

!C assign space scan to onehir
      onehir=suphirs(ind(iii))

!C check the flags
      if(onehir%scanType .ne. 1) then 
      print *, 'First line is not a space line!'
      return
      endif

      do k=1,20   !20 channels                    
      m = iord(k)

      do 110 i = 1,56                                                    
      imfq=onehir%frameQual(i)                                                     
      if(btest(ichar(imfq),2)) goto 110
       c=onehir%ele(i)%rCount(m)
!deal with the sign bit, 1's compliment
        c = c - 4095
        if ( c .gt. 0 )  c = c - 1
        scount(i,k)=c
!lee check space view count
!        write(50,*) scount(i,k),i,k
 110   continue

      enddo    !k=1,20

!C instrument temp count
         sinst=onehir%instTemp

!C now the warm target count

!C assign warm target scan to onehir
      onehir=suphirs(ind(iii)+1)

      awarmc = 0.0  
                                                    
      do k=1,20                                                      
                       
      m = iord(k)                                                       
                                    
      do 120 i = 1,56                                                    
      imfq=onehir%frameQual(i)                                                     
      if(btest(ichar(imfq),2)) goto 120
       c=onehir%ele(i)%rCount(m)
!deal with the sign bit, 1's compliment
        c = c - 4095
        if ( c > 0 )  c = c - 1
        wcount(i,k)=c
!        write(51,*) wcount(i,k),i,k
  120 continue                                                          

      enddo !k=1,20

!C Add sth here, warm BB temp and instrument temp
         warmt(1:5) =  onehir%wtts1
         warmt(6:10) =  onehir%wtts2
         warmt(11:15) =  onehir%wtts3
         warmt(16:20) =  onehir%wtts4

         winst=onehir%instTemp

!C calculate the warm B.B radiance according to temperature 
                          
      tprtw = 0.0 
      do 130 i= 1,4
			wsum=0.0
			do 131 j=1,5 
				kk=(i-1)*5+j
				if (warmt(kk) .ne. -9999 .and. warmt(kk) .lt. 32760)  then 
				 wsum=wsum+warmt(kk)
				endif
 131  continue
      wsum=wsum/5.0

      prtw(i) = cofw(1,i) + cofw(2,i)*wsum + cofw(3,i)*wsum*wsum     &
                 + cofw(4,i)*wsum*wsum*wsum + cofw(5,i)*wsum*wsum*wsum*wsum

      tprtw=tprtw + prtw(i)
 130  continue
      tprtw=tprtw/4.0
                                                                     
      do k=1,19
      tstar(k)=tprtw * bandc(2,k) + bandc(1,k)

      s1 = c1*waven(k)*waven(k)*waven(k)
      s2 = exp( (c2* waven(k))/tstar(k)) -1
      prtrad(k) = s1/s2
      enddo  !k=1,19

!C calculate the mean of the space count and warm count for spots 9-56
      do 140 k=1,19 
      smean(k)=0.0
      wmean(k)=0.0
      ismean=0.
      iwmean=0.
      ismean2=0.
      iwmean2=0.
      nums=0
      numw=0

      do i=9,56 
      if (scount(i,k) .ne. -9999 .and. scount(i,k) .lt. 32760) then
         ismean=ismean+scount(i,k)
         nums=nums+1
      endif
      
      if(wcount(i,k) .ne. -9999 .and. wcount(i,k) .lt. 32760 ) then 
         iwmean=iwmean+wcount(i,k)
         numw=numw+1
      endif
      enddo  !i=9,56
 
      if (nums .gt. 0) then  
        ismean= ismean/nums 
      else 
!         print *,'nums=',nums
         irfail=1
         return
      endif

       if (numw .gt. 0) then  
       iwmean = iwmean/numw 
       else 
!       print *,'numw',numw
       irfail=1
         return
       endif 

! calculate standard deviation, sum diff squred
      do i=9,56 
      if (scount(i,k) .ne. -9999 .and. scount(i,k) .lt. 32760) then
         ismean2=ismean2+(scount(i,k)-ismean)*(scount(i,k)-ismean)
      endif
      if (wcount(i,k) .ne. -9999 .and. wcount(i,k) .lt. 32760) then
         iwmean2=iwmean2+(wcount(i,k)-iwmean)*(wcount(i,k)-iwmean)
      endif
      enddo
      ismean2=sqrt(ismean2/(nums-1.))
      iwmean2=sqrt(iwmean2/(numw-1.))

! Discard 3-sigma outliers (Hai-Tien 20101215)
      nums=0
      numw=0
      do i=9,56
      !   print *,'scount&wcount',scount(i,k),wcount(i,k)
      if (scount(i,k) .ne. -9999 .and. scount(i,k) .lt. 32760 .and. &
                                      abs(scount(i,k)-ismean) .le. 3*ismean2    ) then
         smean(k)=smean(k)+scount(i,k)
         nums=nums+1
      endif
      if(wcount(i,k) .ne. -9999 .and. wcount(i,k) .lt. 32760 .and.  &
                                   abs(wcount(i,k)-iwmean) .le. 3*iwmean2 ) then 
         wmean(k)=wmean(k)+wcount(i,k)
         numw=numw+1
      endif
      enddo  !i=9,56

      if (nums .gt. 0) then  
        smean(k)= smean(k)/float(nums) 
      else 
!         print *,'nums=',nums
         irfail=1
         return
      endif

       if (numw .gt. 0) then  
         wmean(k) = wmean(k)/float(numw) 
       else 
!         print *,'numw',numw
         irfail=1
         return
       endif 

! Re-calculate standard deviation. This is for NEdN.
 	  do i=9,56 
      if (scount(i,k) .ne. -9999 .and. scount(i,k) .lt. 32760) then
         ismean2=ismean2+(scount(i,k)-smean(k))*(scount(i,k)-smean(k))
      endif
      if (wcount(i,k) .ne. -9999 .and. wcount(i,k) .lt. 32760) then
         iwmean2=iwmean2+(wcount(i,k)-wmean(k))*(wcount(i,k)-wmean(k))
      endif
      enddo
      ismean2=sqrt(ismean2/(nums-1.))
      iwmean2=sqrt(iwmean2/(numw-1.))
 
!C here if too many spots are thrown away, add a flag showing 
!C that calibration coefficients may be suspicious

       if (nums .le. 41 .or. numw .le. 41) then
          print*,'Too many spots are thrown away during calibration!!'
          print*,'nums= ',nums,'numw=',numw
!          print *,'K=',k
!          print *,scount(9:56,k)
             do jl=1,40
                do js=1,56
                 if(iii .eq. 1) then
                  hirsdat(33,js,jl)=-1.0
                 else 
                  hirsdat(33,js,jl)=-2.0
                 endif
                enddo
             enddo
       endif   
 140   continue  !k=1,19

!C calculate slope and intercept based on above results
       do k=1,19
       if((smean(k)-wmean(k)) .gt. 0.1) then
          nslope(iii,k)= (0.0 - prtrad(k))/ (smean(k) - wmean(k))
          nintcpt(iii,k)= 0.0 - nslope(iii,k)*smean(k)
!C      print *,'slope&intcpt', k, nslope(iii,k),nintcpt(iii,k)
       else
          print *,'Sth wrong with warm BB counts or space-view counts!'
          irfail=1
          return
       endif   
       enddo

!C  Now predict the slope and intercept from instrument temperatures and
!C  get the differences between calculated and predicted coefficients
      do i=1,8
      if(winst(i) .gt. 0 .and. winst(i) .lt. 32760 .and.   &
                      sinst(i) .gt. 0 .and. sinst(i) .lt. 32760) then
          ainst(i)=(winst(i)+sinst(i))/2.0
      else
          print *,'wsinst',winst(i),sinst(i)
          print *,'Sth wrong with instrument temperatures!'
          irfail=1
          return
      endif  
      enddo
      
      do 150 k=1,19
!C  slope
      pslope(iii,k)=coslope(1,k)+sum(coslope(2:9,k)*ainst(1:8))
      difslope(iii,k)=(nslope(iii,k)-pslope(iii,k))
!C  intercept
 	  pintcpt(iii,k)=cointcpt(1,k)+sum(cointcpt(2:9,k)*ainst(1:8))
      difintcpt(iii,k)=(nintcpt(iii,k)-pintcpt(iii,k))
! 	  print *,'Calibrated coefficients',k,nslope(iii,k),nintcpt(iii,k)
!      print *,'Predicted',pslope(iii,k),pintcpt(iii,k),difslope(iii,k),difintcpt(iii,k)

 150  continue

 100  continue

!C   end of calculate calibration at two ends of the Superswath  R!C

!C Now get the calibration for all the scanline
!C first move the cali from 2 to 41
      do k=1,19
         pslope(41,k) = pslope(2,k)
         pintcpt(41,k) = pintcpt(2,k)
      enddo

   
      do 160 is=3,40    ! all 37 earth-view scans
       onehir=suphirs(is)

!C instrument temp count
      do it=1,8
         sinst(it)=onehir%instTemp(it)
!C         print *,'sinst',it, sinst(it)
         if(sinst(it) .lt. 0 .or. sinst(it) .gt. 32760) then
            print *,'Something wrong with sinst! ', &
                 'Calibration coefficients for ',   &
                 'this scan will be zero!'
            goto 160
         endif
      enddo   !it=1,8
      
      do k=1,19
!C  slope
      pslope(is,k)=0.0
      do j=1,8
       pslope(is,k)=pslope(is,k)+ coslope(j+1,k)*sinst(j)
      enddo
      pslope(is,k)=pslope(is,k)+coslope(1,k)

!C do some adjustment according to the difference at two ends
!  I modified this from original one
      pslope(is,k)=pslope(is,k)+difslope(1,k)*((41-is)/40.0)
      pslope(is,k)=pslope(is,k)+(difslope(2,k))*((is-1)/40.0)

!C  intercept
      pintcpt(is,k)=0.0
      do j=1,8
       pintcpt(is,k)= pintcpt(is,k)+cointcpt(j+1,k)*sinst(j)
      enddo
      pintcpt(is,k) = pintcpt(is,k)+ cointcpt(1,k)

!C do some adjustment according to the difference at two ends
!  I modified this from original one
      pintcpt(is,k)=pintcpt(is,k)+difintcpt(1,k)*((41-is)/40.0)
      pintcpt(is,k)=pintcpt(is,k)+difintcpt(2,k)*((is-1)/40.0)

!      print *,pslope(is,k),pintcpt(is,k)
      enddo  ! k=1,19

 160  continue

!C Fill the original calibration back to the both ends (4 lines) of superswath
      do k=1,19
         is=1
           pslope(is,k)=nslope(1,k)
           pintcpt(is,k)=nintcpt(1,k)
         is=2
           pslope(is,k)=nslope(1,k)
           pintcpt(is,k)=nintcpt(1,k)
         is=41
           pslope(is,k)=nslope(2,k)
           pintcpt(is,k)=nintcpt(2,k)
         is=42
           pslope(is,k)=nslope(2,k)
           pintcpt(is,k)=nintcpt(2,k)
      enddo
      
!      do i=1,42
!         write(6,*) i,pslope(i,19),pintcpt(i,19)
!      enddo
      
      end

!C****************** end of calibration***************************
