!========================================================================================
!@***h* Daily OLR CDR/calc_olr_HIRS34.f90
! 
! NAME         
!   calc_olr_HIRS34.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx/calc_olr_HIRS3.f, xx=15,16,...,21
!
! PURPOSE
!   Performs HIRS OLR retrieval
!
! DESCRIPTION
!   Given calibration radiance and related info (hirsdat), this F90 subroutine calculate OLR
!	using Ellingson et al. (1989) algorithm for the given satellite (satid)
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!  type_def.f90
!	superdata.cmn.f90
!
! INPUTS
!  hirsdat - holding array for calibrated HIRS radiances and related info (via common block)
!	satid - satellite id
!	olr_coeff - static data
!	crec - record number for direct access binary output file
!
! OUTPUTS
!   olrdat(13,56,40) - containing OLR, input radiance, geolocation, lza, & timing info
!
! HISTORY
!   2003-08-01   Hai-Tien Lee Created
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2012-04-09   Hai-Tien Lee Add absoluete function for LZA to index m conversion (line 84).
!   2013-08-23   Hai-Tien Lee Add QC on radiance 1. define rad min and max, 2. QC zero on all radiances
!   2013-09-12   Hai-Tien Lee Add target_day check
!   2013-11-29   Hai-Tien Lee Revise OLR model to v2.7: [3,7,8,11, sq(8),sqrt(11),sqrt(12)]
!  	           Scale radiance to mW/m-2 (sr cm-1)-1 first
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================


! 8/1/03 Hai-Tien Lee
! Calculate OLR given calibrated HIRS radiances (mW/m-2 (sr cm-1)-1)

      subroutine calc_olr(satid,olr_coeff,crec,yday_target)

		use type_def
      implicit none
      include 'superdata.cmn.f90'

      integer, parameter:: nvar = 7
      real*4 olrdat(13,56,40)
      real*4 rad(nvar,56,40),olr(56,40),lza(56,40),c(nvar+1,56,40),h(56,40)
      real*4 rad3_min,rad3_max,rad7_min,rad7_max,rad8_min,rad8_max,rad11_min,rad11_max
      integer chansel(nvar)
      real*4  power(nvar)
      integer satid
      real olr_coeff(nvar+1,6500)
      integer i,j,k,m
      integer crec
      integer*2 yday_target

!   2013-08-20   Hai-Tien Lee Revise OLR model for all HIRS instruments to use Ch[3,7,8,11].
!      if (satid .le. 10 .or. satid .eq. 12) then
!         chansel=(/3,7,10,12/)
!      else
!         chansel=(/3,10,11,12/)
!      endif
!      chansel=(/3,7,8,11/)

!   2013-11-29   Hai-Tien Lee Revise OLR model to v2.7: [3,7,8,11, sq(8),sqrt(11),sqrt(12)]
!  	           Scale radiance to mW/m-2 (sr cm-1)-1 first
      chansel=(/ 3, 7, 8, 11,  8, 11, 12/)
      power=  (/ 1.,1.,1., 1., 2, .5, .5/)

      write(6,'("Satid=",i3," HIRS Channels=",7i3,7f4.1)') satid,chansel,power
      olrdat(1:8,:,:)=hirsdat(1:8,:,:)
      do i=1,nvar
      	rad(i,:,:)=(hirsdat(8+chansel(i),:,:)*1.e-3)**power(i)
		enddo
      h=hirsdat(7,:,:)
      lza=hirsdat(8,:,:)
!      olrdat(9:12,:,:)=rad

!   2013-08-23   Hai-Tien Lee Add QC on radiance 1. define rad min and max, 2. QC zero on all radiances
! Define effective "zero" for QC radiance 
! Note: Need to find out why the bad radiances are not exactly zero in calibration program.

! Ch/Min/Max (mWm-2 (sr cm-1)-1) based on IASI/N15 simnulation for 1st of each of 12 months of 2012.
!;        1      29.2692      87.0645
!;        2      22.5225      73.3243
!;        3      21.2582      66.6354
!;        4      20.8394      59.4717
!;        5      20.1944      77.8058
!;        6      16.8720      99.2426
!;        7      14.6843      120.173
!;        8      6.95927      173.918
!;        9      5.67564      82.4171
!;       10      10.5599      169.539
!;       11     0.724797      30.2111
!;       12     0.329963      9.66025
!;       13   0.00389122      4.61500
!;       14   0.00558491      2.09983
!;       15  1.88287e-08      1.02781
!;       16  2.85381e-07     0.706364
!;       17  1.56005e-06      3.31761
!;       18  4.95744e-07      3.62813
		rad3_min=15*1.e-3
		rad3_max=80*1.e-3
		rad7_min=5*1.e-3
		rad7_max=130*1.e-3
		rad8_min=5*1.e-3
		rad8_max=185*1.e-3
		rad11_min=0.5*1.e-3
		rad11_max=40*1.e-3

      do k=1,40
         do j=1,56
            m=int(abs(lza(j,k))*100)
!   2013-08-23   Hai-Tien Lee Add QC on radiance 1. define zero, 2. QC zero on all radiances
! QC on all channels with min and max constraints.
!            if (rad(1,j,k) .gt. 0 .and. olrdat(1,j,k) .eq. 1) then
            if (rad(1,j,k) .le. rad3_min .or. rad(2,j,k) .le. rad7_min .or.  &
                rad(3,j,k) .le. rad8_min .or. rad(4,j,k) .le. rad11_min .or.  &
                rad(1,j,k) .ge. rad3_max .or. rad(2,j,k) .ge. rad7_max .or.  &
                rad(3,j,k) .ge. rad8_max .or. rad(4,j,k) .ge. rad11_max .or.  &
                olrdat(1,j,k) .ne. 1 ) then
            goto 200
            else 
            if (m .le. 6499 .and. m .ge. 0) then
               do i=1,nvar+1
                  c(i,j,k)=olr_coeff(i,m)
               enddo
! Applying regression equation olrdat(13,j,k)=OLR
               olrdat(13,j,k)=c(1,j,k)+sum(c(2:nvar+1,j,k)*rad(:,j,k) )

! filter OLR values to avoid a few bad radiances
!   2013-09-12   Hai-Tien Lee Add checking on if olrdat(5,j,k) = yday_target
               if (olrdat(5,j,k) .eq. yday_target) then
               if (olrdat(13,j,k) .ge. 50 .and. olrdat(13,j,k) .le. 500) then
                  write(334,rec=crec) olrdat(2,j,k),olrdat(3,j,k), &
                  		olrdat(13,j,k),olrdat(6,j,k)/1000.,lza(j,k)
!                  write(335,rec=crec) rad(1,j,k),rad(2,j,k),rad(3,j,k),rad(4,j,k)

!             print *, olrdat(2,j,k),olrdat(3,j,k),olrdat(13,j,k),olrdat(6,j,k)/1000.,lza(j,k)
                  crec=crec+1
               endif
               endif
            endif
            endif
 200        continue
         enddo
      enddo
 100  format(f7.3,1x,f8.3,1x,f7.3,1x,f6.3,1x,i4,1x,i3,1x,i5)
      return
      end


