!========================================================================================
!@***h* Daily OLR CDR/read_hirs1b.f90
! 
! NAME         
!   read_hirs1b.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx, xx=15,16,...,21
!
! PURPOSE
!   Read in HIRS level-1b data into structure variable
!
! DESCRIPTION
!   This F90 subroutine reads in HIRS Level-1b data, performs HIRS radiance calibration
!	using McMillin method (NOAA POES Users Guide, 1998).
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!  type_def.f90
!
! INPUTS
!	n - direct access record number to be read in 
!   filename - HIRS level-1b data file name
!
! OUTPUTS
!   hirs1b_d(struc_1b) - A structure variable containing HIRS level-1b data
!	nerror - error code for read error
!
! HISTORY
!   2009-01-01   Junsuk Lee created to bypass Intel Fortran limitation that structure variable
!	             cannot be endian swapped unless it is read in as flattened fashion.
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

      subroutine read_hirs1b(n,filename,hirs1b_d,nerror)
      USE type_def
      Type(struc_1b) hirs1b_d
      character*255 filen, filename
      integer hunit, nerror

      nrec   =  n
      filen  =  filename
      hunit  =  1


      Open(hunit, file=filen,form='unformatted',        &
           status='old',access='direct',recl=4608)
      Read(hunit,rec=nrec,err=300,IOstat=Istat)         &
           hirs1b_d%scanNum,                            &
           hirs1b_d%scanYr,                             &
           hirs1b_d%scanDay,                            &
           hirs1b_d%clockDrift,                         &
           hirs1b_d%scanTime,                           &
           hirs1b_d%byte13,                             &
           hirs1b_d%frameNum,                           &
           hirs1b_d%scanPos,                            &
           hirs1b_d%scanType,                           &
           hirs1b_d%byte21(1),                          &
           hirs1b_d%byte21(2),                          &
           hirs1b_d%qualField,                          &
           hirs1b_d%scanQual,                           &
           hirs1b_d%calQual(1),                         &
           hirs1b_d%calQual(2),                         &
           hirs1b_d%calQual(3),                         &
           hirs1b_d%calQual(4),                         &
           hirs1b_d%calQual(5),                         &
           hirs1b_d%calQual(6),                         &
           hirs1b_d%calQual(7),                         &
           hirs1b_d%calQual(8),                         &
           hirs1b_d%calQual(9),                         &
           hirs1b_d%calQual(10),                        &
           hirs1b_d%calQual(11),                        &
           hirs1b_d%calQual(12),                        &
           hirs1b_d%calQual(13),                        &
           hirs1b_d%calQual(14),                        &
           hirs1b_d%calQual(15),                        &
           hirs1b_d%calQual(16),                        &
           hirs1b_d%calQual(17),                        &
           hirs1b_d%calQual(18),                        &
           hirs1b_d%calQual(19),                        &
           hirs1b_d%calQual(20),                        &
           hirs1b_d%frameQual(1),                       &
           hirs1b_d%frameQual(2),                       &
           hirs1b_d%frameQual(3),                       &
           hirs1b_d%frameQual(4),                       &
           hirs1b_d%frameQual(5),                       &
           hirs1b_d%frameQual(6),                       &
           hirs1b_d%frameQual(7),                       &
           hirs1b_d%frameQual(8),                       &
           hirs1b_d%frameQual(9),                       &
           hirs1b_d%frameQual(10),                      &
           hirs1b_d%frameQual(11),                      &
           hirs1b_d%frameQual(12),                      &
           hirs1b_d%frameQual(13),                      &
           hirs1b_d%frameQual(14),                      &
           hirs1b_d%frameQual(15),                      &
           hirs1b_d%frameQual(16),                      &
           hirs1b_d%frameQual(17),                      &
           hirs1b_d%frameQual(18),                      &
           hirs1b_d%frameQual(19),                      &
           hirs1b_d%frameQual(20),                      &
           hirs1b_d%frameQual(21),                      &
           hirs1b_d%frameQual(22),                      &
           hirs1b_d%frameQual(23),                      &
           hirs1b_d%frameQual(24),                      &
           hirs1b_d%frameQual(25),                      &
           hirs1b_d%frameQual(26),                      &
           hirs1b_d%frameQual(27),                      &
           hirs1b_d%frameQual(28),                      &
           hirs1b_d%frameQual(29),                      &
           hirs1b_d%frameQual(30),                      &
           hirs1b_d%frameQual(31),                      &
           hirs1b_d%frameQual(32),                      &
           hirs1b_d%frameQual(33),                      &
           hirs1b_d%frameQual(34),                      &
           hirs1b_d%frameQual(35),                      &
           hirs1b_d%frameQual(36),                      &
           hirs1b_d%frameQual(37),                      &
           hirs1b_d%frameQual(38),                      &
           hirs1b_d%frameQual(39),                      &
           hirs1b_d%frameQual(40),                      &
           hirs1b_d%frameQual(41),                      &
           hirs1b_d%frameQual(42),                      &
           hirs1b_d%frameQual(43),                      &
           hirs1b_d%frameQual(44),                      &
           hirs1b_d%frameQual(45),                      &
           hirs1b_d%frameQual(46),                      &
           hirs1b_d%frameQual(47),                      &
           hirs1b_d%frameQual(48),                      &
           hirs1b_d%frameQual(49),                      &
           hirs1b_d%frameQual(50),                      &
           hirs1b_d%frameQual(51),                      &
           hirs1b_d%frameQual(52),                      &
           hirs1b_d%frameQual(53),                      &
           hirs1b_d%frameQual(54),                      &
           hirs1b_d%frameQual(55),                      &
           hirs1b_d%frameQual(56),                      &
           hirs1b_d%frameQual(57),                      &
           hirs1b_d%frameQual(58),                      &
           hirs1b_d%frameQual(59),                      &
           hirs1b_d%frameQual(60),                      &
           hirs1b_d%frameQual(61),                      &
           hirs1b_d%frameQual(62),                      &
           hirs1b_d%frameQual(63),                      &
           hirs1b_d%frameQual(64),                      &
           hirs1b_d%byte141(1),                         &
           hirs1b_d%byte141(2),                         &
           hirs1b_d%byte141(3),                         &
           hirs1b_d%byte141(4),                         &
           hirs1b_d%PrimCali(1,1),                      &
           hirs1b_d%PrimCali(2,1),                      &
           hirs1b_d%PrimCali(3,1),                      &
           hirs1b_d%PrimCali(1,2),                      &
           hirs1b_d%PrimCali(2,2),                      &
           hirs1b_d%PrimCali(3,2),                      &
           hirs1b_d%PrimCali(1,3),                      &
           hirs1b_d%PrimCali(2,3),                      &
           hirs1b_d%PrimCali(3,3),                      &
           hirs1b_d%PrimCali(1,4),                      &
           hirs1b_d%PrimCali(2,4),                      &
           hirs1b_d%PrimCali(3,4),                      &
           hirs1b_d%PrimCali(1,5),                      &
           hirs1b_d%PrimCali(2,5),                      &
           hirs1b_d%PrimCali(3,5),                      &
           hirs1b_d%PrimCali(1,6),                      &
           hirs1b_d%PrimCali(2,6),                      &
           hirs1b_d%PrimCali(3,6),                      &
           hirs1b_d%PrimCali(1,7),                      &
           hirs1b_d%PrimCali(2,7),                      &
           hirs1b_d%PrimCali(3,7),                      &
           hirs1b_d%PrimCali(1,8),                      &
           hirs1b_d%PrimCali(2,8),                      &
           hirs1b_d%PrimCali(3,8),                      &
           hirs1b_d%PrimCali(1,9),                      &
           hirs1b_d%PrimCali(2,9),                      &
           hirs1b_d%PrimCali(3,9),                      &
           hirs1b_d%PrimCali(1,10),                     &
           hirs1b_d%PrimCali(2,10),                     &
           hirs1b_d%PrimCali(3,10),                     &
           hirs1b_d%PrimCali(1,11),                     &
           hirs1b_d%PrimCali(2,11),                     &
           hirs1b_d%PrimCali(3,11),                     &
           hirs1b_d%PrimCali(1,12),                     &
           hirs1b_d%PrimCali(2,12),                     &
           hirs1b_d%PrimCali(3,12),                     &
           hirs1b_d%PrimCali(1,13),                     &
           hirs1b_d%PrimCali(2,13),                     &
           hirs1b_d%PrimCali(3,13),                     &
           hirs1b_d%PrimCali(1,14),                     &
           hirs1b_d%PrimCali(2,14),                     &
           hirs1b_d%PrimCali(3,14),                     &
           hirs1b_d%PrimCali(1,15),                     &
           hirs1b_d%PrimCali(2,15),                     &
           hirs1b_d%PrimCali(3,15),                     &
           hirs1b_d%PrimCali(1,16),                     &
           hirs1b_d%PrimCali(2,16),                     &
           hirs1b_d%PrimCali(3,16),                     &
           hirs1b_d%PrimCali(1,17),                     &
           hirs1b_d%PrimCali(2,17),                     &
           hirs1b_d%PrimCali(3,17),                     &
           hirs1b_d%PrimCali(1,18),                     &
           hirs1b_d%PrimCali(2,18),                     &
           hirs1b_d%PrimCali(3,18),                     &
           hirs1b_d%PrimCali(1,19),                     &
           hirs1b_d%PrimCali(2,19),                     &
           hirs1b_d%PrimCali(3,19),                     &
           hirs1b_d%PrimCali(1,20),                     &
           hirs1b_d%PrimCali(2,20),                     &
           hirs1b_d%PrimCali(3,20),                     &
           hirs1b_d%SpareCali(1,1),                     &
           hirs1b_d%SpareCali(2,1),                     &
           hirs1b_d%SpareCali(3,1),                     &
           hirs1b_d%SpareCali(1,2),                     &
           hirs1b_d%SpareCali(2,2),                     &
           hirs1b_d%SpareCali(3,2),                     &
           hirs1b_d%SpareCali(1,3),                     &
           hirs1b_d%SpareCali(2,3),                     &
           hirs1b_d%SpareCali(3,3),                     &
           hirs1b_d%SpareCali(1,4),                     &
           hirs1b_d%SpareCali(2,4),                     &
           hirs1b_d%SpareCali(3,4),                     &
           hirs1b_d%SpareCali(1,5),                     &
           hirs1b_d%SpareCali(2,5),                     &
           hirs1b_d%SpareCali(3,5),                     &
           hirs1b_d%SpareCali(1,6),                     &
           hirs1b_d%SpareCali(2,6),                     &
           hirs1b_d%SpareCali(3,6),                     &
           hirs1b_d%SpareCali(1,7),                     &
           hirs1b_d%SpareCali(2,7),                     &
           hirs1b_d%SpareCali(3,7),                     &
           hirs1b_d%SpareCali(1,8),                     &
           hirs1b_d%SpareCali(2,8),                     &
           hirs1b_d%SpareCali(3,8),                     &
           hirs1b_d%SpareCali(1,9),                     &
           hirs1b_d%SpareCali(2,9),                     &
           hirs1b_d%SpareCali(3,9),                     &
           hirs1b_d%SpareCali(1,10),                    &
           hirs1b_d%SpareCali(2,10),                    &
           hirs1b_d%SpareCali(3,10),                    &
           hirs1b_d%SpareCali(1,11),                    &
           hirs1b_d%SpareCali(2,11),                    &
           hirs1b_d%SpareCali(3,11),                    &
           hirs1b_d%SpareCali(1,12),                    &
           hirs1b_d%SpareCali(2,12),                    &
           hirs1b_d%SpareCali(3,12),                    &
           hirs1b_d%SpareCali(1,13),                    &
           hirs1b_d%SpareCali(2,13),                    &
           hirs1b_d%SpareCali(3,13),                    &
           hirs1b_d%SpareCali(1,14),                    &
           hirs1b_d%SpareCali(2,14),                    &
           hirs1b_d%SpareCali(3,14),                    &
           hirs1b_d%SpareCali(1,15),                    &
           hirs1b_d%SpareCali(2,15),                    &
           hirs1b_d%SpareCali(3,15),                    &
           hirs1b_d%SpareCali(1,16),                    &
           hirs1b_d%SpareCali(2,16),                    &
           hirs1b_d%SpareCali(3,16),                    &
           hirs1b_d%SpareCali(1,17),                    &
           hirs1b_d%SpareCali(2,17),                    &
           hirs1b_d%SpareCali(3,17),                    &
           hirs1b_d%SpareCali(1,18),                    &
           hirs1b_d%SpareCali(2,18),                    &
           hirs1b_d%SpareCali(3,18),                    &
           hirs1b_d%SpareCali(1,19),                    &
           hirs1b_d%SpareCali(2,19),                    &
           hirs1b_d%SpareCali(3,19),                    &
           hirs1b_d%SpareCali(1,20),                    &
           hirs1b_d%SpareCali(2,20),                    &
           hirs1b_d%SpareCali(3,20),                    &
           hirs1b_d%byte637(1),                         &
           hirs1b_d%byte637(2),                         &
           hirs1b_d%byte637(3),                         &
           hirs1b_d%byte649(1),                         &
           hirs1b_d%byte649(2),                         &
           hirs1b_d%byte649(3),                         &
           hirs1b_d%byte649(4),                         &
           hirs1b_d%byte649(5),                         &
           hirs1b_d%byte649(6),                         &
           hirs1b_d%byte649(7),                         &
           hirs1b_d%byte649(8),                         &
           hirs1b_d%byte649(9),                         &
           hirs1b_d%byte649(10),                        &
           hirs1b_d%byte649(11),                        &
           hirs1b_d%byte649(12),                        &
           hirs1b_d%byte649(13),                        &
           hirs1b_d%byte649(14),                        &
           hirs1b_d%height,                             &
           hirs1b_d%angles(1,1),                        &
           hirs1b_d%angles(2,1),                        &
           hirs1b_d%angles(3,1),                        &
           hirs1b_d%angles(1,2),                        &
           hirs1b_d%angles(2,2),                        &
           hirs1b_d%angles(3,2),                        &
           hirs1b_d%angles(1,3),                        &
           hirs1b_d%angles(2,3),                        &
           hirs1b_d%angles(3,3),                        &
           hirs1b_d%angles(1,4),                        &
           hirs1b_d%angles(2,4),                        &
           hirs1b_d%angles(3,4),                        &
           hirs1b_d%angles(1,5),                        &
           hirs1b_d%angles(2,5),                        &
           hirs1b_d%angles(3,5),                        &
           hirs1b_d%angles(1,6),                        &
           hirs1b_d%angles(2,6),                        &
           hirs1b_d%angles(3,6),                        &
           hirs1b_d%angles(1,7),                        &
           hirs1b_d%angles(2,7),                        &
           hirs1b_d%angles(3,7),                        &
           hirs1b_d%angles(1,8),                        &
           hirs1b_d%angles(2,8),                        &
           hirs1b_d%angles(3,8),                        &
           hirs1b_d%angles(1,9),                        &
           hirs1b_d%angles(2,9),                        &
           hirs1b_d%angles(3,9),                        &
           hirs1b_d%angles(1,10),                       &
           hirs1b_d%angles(2,10),                       &
           hirs1b_d%angles(3,10),                       &
           hirs1b_d%angles(1,11),                       &
           hirs1b_d%angles(2,11),                       &
           hirs1b_d%angles(3,11),                       &
           hirs1b_d%angles(1,12),                       &
           hirs1b_d%angles(2,12),                       &
           hirs1b_d%angles(3,12),                       &
           hirs1b_d%angles(1,13),                       &
           hirs1b_d%angles(2,13),                       &
           hirs1b_d%angles(3,13),                       &
           hirs1b_d%angles(1,14),                       &
           hirs1b_d%angles(2,14),                       &
           hirs1b_d%angles(3,14),                       &
           hirs1b_d%angles(1,15),                       &
           hirs1b_d%angles(2,15),                       &
           hirs1b_d%angles(3,15),                       &
           hirs1b_d%angles(1,16),                       &
           hirs1b_d%angles(2,16),                       &
           hirs1b_d%angles(3,16),                       &
           hirs1b_d%angles(1,17),                       &
           hirs1b_d%angles(2,17),                       &
           hirs1b_d%angles(3,17),                       &
           hirs1b_d%angles(1,18),                       &
           hirs1b_d%angles(2,18),                       &
           hirs1b_d%angles(3,18),                       &
           hirs1b_d%angles(1,19),                       &
           hirs1b_d%angles(2,19),                       &
           hirs1b_d%angles(3,19),                       &
           hirs1b_d%angles(1,20),                       &
           hirs1b_d%angles(2,20),                       &
           hirs1b_d%angles(3,20),                       &
           hirs1b_d%angles(1,21),                       &
           hirs1b_d%angles(2,21),                       &
           hirs1b_d%angles(3,21),                       &
           hirs1b_d%angles(1,22),                       &
           hirs1b_d%angles(2,22),                       &
           hirs1b_d%angles(3,22),                       &
           hirs1b_d%angles(1,23),                       &
           hirs1b_d%angles(2,23),                       &
           hirs1b_d%angles(3,23),                       &
           hirs1b_d%angles(1,24),                       &
           hirs1b_d%angles(2,24),                       &
           hirs1b_d%angles(3,24),                       &
           hirs1b_d%angles(1,25),                       &
           hirs1b_d%angles(2,25),                       &
           hirs1b_d%angles(3,25),                       &
           hirs1b_d%angles(1,26),                       &
           hirs1b_d%angles(2,26),                       &
           hirs1b_d%angles(3,26),                       &
           hirs1b_d%angles(1,27),                       &
           hirs1b_d%angles(2,27),                       &
           hirs1b_d%angles(3,27),                       &
           hirs1b_d%angles(1,28),                       &
           hirs1b_d%angles(2,28),                       &
           hirs1b_d%angles(3,28),                       &
           hirs1b_d%angles(1,29),                       &
           hirs1b_d%angles(2,29),                       &
           hirs1b_d%angles(3,29),                       &
           hirs1b_d%angles(1,30),                       &
           hirs1b_d%angles(2,30),                       &
           hirs1b_d%angles(3,30),                       &
           hirs1b_d%angles(1,31),                       &
           hirs1b_d%angles(2,31),                       &
           hirs1b_d%angles(3,31),                       &
           hirs1b_d%angles(1,32),                       &
           hirs1b_d%angles(2,32),                       &
           hirs1b_d%angles(3,32),                       &
           hirs1b_d%angles(1,33),                       &
           hirs1b_d%angles(2,33),                       &
           hirs1b_d%angles(3,33),                       &
           hirs1b_d%angles(1,34),                       &
           hirs1b_d%angles(2,34),                       &
           hirs1b_d%angles(3,34),                       &
           hirs1b_d%angles(1,35),                       &
           hirs1b_d%angles(2,35),                       &
           hirs1b_d%angles(3,35),                       &
           hirs1b_d%angles(1,36),                       &
           hirs1b_d%angles(2,36),                       &
           hirs1b_d%angles(3,36),                       &
           hirs1b_d%angles(1,37),                       &
           hirs1b_d%angles(2,37),                       &
           hirs1b_d%angles(3,37),                       &
           hirs1b_d%angles(1,38),                       &
           hirs1b_d%angles(2,38),                       &
           hirs1b_d%angles(3,38),                       &
           hirs1b_d%angles(1,39),                       &
           hirs1b_d%angles(2,39),                       &
           hirs1b_d%angles(3,39),                       &
           hirs1b_d%angles(1,40),                       &
           hirs1b_d%angles(2,40),                       &
           hirs1b_d%angles(3,40),                       &
           hirs1b_d%angles(1,41),                       &
           hirs1b_d%angles(2,41),                       &
           hirs1b_d%angles(3,41),                       &
           hirs1b_d%angles(1,42),                       &
           hirs1b_d%angles(2,42),                       &
           hirs1b_d%angles(3,42),                       &
           hirs1b_d%angles(1,43),                       &
           hirs1b_d%angles(2,43),                       &
           hirs1b_d%angles(3,43),                       &
           hirs1b_d%angles(1,44),                       &
           hirs1b_d%angles(2,44),                       &
           hirs1b_d%angles(3,44),                       &
           hirs1b_d%angles(1,45),                       &
           hirs1b_d%angles(2,45),                       &
           hirs1b_d%angles(3,45),                       &
           hirs1b_d%angles(1,46),                       &
           hirs1b_d%angles(2,46),                       &
           hirs1b_d%angles(3,46),                       &
           hirs1b_d%angles(1,47),                       &
           hirs1b_d%angles(2,47),                       &
           hirs1b_d%angles(3,47),                       &
           hirs1b_d%angles(1,48),                       &
           hirs1b_d%angles(2,48),                       &
           hirs1b_d%angles(3,48),                       &
           hirs1b_d%angles(1,49),                       &
           hirs1b_d%angles(2,49),                       &
           hirs1b_d%angles(3,49),                       &
           hirs1b_d%angles(1,50),                       &
           hirs1b_d%angles(2,50),                       &
           hirs1b_d%angles(3,50),                       &
           hirs1b_d%angles(1,51),                       &
           hirs1b_d%angles(2,51),                       &
           hirs1b_d%angles(3,51),                       &
           hirs1b_d%angles(1,52),                       &
           hirs1b_d%angles(2,52),                       &
           hirs1b_d%angles(3,52),                       &
           hirs1b_d%angles(1,53),                       &
           hirs1b_d%angles(2,53),                       &
           hirs1b_d%angles(3,53),                       &
           hirs1b_d%angles(1,54),                       &
           hirs1b_d%angles(2,54),                       &
           hirs1b_d%angles(3,54),                       &
           hirs1b_d%angles(1,55),                       &
           hirs1b_d%angles(2,55),                       &
           hirs1b_d%angles(3,55),                       &
           hirs1b_d%angles(1,56),                       &
           hirs1b_d%angles(2,56),                       &
           hirs1b_d%angles(3,56),                       &
           hirs1b_d%location(1,1),                      &
           hirs1b_d%location(2,1),                      &
           hirs1b_d%location(1,2),                      &
           hirs1b_d%location(2,2),                      &
           hirs1b_d%location(1,3),                      &
           hirs1b_d%location(2,3),                      &
           hirs1b_d%location(1,4),                      &
           hirs1b_d%location(2,4),                      &
           hirs1b_d%location(1,5),                      &
           hirs1b_d%location(2,5),                      &
           hirs1b_d%location(1,6),                      &
           hirs1b_d%location(2,6),                      &
           hirs1b_d%location(1,7),                      &
           hirs1b_d%location(2,7),                      &
           hirs1b_d%location(1,8),                      &
           hirs1b_d%location(2,8),                      &
           hirs1b_d%location(1,9),                      &
           hirs1b_d%location(2,9),                      &
           hirs1b_d%location(1,10),                     &
           hirs1b_d%location(2,10),                     &
           hirs1b_d%location(1,11),                     &
           hirs1b_d%location(2,11),                     &
           hirs1b_d%location(1,12),                     &
           hirs1b_d%location(2,12),                     &
           hirs1b_d%location(1,13),                     &
           hirs1b_d%location(2,13),                     &
           hirs1b_d%location(1,14),                     &
           hirs1b_d%location(2,14),                     &
           hirs1b_d%location(1,15),                     &
           hirs1b_d%location(2,15),                     &
           hirs1b_d%location(1,16),                     &
           hirs1b_d%location(2,16),                     &
           hirs1b_d%location(1,17),                     &
           hirs1b_d%location(2,17),                     &
           hirs1b_d%location(1,18),                     &
           hirs1b_d%location(2,18),                     &
           hirs1b_d%location(1,19),                     &
           hirs1b_d%location(2,19),                     &
           hirs1b_d%location(1,20),                     &
           hirs1b_d%location(2,20),                     &
           hirs1b_d%location(1,21),                     &
           hirs1b_d%location(2,21),                     &
           hirs1b_d%location(1,22),                     &
           hirs1b_d%location(2,22),                     &
           hirs1b_d%location(1,23),                     &
           hirs1b_d%location(2,23),                     &
           hirs1b_d%location(1,24),                     &
           hirs1b_d%location(2,24),                     &
           hirs1b_d%location(1,25),                     &
           hirs1b_d%location(2,25),                     &
           hirs1b_d%location(1,26),                     &
           hirs1b_d%location(2,26),                     &
           hirs1b_d%location(1,27),                     &
           hirs1b_d%location(2,27),                     &
           hirs1b_d%location(1,28),                     &
           hirs1b_d%location(2,28),                     &
           hirs1b_d%location(1,29),                     &
           hirs1b_d%location(2,29),                     &
           hirs1b_d%location(1,30),                     &
           hirs1b_d%location(2,30),                     &
           hirs1b_d%location(1,31),                     &
           hirs1b_d%location(2,31),                     &
           hirs1b_d%location(1,32),                     &
           hirs1b_d%location(2,32),                     &
           hirs1b_d%location(1,33),                     &
           hirs1b_d%location(2,33),                     &
           hirs1b_d%location(1,34),                     &
           hirs1b_d%location(2,34),                     &
           hirs1b_d%location(1,35),                     &
           hirs1b_d%location(2,35),                     &
           hirs1b_d%location(1,36),                     &
           hirs1b_d%location(2,36),                     &
           hirs1b_d%location(1,37),                     &
           hirs1b_d%location(2,37),                     &
           hirs1b_d%location(1,38),                     &
           hirs1b_d%location(2,38),                     &
           hirs1b_d%location(1,39),                     &
           hirs1b_d%location(2,39),                     &
           hirs1b_d%location(1,40),                     &
           hirs1b_d%location(2,40),                     &
           hirs1b_d%location(1,41),                     &
           hirs1b_d%location(2,41),                     &
           hirs1b_d%location(1,42),                     &
           hirs1b_d%location(2,42),                     &
           hirs1b_d%location(1,43),                     &
           hirs1b_d%location(2,43),                     &
           hirs1b_d%location(1,44),                     &
           hirs1b_d%location(2,44),                     &
           hirs1b_d%location(1,45),                     &
           hirs1b_d%location(2,45),                     &
           hirs1b_d%location(1,46),                     &
           hirs1b_d%location(2,46),                     &
           hirs1b_d%location(1,47),                     &
           hirs1b_d%location(2,47),                     &
           hirs1b_d%location(1,48),                     &
           hirs1b_d%location(2,48),                     &
           hirs1b_d%location(1,49),                     &
           hirs1b_d%location(2,49),                     &
           hirs1b_d%location(1,50),                     &
           hirs1b_d%location(2,50),                     &
           hirs1b_d%location(1,51),                     &
           hirs1b_d%location(2,51),                     &
           hirs1b_d%location(1,52),                     &
           hirs1b_d%location(2,52),                     &
           hirs1b_d%location(1,53),                     &
           hirs1b_d%location(2,53),                     &
           hirs1b_d%location(1,54),                     &
           hirs1b_d%location(2,54),                     &
           hirs1b_d%location(1,55),                     &
           hirs1b_d%location(2,55),                     &
           hirs1b_d%location(1,56),                     &
           hirs1b_d%location(2,56),                     &
           hirs1b_d%byte1449(1),                        &
           hirs1b_d%byte1449(2),                        &
           hirs1b_d%ele(1)%headElem,                    &
           hirs1b_d%ele(1)%rCount(1),                   &
           hirs1b_d%ele(1)%rCount(2),                   &
           hirs1b_d%ele(1)%rCount(3),                   &
           hirs1b_d%ele(1)%rCount(4),                   &
           hirs1b_d%ele(1)%rCount(5),                   &
           hirs1b_d%ele(1)%rCount(6),                   &
           hirs1b_d%ele(1)%rCount(7),                   &
           hirs1b_d%ele(1)%rCount(8),                   &
           hirs1b_d%ele(1)%rCount(9),                   &
           hirs1b_d%ele(1)%rCount(10),                  &
           hirs1b_d%ele(1)%rCount(11),                  &
           hirs1b_d%ele(1)%rCount(12),                  &
           hirs1b_d%ele(1)%rCount(13),                  &
           hirs1b_d%ele(1)%rCount(14),                  &
           hirs1b_d%ele(1)%rCount(15),                  &
           hirs1b_d%ele(1)%rCount(16),                  &
           hirs1b_d%ele(1)%rCount(17),                  &
           hirs1b_d%ele(1)%rCount(18),                  &
           hirs1b_d%ele(1)%rCount(19),                  &
           hirs1b_d%ele(1)%rCount(20),                  &
           hirs1b_d%ele(1)%flagElem,                    &
           hirs1b_d%ele(1)%zeroFill,                    &
           hirs1b_d%ele(2)%headElem,                    &
           hirs1b_d%ele(2)%rCount(1),                   &
           hirs1b_d%ele(2)%rCount(2),                   &
           hirs1b_d%ele(2)%rCount(3),                   &
           hirs1b_d%ele(2)%rCount(4),                   &
           hirs1b_d%ele(2)%rCount(5),                   &
           hirs1b_d%ele(2)%rCount(6),                   &
           hirs1b_d%ele(2)%rCount(7),                   &
           hirs1b_d%ele(2)%rCount(8),                   &
           hirs1b_d%ele(2)%rCount(9),                   &
           hirs1b_d%ele(2)%rCount(10),                  &
           hirs1b_d%ele(2)%rCount(11),                  &
           hirs1b_d%ele(2)%rCount(12),                  &
           hirs1b_d%ele(2)%rCount(13),                  &
           hirs1b_d%ele(2)%rCount(14),                  &
           hirs1b_d%ele(2)%rCount(15),                  &
           hirs1b_d%ele(2)%rCount(16),                  &
           hirs1b_d%ele(2)%rCount(17),                  &
           hirs1b_d%ele(2)%rCount(18),                  &
           hirs1b_d%ele(2)%rCount(19),                  &
           hirs1b_d%ele(2)%rCount(20),                  &
           hirs1b_d%ele(2)%flagElem,                    &
           hirs1b_d%ele(2)%zeroFill,                    &
           hirs1b_d%ele(3)%headElem,                    &
           hirs1b_d%ele(3)%rCount(1),                   &
           hirs1b_d%ele(3)%rCount(2),                   &
           hirs1b_d%ele(3)%rCount(3),                   &
           hirs1b_d%ele(3)%rCount(4),                   &
           hirs1b_d%ele(3)%rCount(5),                   &
           hirs1b_d%ele(3)%rCount(6),                   &
           hirs1b_d%ele(3)%rCount(7),                   &
           hirs1b_d%ele(3)%rCount(8),                   &
           hirs1b_d%ele(3)%rCount(9),                   &
           hirs1b_d%ele(3)%rCount(10),                  &
           hirs1b_d%ele(3)%rCount(11),                  &
           hirs1b_d%ele(3)%rCount(12),                  &
           hirs1b_d%ele(3)%rCount(13),                  &
           hirs1b_d%ele(3)%rCount(14),                  &
           hirs1b_d%ele(3)%rCount(15),                  &
           hirs1b_d%ele(3)%rCount(16),                  &
           hirs1b_d%ele(3)%rCount(17),                  &
           hirs1b_d%ele(3)%rCount(18),                  &
           hirs1b_d%ele(3)%rCount(19),                  &
           hirs1b_d%ele(3)%rCount(20),                  &
           hirs1b_d%ele(3)%flagElem,                    &
           hirs1b_d%ele(3)%zeroFill,                    &
           hirs1b_d%ele(4)%headElem,                    &
           hirs1b_d%ele(4)%rCount(1),                   &
           hirs1b_d%ele(4)%rCount(2),                   &
           hirs1b_d%ele(4)%rCount(3),                   &
           hirs1b_d%ele(4)%rCount(4),                   &
           hirs1b_d%ele(4)%rCount(5),                   &
           hirs1b_d%ele(4)%rCount(6),                   &
           hirs1b_d%ele(4)%rCount(7),                   &
           hirs1b_d%ele(4)%rCount(8),                   &
           hirs1b_d%ele(4)%rCount(9),                   &
           hirs1b_d%ele(4)%rCount(10),                  &
           hirs1b_d%ele(4)%rCount(11),                  &
           hirs1b_d%ele(4)%rCount(12),                  &
           hirs1b_d%ele(4)%rCount(13),                  &
           hirs1b_d%ele(4)%rCount(14),                  &
           hirs1b_d%ele(4)%rCount(15),                  &
           hirs1b_d%ele(4)%rCount(16),                  &
           hirs1b_d%ele(4)%rCount(17),                  &
           hirs1b_d%ele(4)%rCount(18),                  &
           hirs1b_d%ele(4)%rCount(19),                  &
           hirs1b_d%ele(4)%rCount(20),                  &
           hirs1b_d%ele(4)%flagElem,                    &
           hirs1b_d%ele(4)%zeroFill,                    &
           hirs1b_d%ele(5)%headElem,                    &
           hirs1b_d%ele(5)%rCount(1),                   &
           hirs1b_d%ele(5)%rCount(2),                   &
           hirs1b_d%ele(5)%rCount(3),                   &
           hirs1b_d%ele(5)%rCount(4),                   &
           hirs1b_d%ele(5)%rCount(5),                   &
           hirs1b_d%ele(5)%rCount(6),                   &
           hirs1b_d%ele(5)%rCount(7),                   &
           hirs1b_d%ele(5)%rCount(8),                   &
           hirs1b_d%ele(5)%rCount(9),                   &
           hirs1b_d%ele(5)%rCount(10),                  &
           hirs1b_d%ele(5)%rCount(11),                  &
           hirs1b_d%ele(5)%rCount(12),                  &
           hirs1b_d%ele(5)%rCount(13),                  &
           hirs1b_d%ele(5)%rCount(14),                  &
           hirs1b_d%ele(5)%rCount(15),                  &
           hirs1b_d%ele(5)%rCount(16),                  &
           hirs1b_d%ele(5)%rCount(17),                  &
           hirs1b_d%ele(5)%rCount(18),                  &
           hirs1b_d%ele(5)%rCount(19),                  &
           hirs1b_d%ele(5)%rCount(20),                  &
           hirs1b_d%ele(5)%flagElem,                    &
           hirs1b_d%ele(5)%zeroFill,                    &
           hirs1b_d%ele(6)%headElem,                    &
           hirs1b_d%ele(6)%rCount(1),                   &
           hirs1b_d%ele(6)%rCount(2),                   &
           hirs1b_d%ele(6)%rCount(3),                   &
           hirs1b_d%ele(6)%rCount(4),                   &
           hirs1b_d%ele(6)%rCount(5),                   &
           hirs1b_d%ele(6)%rCount(6),                   &
           hirs1b_d%ele(6)%rCount(7),                   &
           hirs1b_d%ele(6)%rCount(8),                   &
           hirs1b_d%ele(6)%rCount(9),                   &
           hirs1b_d%ele(6)%rCount(10),                  &
           hirs1b_d%ele(6)%rCount(11),                  &
           hirs1b_d%ele(6)%rCount(12),                  &
           hirs1b_d%ele(6)%rCount(13),                  &
           hirs1b_d%ele(6)%rCount(14),                  &
           hirs1b_d%ele(6)%rCount(15),                  &
           hirs1b_d%ele(6)%rCount(16),                  &
           hirs1b_d%ele(6)%rCount(17),                  &
           hirs1b_d%ele(6)%rCount(18),                  &
           hirs1b_d%ele(6)%rCount(19),                  &
           hirs1b_d%ele(6)%rCount(20),                  &
           hirs1b_d%ele(6)%flagElem,                    &
           hirs1b_d%ele(6)%zeroFill,                    &
           hirs1b_d%ele(7)%headElem,                    &
           hirs1b_d%ele(7)%rCount(1),                   &
           hirs1b_d%ele(7)%rCount(2),                   &
           hirs1b_d%ele(7)%rCount(3),                   &
           hirs1b_d%ele(7)%rCount(4),                   &
           hirs1b_d%ele(7)%rCount(5),                   &
           hirs1b_d%ele(7)%rCount(6),                   &
           hirs1b_d%ele(7)%rCount(7),                   &
           hirs1b_d%ele(7)%rCount(8),                   &
           hirs1b_d%ele(7)%rCount(9),                   &
           hirs1b_d%ele(7)%rCount(10),                  &
           hirs1b_d%ele(7)%rCount(11),                  &
           hirs1b_d%ele(7)%rCount(12),                  &
           hirs1b_d%ele(7)%rCount(13),                  &
           hirs1b_d%ele(7)%rCount(14),                  &
           hirs1b_d%ele(7)%rCount(15),                  &
           hirs1b_d%ele(7)%rCount(16),                  &
           hirs1b_d%ele(7)%rCount(17),                  &
           hirs1b_d%ele(7)%rCount(18),                  &
           hirs1b_d%ele(7)%rCount(19),                  &
           hirs1b_d%ele(7)%rCount(20),                  &
           hirs1b_d%ele(7)%flagElem,                    &
           hirs1b_d%ele(7)%zeroFill,                    &
           hirs1b_d%ele(8)%headElem,                    &
           hirs1b_d%ele(8)%rCount(1),                   &
           hirs1b_d%ele(8)%rCount(2),                   &
           hirs1b_d%ele(8)%rCount(3),                   &
           hirs1b_d%ele(8)%rCount(4),                   &
           hirs1b_d%ele(8)%rCount(5),                   &
           hirs1b_d%ele(8)%rCount(6),                   &
           hirs1b_d%ele(8)%rCount(7),                   &
           hirs1b_d%ele(8)%rCount(8),                   &
           hirs1b_d%ele(8)%rCount(9),                   &
           hirs1b_d%ele(8)%rCount(10),                  &
           hirs1b_d%ele(8)%rCount(11),                  &
           hirs1b_d%ele(8)%rCount(12),                  &
           hirs1b_d%ele(8)%rCount(13),                  &
           hirs1b_d%ele(8)%rCount(14),                  &
           hirs1b_d%ele(8)%rCount(15),                  &
           hirs1b_d%ele(8)%rCount(16),                  &
           hirs1b_d%ele(8)%rCount(17),                  &
           hirs1b_d%ele(8)%rCount(18),                  &
           hirs1b_d%ele(8)%rCount(19),                  &
           hirs1b_d%ele(8)%rCount(20),                  &
           hirs1b_d%ele(8)%flagElem,                    &
           hirs1b_d%ele(8)%zeroFill,                    &
           hirs1b_d%ele(9)%headElem,                    &
           hirs1b_d%ele(9)%rCount(1),                   &
           hirs1b_d%ele(9)%rCount(2),                   &
           hirs1b_d%ele(9)%rCount(3),                   &
           hirs1b_d%ele(9)%rCount(4),                   &
           hirs1b_d%ele(9)%rCount(5),                   &
           hirs1b_d%ele(9)%rCount(6),                   &
           hirs1b_d%ele(9)%rCount(7),                   &
           hirs1b_d%ele(9)%rCount(8),                   &
           hirs1b_d%ele(9)%rCount(9),                   &
           hirs1b_d%ele(9)%rCount(10),                  &
           hirs1b_d%ele(9)%rCount(11),                  &
           hirs1b_d%ele(9)%rCount(12),                  &
           hirs1b_d%ele(9)%rCount(13),                  &
           hirs1b_d%ele(9)%rCount(14),                  &
           hirs1b_d%ele(9)%rCount(15),                  &
           hirs1b_d%ele(9)%rCount(16),                  &
           hirs1b_d%ele(9)%rCount(17),                  &
           hirs1b_d%ele(9)%rCount(18),                  &
           hirs1b_d%ele(9)%rCount(19),                  &
           hirs1b_d%ele(9)%rCount(20),                  &
           hirs1b_d%ele(9)%flagElem,                    &
           hirs1b_d%ele(9)%zeroFill,                    &
           hirs1b_d%ele(10)%headElem,                   &
           hirs1b_d%ele(10)%rCount(1),                  &
           hirs1b_d%ele(10)%rCount(2),                  &
           hirs1b_d%ele(10)%rCount(3),                  &
           hirs1b_d%ele(10)%rCount(4),                  &
           hirs1b_d%ele(10)%rCount(5),                  &
           hirs1b_d%ele(10)%rCount(6),                  &
           hirs1b_d%ele(10)%rCount(7),                  &
           hirs1b_d%ele(10)%rCount(8),                  &
           hirs1b_d%ele(10)%rCount(9),                  &
           hirs1b_d%ele(10)%rCount(10),                 &
           hirs1b_d%ele(10)%rCount(11),                 &
           hirs1b_d%ele(10)%rCount(12),                 &
           hirs1b_d%ele(10)%rCount(13),                 &
           hirs1b_d%ele(10)%rCount(14),                 &
           hirs1b_d%ele(10)%rCount(15),                 &
           hirs1b_d%ele(10)%rCount(16),                 &
           hirs1b_d%ele(10)%rCount(17),                 &
           hirs1b_d%ele(10)%rCount(18),                 &
           hirs1b_d%ele(10)%rCount(19),                 &
           hirs1b_d%ele(10)%rCount(20),                 &
           hirs1b_d%ele(10)%flagElem,                   &
           hirs1b_d%ele(10)%zeroFill,                   &
           hirs1b_d%ele(11)%headElem,                   &
           hirs1b_d%ele(11)%rCount(1),                  &
           hirs1b_d%ele(11)%rCount(2),                  &
           hirs1b_d%ele(11)%rCount(3),                  &
           hirs1b_d%ele(11)%rCount(4),                  &
           hirs1b_d%ele(11)%rCount(5),                  &
           hirs1b_d%ele(11)%rCount(6),                  &
           hirs1b_d%ele(11)%rCount(7),                  &
           hirs1b_d%ele(11)%rCount(8),                  &
           hirs1b_d%ele(11)%rCount(9),                  &
           hirs1b_d%ele(11)%rCount(10),                 &
           hirs1b_d%ele(11)%rCount(11),                 &
           hirs1b_d%ele(11)%rCount(12),                 &
           hirs1b_d%ele(11)%rCount(13),                 &
           hirs1b_d%ele(11)%rCount(14),                 &
           hirs1b_d%ele(11)%rCount(15),                 &
           hirs1b_d%ele(11)%rCount(16),                 &
           hirs1b_d%ele(11)%rCount(17),                 &
           hirs1b_d%ele(11)%rCount(18),                 &
           hirs1b_d%ele(11)%rCount(19),                 &
           hirs1b_d%ele(11)%rCount(20),                 &
           hirs1b_d%ele(11)%flagElem,                   &
           hirs1b_d%ele(11)%zeroFill,                   &
           hirs1b_d%ele(12)%headElem,                   &
           hirs1b_d%ele(12)%rCount(1),                  &
           hirs1b_d%ele(12)%rCount(2),                  &
           hirs1b_d%ele(12)%rCount(3),                  &
           hirs1b_d%ele(12)%rCount(4),                  &
           hirs1b_d%ele(12)%rCount(5),                  &
           hirs1b_d%ele(12)%rCount(6),                  &
           hirs1b_d%ele(12)%rCount(7),                  &
           hirs1b_d%ele(12)%rCount(8),                  &
           hirs1b_d%ele(12)%rCount(9),                  &
           hirs1b_d%ele(12)%rCount(10),                 &
           hirs1b_d%ele(12)%rCount(11),                 &
           hirs1b_d%ele(12)%rCount(12),                 &
           hirs1b_d%ele(12)%rCount(13),                 &
           hirs1b_d%ele(12)%rCount(14),                 &
           hirs1b_d%ele(12)%rCount(15),                 &
           hirs1b_d%ele(12)%rCount(16),                 &
           hirs1b_d%ele(12)%rCount(17),                 &
           hirs1b_d%ele(12)%rCount(18),                 &
           hirs1b_d%ele(12)%rCount(19),                 &
           hirs1b_d%ele(12)%rCount(20),                 &
           hirs1b_d%ele(12)%flagElem,                   &
           hirs1b_d%ele(12)%zeroFill,                   &
           hirs1b_d%ele(13)%headElem,                   &
           hirs1b_d%ele(13)%rCount(1),                  &
           hirs1b_d%ele(13)%rCount(2),                  &
           hirs1b_d%ele(13)%rCount(3),                  &
           hirs1b_d%ele(13)%rCount(4),                  &
           hirs1b_d%ele(13)%rCount(5),                  &
           hirs1b_d%ele(13)%rCount(6),                  &
           hirs1b_d%ele(13)%rCount(7),                  &
           hirs1b_d%ele(13)%rCount(8),                  &
           hirs1b_d%ele(13)%rCount(9),                  &
           hirs1b_d%ele(13)%rCount(10),                 &
           hirs1b_d%ele(13)%rCount(11),                 &
           hirs1b_d%ele(13)%rCount(12),                 &
           hirs1b_d%ele(13)%rCount(13),                 &
           hirs1b_d%ele(13)%rCount(14),                 &
           hirs1b_d%ele(13)%rCount(15),                 &
           hirs1b_d%ele(13)%rCount(16),                 &
           hirs1b_d%ele(13)%rCount(17),                 &
           hirs1b_d%ele(13)%rCount(18),                 &
           hirs1b_d%ele(13)%rCount(19),                 &
           hirs1b_d%ele(13)%rCount(20),                 &
           hirs1b_d%ele(13)%flagElem,                   &
           hirs1b_d%ele(13)%zeroFill,                   &
           hirs1b_d%ele(14)%headElem,                   &
           hirs1b_d%ele(14)%rCount(1),                  &
           hirs1b_d%ele(14)%rCount(2),                  &
           hirs1b_d%ele(14)%rCount(3),                  &
           hirs1b_d%ele(14)%rCount(4),                  &
           hirs1b_d%ele(14)%rCount(5),                  &
           hirs1b_d%ele(14)%rCount(6),                  &
           hirs1b_d%ele(14)%rCount(7),                  &
           hirs1b_d%ele(14)%rCount(8),                  &
           hirs1b_d%ele(14)%rCount(9),                  &
           hirs1b_d%ele(14)%rCount(10),                 &
           hirs1b_d%ele(14)%rCount(11),                 &
           hirs1b_d%ele(14)%rCount(12),                 &
           hirs1b_d%ele(14)%rCount(13),                 &
           hirs1b_d%ele(14)%rCount(14),                 &
           hirs1b_d%ele(14)%rCount(15),                 &
           hirs1b_d%ele(14)%rCount(16),                 &
           hirs1b_d%ele(14)%rCount(17),                 &
           hirs1b_d%ele(14)%rCount(18),                 &
           hirs1b_d%ele(14)%rCount(19),                 &
           hirs1b_d%ele(14)%rCount(20),                 &
           hirs1b_d%ele(14)%flagElem,                   &
           hirs1b_d%ele(14)%zeroFill,                   &
           hirs1b_d%ele(15)%headElem,                   &
           hirs1b_d%ele(15)%rCount(1),                  &
           hirs1b_d%ele(15)%rCount(2),                  &
           hirs1b_d%ele(15)%rCount(3),                  &
           hirs1b_d%ele(15)%rCount(4),                  &
           hirs1b_d%ele(15)%rCount(5),                  &
           hirs1b_d%ele(15)%rCount(6),                  &
           hirs1b_d%ele(15)%rCount(7),                  &
           hirs1b_d%ele(15)%rCount(8),                  &
           hirs1b_d%ele(15)%rCount(9),                  &
           hirs1b_d%ele(15)%rCount(10),                 &
           hirs1b_d%ele(15)%rCount(11),                 &
           hirs1b_d%ele(15)%rCount(12),                 &
           hirs1b_d%ele(15)%rCount(13),                 &
           hirs1b_d%ele(15)%rCount(14),                 &
           hirs1b_d%ele(15)%rCount(15),                 &
           hirs1b_d%ele(15)%rCount(16),                 &
           hirs1b_d%ele(15)%rCount(17),                 &
           hirs1b_d%ele(15)%rCount(18),                 &
           hirs1b_d%ele(15)%rCount(19),                 &
           hirs1b_d%ele(15)%rCount(20),                 &
           hirs1b_d%ele(15)%flagElem,                   &
           hirs1b_d%ele(15)%zeroFill,                   &
           hirs1b_d%ele(16)%headElem,                   &
           hirs1b_d%ele(16)%rCount(1),                  &
           hirs1b_d%ele(16)%rCount(2),                  &
           hirs1b_d%ele(16)%rCount(3),                  &
           hirs1b_d%ele(16)%rCount(4),                  &
           hirs1b_d%ele(16)%rCount(5),                  &
           hirs1b_d%ele(16)%rCount(6),                  &
           hirs1b_d%ele(16)%rCount(7),                  &
           hirs1b_d%ele(16)%rCount(8),                  &
           hirs1b_d%ele(16)%rCount(9),                  &
           hirs1b_d%ele(16)%rCount(10),                 &
           hirs1b_d%ele(16)%rCount(11),                 &
           hirs1b_d%ele(16)%rCount(12),                 &
           hirs1b_d%ele(16)%rCount(13),                 &
           hirs1b_d%ele(16)%rCount(14),                 &
           hirs1b_d%ele(16)%rCount(15),                 &
           hirs1b_d%ele(16)%rCount(16),                 &
           hirs1b_d%ele(16)%rCount(17),                 &
           hirs1b_d%ele(16)%rCount(18),                 &
           hirs1b_d%ele(16)%rCount(19),                 &
           hirs1b_d%ele(16)%rCount(20),                 &
           hirs1b_d%ele(16)%flagElem,                   &
           hirs1b_d%ele(16)%zeroFill,                   &
           hirs1b_d%ele(17)%headElem,                   &
           hirs1b_d%ele(17)%rCount(1),                  &
           hirs1b_d%ele(17)%rCount(2),                  &
           hirs1b_d%ele(17)%rCount(3),                  &
           hirs1b_d%ele(17)%rCount(4),                  &
           hirs1b_d%ele(17)%rCount(5),                  &
           hirs1b_d%ele(17)%rCount(6),                  &
           hirs1b_d%ele(17)%rCount(7),                  &
           hirs1b_d%ele(17)%rCount(8),                  &
           hirs1b_d%ele(17)%rCount(9),                  &
           hirs1b_d%ele(17)%rCount(10),                 &
           hirs1b_d%ele(17)%rCount(11),                 &
           hirs1b_d%ele(17)%rCount(12),                 &
           hirs1b_d%ele(17)%rCount(13),                 &
           hirs1b_d%ele(17)%rCount(14),                 &
           hirs1b_d%ele(17)%rCount(15),                 &
           hirs1b_d%ele(17)%rCount(16),                 &
           hirs1b_d%ele(17)%rCount(17),                 &
           hirs1b_d%ele(17)%rCount(18),                 &
           hirs1b_d%ele(17)%rCount(19),                 &
           hirs1b_d%ele(17)%rCount(20),                 &
           hirs1b_d%ele(17)%flagElem,                   &
           hirs1b_d%ele(17)%zeroFill,                   &
           hirs1b_d%ele(18)%headElem,                   &
           hirs1b_d%ele(18)%rCount(1),                  &
           hirs1b_d%ele(18)%rCount(2),                  &
           hirs1b_d%ele(18)%rCount(3),                  &
           hirs1b_d%ele(18)%rCount(4),                  &
           hirs1b_d%ele(18)%rCount(5),                  &
           hirs1b_d%ele(18)%rCount(6),                  &
           hirs1b_d%ele(18)%rCount(7),                  &
           hirs1b_d%ele(18)%rCount(8),                  &
           hirs1b_d%ele(18)%rCount(9),                  &
           hirs1b_d%ele(18)%rCount(10),                 &
           hirs1b_d%ele(18)%rCount(11),                 &
           hirs1b_d%ele(18)%rCount(12),                 &
           hirs1b_d%ele(18)%rCount(13),                 &
           hirs1b_d%ele(18)%rCount(14),                 &
           hirs1b_d%ele(18)%rCount(15),                 &
           hirs1b_d%ele(18)%rCount(16),                 &
           hirs1b_d%ele(18)%rCount(17),                 &
           hirs1b_d%ele(18)%rCount(18),                 &
           hirs1b_d%ele(18)%rCount(19),                 &
           hirs1b_d%ele(18)%rCount(20),                 &
           hirs1b_d%ele(18)%flagElem,                   &
           hirs1b_d%ele(18)%zeroFill,                   &
           hirs1b_d%ele(19)%headElem,                   &
           hirs1b_d%ele(19)%rCount(1),                  &
           hirs1b_d%ele(19)%rCount(2),                  &
           hirs1b_d%ele(19)%rCount(3),                  &
           hirs1b_d%ele(19)%rCount(4),                  &
           hirs1b_d%ele(19)%rCount(5),                  &
           hirs1b_d%ele(19)%rCount(6),                  &
           hirs1b_d%ele(19)%rCount(7),                  &
           hirs1b_d%ele(19)%rCount(8),                  &
           hirs1b_d%ele(19)%rCount(9),                  &
           hirs1b_d%ele(19)%rCount(10),                 &
           hirs1b_d%ele(19)%rCount(11),                 &
           hirs1b_d%ele(19)%rCount(12),                 &
           hirs1b_d%ele(19)%rCount(13),                 &
           hirs1b_d%ele(19)%rCount(14),                 &
           hirs1b_d%ele(19)%rCount(15),                 &
           hirs1b_d%ele(19)%rCount(16),                 &
           hirs1b_d%ele(19)%rCount(17),                 &
           hirs1b_d%ele(19)%rCount(18),                 &
           hirs1b_d%ele(19)%rCount(19),                 &
           hirs1b_d%ele(19)%rCount(20),                 &
           hirs1b_d%ele(19)%flagElem,                   &
           hirs1b_d%ele(19)%zeroFill,                   &
           hirs1b_d%ele(20)%headElem,                   &
           hirs1b_d%ele(20)%rCount(1),                  &
           hirs1b_d%ele(20)%rCount(2),                  &
           hirs1b_d%ele(20)%rCount(3),                  &
           hirs1b_d%ele(20)%rCount(4),                  &
           hirs1b_d%ele(20)%rCount(5),                  &
           hirs1b_d%ele(20)%rCount(6),                  &
           hirs1b_d%ele(20)%rCount(7),                  &
           hirs1b_d%ele(20)%rCount(8),                  &
           hirs1b_d%ele(20)%rCount(9),                  &
           hirs1b_d%ele(20)%rCount(10),                 &
           hirs1b_d%ele(20)%rCount(11),                 &
           hirs1b_d%ele(20)%rCount(12),                 &
           hirs1b_d%ele(20)%rCount(13),                 &
           hirs1b_d%ele(20)%rCount(14),                 &
           hirs1b_d%ele(20)%rCount(15),                 &
           hirs1b_d%ele(20)%rCount(16),                 &
           hirs1b_d%ele(20)%rCount(17),                 &
           hirs1b_d%ele(20)%rCount(18),                 &
           hirs1b_d%ele(20)%rCount(19),                 &
           hirs1b_d%ele(20)%rCount(20),                 &
           hirs1b_d%ele(20)%flagElem,                   &
           hirs1b_d%ele(20)%zeroFill,                   &
           hirs1b_d%ele(21)%headElem,                   &
           hirs1b_d%ele(21)%rCount(1),                  &
           hirs1b_d%ele(21)%rCount(2),                  &
           hirs1b_d%ele(21)%rCount(3),                  &
           hirs1b_d%ele(21)%rCount(4),                  &
           hirs1b_d%ele(21)%rCount(5),                  &
           hirs1b_d%ele(21)%rCount(6),                  &
           hirs1b_d%ele(21)%rCount(7),                  &
           hirs1b_d%ele(21)%rCount(8),                  &
           hirs1b_d%ele(21)%rCount(9),                  &
           hirs1b_d%ele(21)%rCount(10),                 &
           hirs1b_d%ele(21)%rCount(11),                 &
           hirs1b_d%ele(21)%rCount(12),                 &
           hirs1b_d%ele(21)%rCount(13),                 &
           hirs1b_d%ele(21)%rCount(14),                 &
           hirs1b_d%ele(21)%rCount(15),                 &
           hirs1b_d%ele(21)%rCount(16),                 &
           hirs1b_d%ele(21)%rCount(17),                 &
           hirs1b_d%ele(21)%rCount(18),                 &
           hirs1b_d%ele(21)%rCount(19),                 &
           hirs1b_d%ele(21)%rCount(20),                 &
           hirs1b_d%ele(21)%flagElem,                   &
           hirs1b_d%ele(21)%zeroFill,                   &
           hirs1b_d%ele(22)%headElem,                   &
           hirs1b_d%ele(22)%rCount(1),                  &
           hirs1b_d%ele(22)%rCount(2),                  &
           hirs1b_d%ele(22)%rCount(3),                  &
           hirs1b_d%ele(22)%rCount(4),                  &
           hirs1b_d%ele(22)%rCount(5),                  &
           hirs1b_d%ele(22)%rCount(6),                  &
           hirs1b_d%ele(22)%rCount(7),                  &
           hirs1b_d%ele(22)%rCount(8),                  &
           hirs1b_d%ele(22)%rCount(9),                  &
           hirs1b_d%ele(22)%rCount(10),                 &
           hirs1b_d%ele(22)%rCount(11),                 &
           hirs1b_d%ele(22)%rCount(12),                 &
           hirs1b_d%ele(22)%rCount(13),                 &
           hirs1b_d%ele(22)%rCount(14),                 &
           hirs1b_d%ele(22)%rCount(15),                 &
           hirs1b_d%ele(22)%rCount(16),                 &
           hirs1b_d%ele(22)%rCount(17),                 &
           hirs1b_d%ele(22)%rCount(18),                 &
           hirs1b_d%ele(22)%rCount(19),                 &
           hirs1b_d%ele(22)%rCount(20),                 &
           hirs1b_d%ele(22)%flagElem,                   &
           hirs1b_d%ele(22)%zeroFill,                   &
           hirs1b_d%ele(23)%headElem,                   &
           hirs1b_d%ele(23)%rCount(1),                  &
           hirs1b_d%ele(23)%rCount(2),                  &
           hirs1b_d%ele(23)%rCount(3),                  &
           hirs1b_d%ele(23)%rCount(4),                  &
           hirs1b_d%ele(23)%rCount(5),                  &
           hirs1b_d%ele(23)%rCount(6),                  &
           hirs1b_d%ele(23)%rCount(7),                  &
           hirs1b_d%ele(23)%rCount(8),                  &
           hirs1b_d%ele(23)%rCount(9),                  &
           hirs1b_d%ele(23)%rCount(10),                 &
           hirs1b_d%ele(23)%rCount(11),                 &
           hirs1b_d%ele(23)%rCount(12),                 &
           hirs1b_d%ele(23)%rCount(13),                 &
           hirs1b_d%ele(23)%rCount(14),                 &
           hirs1b_d%ele(23)%rCount(15),                 &
           hirs1b_d%ele(23)%rCount(16),                 &
           hirs1b_d%ele(23)%rCount(17),                 &
           hirs1b_d%ele(23)%rCount(18),                 &
           hirs1b_d%ele(23)%rCount(19),                 &
           hirs1b_d%ele(23)%rCount(20),                 &
           hirs1b_d%ele(23)%flagElem,                   &
           hirs1b_d%ele(23)%zeroFill,                   &
           hirs1b_d%ele(24)%headElem,                   &
           hirs1b_d%ele(24)%rCount(1),                  &
           hirs1b_d%ele(24)%rCount(2),                  &
           hirs1b_d%ele(24)%rCount(3),                  &
           hirs1b_d%ele(24)%rCount(4),                  &
           hirs1b_d%ele(24)%rCount(5),                  &
           hirs1b_d%ele(24)%rCount(6),                  &
           hirs1b_d%ele(24)%rCount(7),                  &
           hirs1b_d%ele(24)%rCount(8),                  &
           hirs1b_d%ele(24)%rCount(9),                  &
           hirs1b_d%ele(24)%rCount(10),                 &
           hirs1b_d%ele(24)%rCount(11),                 &
           hirs1b_d%ele(24)%rCount(12),                 &
           hirs1b_d%ele(24)%rCount(13),                 &
           hirs1b_d%ele(24)%rCount(14),                 &
           hirs1b_d%ele(24)%rCount(15),                 &
           hirs1b_d%ele(24)%rCount(16),                 &
           hirs1b_d%ele(24)%rCount(17),                 &
           hirs1b_d%ele(24)%rCount(18),                 &
           hirs1b_d%ele(24)%rCount(19),                 &
           hirs1b_d%ele(24)%rCount(20),                 &
           hirs1b_d%ele(24)%flagElem,                   &
           hirs1b_d%ele(24)%zeroFill,                   &
           hirs1b_d%ele(25)%headElem,                   &
           hirs1b_d%ele(25)%rCount(1),                  &
           hirs1b_d%ele(25)%rCount(2),                  &
           hirs1b_d%ele(25)%rCount(3),                  &
           hirs1b_d%ele(25)%rCount(4),                  &
           hirs1b_d%ele(25)%rCount(5),                  &
           hirs1b_d%ele(25)%rCount(6),                  &
           hirs1b_d%ele(25)%rCount(7),                  &
           hirs1b_d%ele(25)%rCount(8),                  &
           hirs1b_d%ele(25)%rCount(9),                  &
           hirs1b_d%ele(25)%rCount(10),                 &
           hirs1b_d%ele(25)%rCount(11),                 &
           hirs1b_d%ele(25)%rCount(12),                 &
           hirs1b_d%ele(25)%rCount(13),                 &
           hirs1b_d%ele(25)%rCount(14),                 &
           hirs1b_d%ele(25)%rCount(15),                 &
           hirs1b_d%ele(25)%rCount(16),                 &
           hirs1b_d%ele(25)%rCount(17),                 &
           hirs1b_d%ele(25)%rCount(18),                 &
           hirs1b_d%ele(25)%rCount(19),                 &
           hirs1b_d%ele(25)%rCount(20),                 &
           hirs1b_d%ele(25)%flagElem,                   &
           hirs1b_d%ele(25)%zeroFill,                   &
           hirs1b_d%ele(26)%headElem,                   &
           hirs1b_d%ele(26)%rCount(1),                  &
           hirs1b_d%ele(26)%rCount(2),                  &
           hirs1b_d%ele(26)%rCount(3),                  &
           hirs1b_d%ele(26)%rCount(4),                  &
           hirs1b_d%ele(26)%rCount(5),                  &
           hirs1b_d%ele(26)%rCount(6),                  &
           hirs1b_d%ele(26)%rCount(7),                  &
           hirs1b_d%ele(26)%rCount(8),                  &
           hirs1b_d%ele(26)%rCount(9),                  &
           hirs1b_d%ele(26)%rCount(10),                 &
           hirs1b_d%ele(26)%rCount(11),                 &
           hirs1b_d%ele(26)%rCount(12),                 &
           hirs1b_d%ele(26)%rCount(13),                 &
           hirs1b_d%ele(26)%rCount(14),                 &
           hirs1b_d%ele(26)%rCount(15),                 &
           hirs1b_d%ele(26)%rCount(16),                 &
           hirs1b_d%ele(26)%rCount(17),                 &
           hirs1b_d%ele(26)%rCount(18),                 &
           hirs1b_d%ele(26)%rCount(19),                 &
           hirs1b_d%ele(26)%rCount(20),                 &
           hirs1b_d%ele(26)%flagElem,                   &
           hirs1b_d%ele(26)%zeroFill,                   &
           hirs1b_d%ele(27)%headElem,                   &
           hirs1b_d%ele(27)%rCount(1),                  &
           hirs1b_d%ele(27)%rCount(2),                  &
           hirs1b_d%ele(27)%rCount(3),                  &
           hirs1b_d%ele(27)%rCount(4),                  &
           hirs1b_d%ele(27)%rCount(5),                  &
           hirs1b_d%ele(27)%rCount(6),                  &
           hirs1b_d%ele(27)%rCount(7),                  &
           hirs1b_d%ele(27)%rCount(8),                  &
           hirs1b_d%ele(27)%rCount(9),                  &
           hirs1b_d%ele(27)%rCount(10),                 &
           hirs1b_d%ele(27)%rCount(11),                 &
           hirs1b_d%ele(27)%rCount(12),                 &
           hirs1b_d%ele(27)%rCount(13),                 &
           hirs1b_d%ele(27)%rCount(14),                 &
           hirs1b_d%ele(27)%rCount(15),                 &
           hirs1b_d%ele(27)%rCount(16),                 &
           hirs1b_d%ele(27)%rCount(17),                 &
           hirs1b_d%ele(27)%rCount(18),                 &
           hirs1b_d%ele(27)%rCount(19),                 &
           hirs1b_d%ele(27)%rCount(20),                 &
           hirs1b_d%ele(27)%flagElem,                   &
           hirs1b_d%ele(27)%zeroFill,                   &
           hirs1b_d%ele(28)%headElem,                   &
           hirs1b_d%ele(28)%rCount(1),                  &
           hirs1b_d%ele(28)%rCount(2),                  &
           hirs1b_d%ele(28)%rCount(3),                  &
           hirs1b_d%ele(28)%rCount(4),                  &
           hirs1b_d%ele(28)%rCount(5),                  &
           hirs1b_d%ele(28)%rCount(6),                  &
           hirs1b_d%ele(28)%rCount(7),                  &
           hirs1b_d%ele(28)%rCount(8),                  &
           hirs1b_d%ele(28)%rCount(9),                  &
           hirs1b_d%ele(28)%rCount(10),                 &
           hirs1b_d%ele(28)%rCount(11),                 &
           hirs1b_d%ele(28)%rCount(12),                 &
           hirs1b_d%ele(28)%rCount(13),                 &
           hirs1b_d%ele(28)%rCount(14),                 &
           hirs1b_d%ele(28)%rCount(15),                 &
           hirs1b_d%ele(28)%rCount(16),                 &
           hirs1b_d%ele(28)%rCount(17),                 &
           hirs1b_d%ele(28)%rCount(18),                 &
           hirs1b_d%ele(28)%rCount(19),                 &
           hirs1b_d%ele(28)%rCount(20),                 &
           hirs1b_d%ele(28)%flagElem,                   &
           hirs1b_d%ele(28)%zeroFill,                   &
           hirs1b_d%ele(29)%headElem,                   &
           hirs1b_d%ele(29)%rCount(1),                  &
           hirs1b_d%ele(29)%rCount(2),                  &
           hirs1b_d%ele(29)%rCount(3),                  &
           hirs1b_d%ele(29)%rCount(4),                  &
           hirs1b_d%ele(29)%rCount(5),                  &
           hirs1b_d%ele(29)%rCount(6),                  &
           hirs1b_d%ele(29)%rCount(7),                  &
           hirs1b_d%ele(29)%rCount(8),                  &
           hirs1b_d%ele(29)%rCount(9),                  &
           hirs1b_d%ele(29)%rCount(10),                 &
           hirs1b_d%ele(29)%rCount(11),                 &
           hirs1b_d%ele(29)%rCount(12),                 &
           hirs1b_d%ele(29)%rCount(13),                 &
           hirs1b_d%ele(29)%rCount(14),                 &
           hirs1b_d%ele(29)%rCount(15),                 &
           hirs1b_d%ele(29)%rCount(16),                 &
           hirs1b_d%ele(29)%rCount(17),                 &
           hirs1b_d%ele(29)%rCount(18),                 &
           hirs1b_d%ele(29)%rCount(19),                 &
           hirs1b_d%ele(29)%rCount(20),                 &
           hirs1b_d%ele(29)%flagElem,                   &
           hirs1b_d%ele(29)%zeroFill,                   &
           hirs1b_d%ele(30)%headElem,                   &
           hirs1b_d%ele(30)%rCount(1),                  &
           hirs1b_d%ele(30)%rCount(2),                  &
           hirs1b_d%ele(30)%rCount(3),                  &
           hirs1b_d%ele(30)%rCount(4),                  &
           hirs1b_d%ele(30)%rCount(5),                  &
           hirs1b_d%ele(30)%rCount(6),                  &
           hirs1b_d%ele(30)%rCount(7),                  &
           hirs1b_d%ele(30)%rCount(8),                  &
           hirs1b_d%ele(30)%rCount(9),                  &
           hirs1b_d%ele(30)%rCount(10),                 &
           hirs1b_d%ele(30)%rCount(11),                 &
           hirs1b_d%ele(30)%rCount(12),                 &
           hirs1b_d%ele(30)%rCount(13),                 &
           hirs1b_d%ele(30)%rCount(14),                 &
           hirs1b_d%ele(30)%rCount(15),                 &
           hirs1b_d%ele(30)%rCount(16),                 &
           hirs1b_d%ele(30)%rCount(17),                 &
           hirs1b_d%ele(30)%rCount(18),                 &
           hirs1b_d%ele(30)%rCount(19),                 &
           hirs1b_d%ele(30)%rCount(20),                 &
           hirs1b_d%ele(30)%flagElem,                   &
           hirs1b_d%ele(30)%zeroFill,                   &
           hirs1b_d%ele(31)%headElem,                   &
           hirs1b_d%ele(31)%rCount(1),                  &
           hirs1b_d%ele(31)%rCount(2),                  &
           hirs1b_d%ele(31)%rCount(3),                  &
           hirs1b_d%ele(31)%rCount(4),                  &
           hirs1b_d%ele(31)%rCount(5),                  &
           hirs1b_d%ele(31)%rCount(6),                  &
           hirs1b_d%ele(31)%rCount(7),                  &
           hirs1b_d%ele(31)%rCount(8),                  &
           hirs1b_d%ele(31)%rCount(9),                  &
           hirs1b_d%ele(31)%rCount(10),                 &
           hirs1b_d%ele(31)%rCount(11),                 &
           hirs1b_d%ele(31)%rCount(12),                 &
           hirs1b_d%ele(31)%rCount(13),                 &
           hirs1b_d%ele(31)%rCount(14),                 &
           hirs1b_d%ele(31)%rCount(15),                 &
           hirs1b_d%ele(31)%rCount(16),                 &
           hirs1b_d%ele(31)%rCount(17),                 &
           hirs1b_d%ele(31)%rCount(18),                 &
           hirs1b_d%ele(31)%rCount(19),                 &
           hirs1b_d%ele(31)%rCount(20),                 &
           hirs1b_d%ele(31)%flagElem,                   &
           hirs1b_d%ele(31)%zeroFill,                   &
           hirs1b_d%ele(32)%headElem,                   &
           hirs1b_d%ele(32)%rCount(1),                  &
           hirs1b_d%ele(32)%rCount(2),                  &
           hirs1b_d%ele(32)%rCount(3),                  &
           hirs1b_d%ele(32)%rCount(4),                  &
           hirs1b_d%ele(32)%rCount(5),                  &
           hirs1b_d%ele(32)%rCount(6),                  &
           hirs1b_d%ele(32)%rCount(7),                  &
           hirs1b_d%ele(32)%rCount(8),                  &
           hirs1b_d%ele(32)%rCount(9),                  &
           hirs1b_d%ele(32)%rCount(10),                 &
           hirs1b_d%ele(32)%rCount(11),                 &
           hirs1b_d%ele(32)%rCount(12),                 &
           hirs1b_d%ele(32)%rCount(13),                 &
           hirs1b_d%ele(32)%rCount(14),                 &
           hirs1b_d%ele(32)%rCount(15),                 &
           hirs1b_d%ele(32)%rCount(16),                 &
           hirs1b_d%ele(32)%rCount(17),                 &
           hirs1b_d%ele(32)%rCount(18),                 &
           hirs1b_d%ele(32)%rCount(19),                 &
           hirs1b_d%ele(32)%rCount(20),                 &
           hirs1b_d%ele(32)%flagElem,                   &
           hirs1b_d%ele(32)%zeroFill,                   &
           hirs1b_d%ele(33)%headElem,                   &
           hirs1b_d%ele(33)%rCount(1),                  &
           hirs1b_d%ele(33)%rCount(2),                  &
           hirs1b_d%ele(33)%rCount(3),                  &
           hirs1b_d%ele(33)%rCount(4),                  &
           hirs1b_d%ele(33)%rCount(5),                  &
           hirs1b_d%ele(33)%rCount(6),                  &
           hirs1b_d%ele(33)%rCount(7),                  &
           hirs1b_d%ele(33)%rCount(8),                  &
           hirs1b_d%ele(33)%rCount(9),                  &
           hirs1b_d%ele(33)%rCount(10),                 &
           hirs1b_d%ele(33)%rCount(11),                 &
           hirs1b_d%ele(33)%rCount(12),                 &
           hirs1b_d%ele(33)%rCount(13),                 &
           hirs1b_d%ele(33)%rCount(14),                 &
           hirs1b_d%ele(33)%rCount(15),                 &
           hirs1b_d%ele(33)%rCount(16),                 &
           hirs1b_d%ele(33)%rCount(17),                 &
           hirs1b_d%ele(33)%rCount(18),                 &
           hirs1b_d%ele(33)%rCount(19),                 &
           hirs1b_d%ele(33)%rCount(20),                 &
           hirs1b_d%ele(33)%flagElem,                   &
           hirs1b_d%ele(33)%zeroFill,                   &
           hirs1b_d%ele(34)%headElem,                   &
           hirs1b_d%ele(34)%rCount(1),                  &
           hirs1b_d%ele(34)%rCount(2),                  &
           hirs1b_d%ele(34)%rCount(3),                  &
           hirs1b_d%ele(34)%rCount(4),                  &
           hirs1b_d%ele(34)%rCount(5),                  &
           hirs1b_d%ele(34)%rCount(6),                  &
           hirs1b_d%ele(34)%rCount(7),                  &
           hirs1b_d%ele(34)%rCount(8),                  &
           hirs1b_d%ele(34)%rCount(9),                  &
           hirs1b_d%ele(34)%rCount(10),                 &
           hirs1b_d%ele(34)%rCount(11),                 &
           hirs1b_d%ele(34)%rCount(12),                 &
           hirs1b_d%ele(34)%rCount(13),                 &
           hirs1b_d%ele(34)%rCount(14),                 &
           hirs1b_d%ele(34)%rCount(15),                 &
           hirs1b_d%ele(34)%rCount(16),                 &
           hirs1b_d%ele(34)%rCount(17),                 &
           hirs1b_d%ele(34)%rCount(18),                 &
           hirs1b_d%ele(34)%rCount(19),                 &
           hirs1b_d%ele(34)%rCount(20),                 &
           hirs1b_d%ele(34)%flagElem,                   &
           hirs1b_d%ele(34)%zeroFill,                   &
           hirs1b_d%ele(35)%headElem,                   &
           hirs1b_d%ele(35)%rCount(1),                  &
           hirs1b_d%ele(35)%rCount(2),                  &
           hirs1b_d%ele(35)%rCount(3),                  &
           hirs1b_d%ele(35)%rCount(4),                  &
           hirs1b_d%ele(35)%rCount(5),                  &
           hirs1b_d%ele(35)%rCount(6),                  &
           hirs1b_d%ele(35)%rCount(7),                  &
           hirs1b_d%ele(35)%rCount(8),                  &
           hirs1b_d%ele(35)%rCount(9),                  &
           hirs1b_d%ele(35)%rCount(10),                 &
           hirs1b_d%ele(35)%rCount(11),                 &
           hirs1b_d%ele(35)%rCount(12),                 &
           hirs1b_d%ele(35)%rCount(13),                 &
           hirs1b_d%ele(35)%rCount(14),                 &
           hirs1b_d%ele(35)%rCount(15),                 &
           hirs1b_d%ele(35)%rCount(16),                 &
           hirs1b_d%ele(35)%rCount(17),                 &
           hirs1b_d%ele(35)%rCount(18),                 &
           hirs1b_d%ele(35)%rCount(19),                 &
           hirs1b_d%ele(35)%rCount(20),                 &
           hirs1b_d%ele(35)%flagElem,                   &
           hirs1b_d%ele(35)%zeroFill,                   &
           hirs1b_d%ele(36)%headElem,                   &
           hirs1b_d%ele(36)%rCount(1),                  &
           hirs1b_d%ele(36)%rCount(2),                  &
           hirs1b_d%ele(36)%rCount(3),                  &
           hirs1b_d%ele(36)%rCount(4),                  &
           hirs1b_d%ele(36)%rCount(5),                  &
           hirs1b_d%ele(36)%rCount(6),                  &
           hirs1b_d%ele(36)%rCount(7),                  &
           hirs1b_d%ele(36)%rCount(8),                  &
           hirs1b_d%ele(36)%rCount(9),                  &
           hirs1b_d%ele(36)%rCount(10),                 &
           hirs1b_d%ele(36)%rCount(11),                 &
           hirs1b_d%ele(36)%rCount(12),                 &
           hirs1b_d%ele(36)%rCount(13),                 &
           hirs1b_d%ele(36)%rCount(14),                 &
           hirs1b_d%ele(36)%rCount(15),                 &
           hirs1b_d%ele(36)%rCount(16),                 &
           hirs1b_d%ele(36)%rCount(17),                 &
           hirs1b_d%ele(36)%rCount(18),                 &
           hirs1b_d%ele(36)%rCount(19),                 &
           hirs1b_d%ele(36)%rCount(20),                 &
           hirs1b_d%ele(36)%flagElem,                   &
           hirs1b_d%ele(36)%zeroFill,                   &
           hirs1b_d%ele(37)%headElem,                   &
           hirs1b_d%ele(37)%rCount(1),                  &
           hirs1b_d%ele(37)%rCount(2),                  &
           hirs1b_d%ele(37)%rCount(3),                  &
           hirs1b_d%ele(37)%rCount(4),                  &
           hirs1b_d%ele(37)%rCount(5),                  &
           hirs1b_d%ele(37)%rCount(6),                  &
           hirs1b_d%ele(37)%rCount(7),                  &
           hirs1b_d%ele(37)%rCount(8),                  &
           hirs1b_d%ele(37)%rCount(9),                  &
           hirs1b_d%ele(37)%rCount(10),                 &
           hirs1b_d%ele(37)%rCount(11),                 &
           hirs1b_d%ele(37)%rCount(12),                 &
           hirs1b_d%ele(37)%rCount(13),                 &
           hirs1b_d%ele(37)%rCount(14),                 &
           hirs1b_d%ele(37)%rCount(15),                 &
           hirs1b_d%ele(37)%rCount(16),                 &
           hirs1b_d%ele(37)%rCount(17),                 &
           hirs1b_d%ele(37)%rCount(18),                 &
           hirs1b_d%ele(37)%rCount(19),                 &
           hirs1b_d%ele(37)%rCount(20),                 &
           hirs1b_d%ele(37)%flagElem,                   &
           hirs1b_d%ele(37)%zeroFill,                   &
           hirs1b_d%ele(38)%headElem,                   &
           hirs1b_d%ele(38)%rCount(1),                  &
           hirs1b_d%ele(38)%rCount(2),                  &
           hirs1b_d%ele(38)%rCount(3),                  &
           hirs1b_d%ele(38)%rCount(4),                  &
           hirs1b_d%ele(38)%rCount(5),                  &
           hirs1b_d%ele(38)%rCount(6),                  &
           hirs1b_d%ele(38)%rCount(7),                  &
           hirs1b_d%ele(38)%rCount(8),                  &
           hirs1b_d%ele(38)%rCount(9),                  &
           hirs1b_d%ele(38)%rCount(10),                 &
           hirs1b_d%ele(38)%rCount(11),                 &
           hirs1b_d%ele(38)%rCount(12),                 &
           hirs1b_d%ele(38)%rCount(13),                 &
           hirs1b_d%ele(38)%rCount(14),                 &
           hirs1b_d%ele(38)%rCount(15),                 &
           hirs1b_d%ele(38)%rCount(16),                 &
           hirs1b_d%ele(38)%rCount(17),                 &
           hirs1b_d%ele(38)%rCount(18),                 &
           hirs1b_d%ele(38)%rCount(19),                 &
           hirs1b_d%ele(38)%rCount(20),                 &
           hirs1b_d%ele(38)%flagElem,                   &
           hirs1b_d%ele(38)%zeroFill,                   &
           hirs1b_d%ele(39)%headElem,                   &
           hirs1b_d%ele(39)%rCount(1),                  &
           hirs1b_d%ele(39)%rCount(2),                  &
           hirs1b_d%ele(39)%rCount(3),                  &
           hirs1b_d%ele(39)%rCount(4),                  &
           hirs1b_d%ele(39)%rCount(5),                  &
           hirs1b_d%ele(39)%rCount(6),                  &
           hirs1b_d%ele(39)%rCount(7),                  &
           hirs1b_d%ele(39)%rCount(8),                  &
           hirs1b_d%ele(39)%rCount(9),                  &
           hirs1b_d%ele(39)%rCount(10),                 &
           hirs1b_d%ele(39)%rCount(11),                 &
           hirs1b_d%ele(39)%rCount(12),                 &
           hirs1b_d%ele(39)%rCount(13),                 &
           hirs1b_d%ele(39)%rCount(14),                 &
           hirs1b_d%ele(39)%rCount(15),                 &
           hirs1b_d%ele(39)%rCount(16),                 &
           hirs1b_d%ele(39)%rCount(17),                 &
           hirs1b_d%ele(39)%rCount(18),                 &
           hirs1b_d%ele(39)%rCount(19),                 &
           hirs1b_d%ele(39)%rCount(20),                 &
           hirs1b_d%ele(39)%flagElem,                   &
           hirs1b_d%ele(39)%zeroFill,                   &
           hirs1b_d%ele(40)%headElem,                   &
           hirs1b_d%ele(40)%rCount(1),                  &
           hirs1b_d%ele(40)%rCount(2),                  &
           hirs1b_d%ele(40)%rCount(3),                  &
           hirs1b_d%ele(40)%rCount(4),                  &
           hirs1b_d%ele(40)%rCount(5),                  &
           hirs1b_d%ele(40)%rCount(6),                  &
           hirs1b_d%ele(40)%rCount(7),                  &
           hirs1b_d%ele(40)%rCount(8),                  &
           hirs1b_d%ele(40)%rCount(9),                  &
           hirs1b_d%ele(40)%rCount(10),                 &
           hirs1b_d%ele(40)%rCount(11),                 &
           hirs1b_d%ele(40)%rCount(12),                 &
           hirs1b_d%ele(40)%rCount(13),                 &
           hirs1b_d%ele(40)%rCount(14),                 &
           hirs1b_d%ele(40)%rCount(15),                 &
           hirs1b_d%ele(40)%rCount(16),                 &
           hirs1b_d%ele(40)%rCount(17),                 &
           hirs1b_d%ele(40)%rCount(18),                 &
           hirs1b_d%ele(40)%rCount(19),                 &
           hirs1b_d%ele(40)%rCount(20),                 &
           hirs1b_d%ele(40)%flagElem,                   &
           hirs1b_d%ele(40)%zeroFill,                   &
           hirs1b_d%ele(41)%headElem,                   &
           hirs1b_d%ele(41)%rCount(1),                  &
           hirs1b_d%ele(41)%rCount(2),                  &
           hirs1b_d%ele(41)%rCount(3),                  &
           hirs1b_d%ele(41)%rCount(4),                  &
           hirs1b_d%ele(41)%rCount(5),                  &
           hirs1b_d%ele(41)%rCount(6),                  &
           hirs1b_d%ele(41)%rCount(7),                  &
           hirs1b_d%ele(41)%rCount(8),                  &
           hirs1b_d%ele(41)%rCount(9),                  &
           hirs1b_d%ele(41)%rCount(10),                 &
           hirs1b_d%ele(41)%rCount(11),                 &
           hirs1b_d%ele(41)%rCount(12),                 &
           hirs1b_d%ele(41)%rCount(13),                 &
           hirs1b_d%ele(41)%rCount(14),                 &
           hirs1b_d%ele(41)%rCount(15),                 &
           hirs1b_d%ele(41)%rCount(16),                 &
           hirs1b_d%ele(41)%rCount(17),                 &
           hirs1b_d%ele(41)%rCount(18),                 &
           hirs1b_d%ele(41)%rCount(19),                 &
           hirs1b_d%ele(41)%rCount(20),                 &
           hirs1b_d%ele(41)%flagElem,                   &
           hirs1b_d%ele(41)%zeroFill,                   &
           hirs1b_d%ele(42)%headElem,                   &
           hirs1b_d%ele(42)%rCount(1),                  &
           hirs1b_d%ele(42)%rCount(2),                  &
           hirs1b_d%ele(42)%rCount(3),                  &
           hirs1b_d%ele(42)%rCount(4),                  &
           hirs1b_d%ele(42)%rCount(5),                  &
           hirs1b_d%ele(42)%rCount(6),                  &
           hirs1b_d%ele(42)%rCount(7),                  &
           hirs1b_d%ele(42)%rCount(8),                  &
           hirs1b_d%ele(42)%rCount(9),                  &
           hirs1b_d%ele(42)%rCount(10),                 &
           hirs1b_d%ele(42)%rCount(11),                 &
           hirs1b_d%ele(42)%rCount(12),                 &
           hirs1b_d%ele(42)%rCount(13),                 &
           hirs1b_d%ele(42)%rCount(14),                 &
           hirs1b_d%ele(42)%rCount(15),                 &
           hirs1b_d%ele(42)%rCount(16),                 &
           hirs1b_d%ele(42)%rCount(17),                 &
           hirs1b_d%ele(42)%rCount(18),                 &
           hirs1b_d%ele(42)%rCount(19),                 &
           hirs1b_d%ele(42)%rCount(20),                 &
           hirs1b_d%ele(42)%flagElem,                   &
           hirs1b_d%ele(42)%zeroFill,                   &
           hirs1b_d%ele(43)%headElem,                   &
           hirs1b_d%ele(43)%rCount(1),                  &
           hirs1b_d%ele(43)%rCount(2),                  &
           hirs1b_d%ele(43)%rCount(3),                  &
           hirs1b_d%ele(43)%rCount(4),                  &
           hirs1b_d%ele(43)%rCount(5),                  &
           hirs1b_d%ele(43)%rCount(6),                  &
           hirs1b_d%ele(43)%rCount(7),                  &
           hirs1b_d%ele(43)%rCount(8),                  &
           hirs1b_d%ele(43)%rCount(9),                  &
           hirs1b_d%ele(43)%rCount(10),                 &
           hirs1b_d%ele(43)%rCount(11),                 &
           hirs1b_d%ele(43)%rCount(12),                 &
           hirs1b_d%ele(43)%rCount(13),                 &
           hirs1b_d%ele(43)%rCount(14),                 &
           hirs1b_d%ele(43)%rCount(15),                 &
           hirs1b_d%ele(43)%rCount(16),                 &
           hirs1b_d%ele(43)%rCount(17),                 &
           hirs1b_d%ele(43)%rCount(18),                 &
           hirs1b_d%ele(43)%rCount(19),                 &
           hirs1b_d%ele(43)%rCount(20),                 &
           hirs1b_d%ele(43)%flagElem,                   &
           hirs1b_d%ele(43)%zeroFill,                   &
           hirs1b_d%ele(44)%headElem,                   &
           hirs1b_d%ele(44)%rCount(1),                  &
           hirs1b_d%ele(44)%rCount(2),                  &
           hirs1b_d%ele(44)%rCount(3),                  &
           hirs1b_d%ele(44)%rCount(4),                  &
           hirs1b_d%ele(44)%rCount(5),                  &
           hirs1b_d%ele(44)%rCount(6),                  &
           hirs1b_d%ele(44)%rCount(7),                  &
           hirs1b_d%ele(44)%rCount(8),                  &
           hirs1b_d%ele(44)%rCount(9),                  &
           hirs1b_d%ele(44)%rCount(10),                 &
           hirs1b_d%ele(44)%rCount(11),                 &
           hirs1b_d%ele(44)%rCount(12),                 &
           hirs1b_d%ele(44)%rCount(13),                 &
           hirs1b_d%ele(44)%rCount(14),                 &
           hirs1b_d%ele(44)%rCount(15),                 &
           hirs1b_d%ele(44)%rCount(16),                 &
           hirs1b_d%ele(44)%rCount(17),                 &
           hirs1b_d%ele(44)%rCount(18),                 &
           hirs1b_d%ele(44)%rCount(19),                 &
           hirs1b_d%ele(44)%rCount(20),                 &
           hirs1b_d%ele(44)%flagElem,                   &
           hirs1b_d%ele(44)%zeroFill,                   &
           hirs1b_d%ele(45)%headElem,                   &
           hirs1b_d%ele(45)%rCount(1),                  &
           hirs1b_d%ele(45)%rCount(2),                  &
           hirs1b_d%ele(45)%rCount(3),                  &
           hirs1b_d%ele(45)%rCount(4),                  &
           hirs1b_d%ele(45)%rCount(5),                  &
           hirs1b_d%ele(45)%rCount(6),                  &
           hirs1b_d%ele(45)%rCount(7),                  &
           hirs1b_d%ele(45)%rCount(8),                  &
           hirs1b_d%ele(45)%rCount(9),                  &
           hirs1b_d%ele(45)%rCount(10),                 &
           hirs1b_d%ele(45)%rCount(11),                 &
           hirs1b_d%ele(45)%rCount(12),                 &
           hirs1b_d%ele(45)%rCount(13),                 &
           hirs1b_d%ele(45)%rCount(14),                 &
           hirs1b_d%ele(45)%rCount(15),                 &
           hirs1b_d%ele(45)%rCount(16),                 &
           hirs1b_d%ele(45)%rCount(17),                 &
           hirs1b_d%ele(45)%rCount(18),                 &
           hirs1b_d%ele(45)%rCount(19),                 &
           hirs1b_d%ele(45)%rCount(20),                 &
           hirs1b_d%ele(45)%flagElem,                   &
           hirs1b_d%ele(45)%zeroFill,                   &
           hirs1b_d%ele(46)%headElem,                   &
           hirs1b_d%ele(46)%rCount(1),                  &
           hirs1b_d%ele(46)%rCount(2),                  &
           hirs1b_d%ele(46)%rCount(3),                  &
           hirs1b_d%ele(46)%rCount(4),                  &
           hirs1b_d%ele(46)%rCount(5),                  &
           hirs1b_d%ele(46)%rCount(6),                  &
           hirs1b_d%ele(46)%rCount(7),                  &
           hirs1b_d%ele(46)%rCount(8),                  &
           hirs1b_d%ele(46)%rCount(9),                  &
           hirs1b_d%ele(46)%rCount(10),                 &
           hirs1b_d%ele(46)%rCount(11),                 &
           hirs1b_d%ele(46)%rCount(12),                 &
           hirs1b_d%ele(46)%rCount(13),                 &
           hirs1b_d%ele(46)%rCount(14),                 &
           hirs1b_d%ele(46)%rCount(15),                 &
           hirs1b_d%ele(46)%rCount(16),                 &
           hirs1b_d%ele(46)%rCount(17),                 &
           hirs1b_d%ele(46)%rCount(18),                 &
           hirs1b_d%ele(46)%rCount(19),                 &
           hirs1b_d%ele(46)%rCount(20),                 &
           hirs1b_d%ele(46)%flagElem,                   &
           hirs1b_d%ele(46)%zeroFill,                   &
           hirs1b_d%ele(47)%headElem,                   &
           hirs1b_d%ele(47)%rCount(1),                  &
           hirs1b_d%ele(47)%rCount(2),                  &
           hirs1b_d%ele(47)%rCount(3),                  &
           hirs1b_d%ele(47)%rCount(4),                  &
           hirs1b_d%ele(47)%rCount(5),                  &
           hirs1b_d%ele(47)%rCount(6),                  &
           hirs1b_d%ele(47)%rCount(7),                  &
           hirs1b_d%ele(47)%rCount(8),                  &
           hirs1b_d%ele(47)%rCount(9),                  &
           hirs1b_d%ele(47)%rCount(10),                 &
           hirs1b_d%ele(47)%rCount(11),                 &
           hirs1b_d%ele(47)%rCount(12),                 &
           hirs1b_d%ele(47)%rCount(13),                 &
           hirs1b_d%ele(47)%rCount(14),                 &
           hirs1b_d%ele(47)%rCount(15),                 &
           hirs1b_d%ele(47)%rCount(16),                 &
           hirs1b_d%ele(47)%rCount(17),                 &
           hirs1b_d%ele(47)%rCount(18),                 &
           hirs1b_d%ele(47)%rCount(19),                 &
           hirs1b_d%ele(47)%rCount(20),                 &
           hirs1b_d%ele(47)%flagElem,                   &
           hirs1b_d%ele(47)%zeroFill,                   &
           hirs1b_d%ele(48)%headElem,                   &
           hirs1b_d%ele(48)%rCount(1),                  &
           hirs1b_d%ele(48)%rCount(2),                  &
           hirs1b_d%ele(48)%rCount(3),                  &
           hirs1b_d%ele(48)%rCount(4),                  &
           hirs1b_d%ele(48)%rCount(5),                  &
           hirs1b_d%ele(48)%rCount(6),                  &
           hirs1b_d%ele(48)%rCount(7),                  &
           hirs1b_d%ele(48)%rCount(8),                  &
           hirs1b_d%ele(48)%rCount(9),                  &
           hirs1b_d%ele(48)%rCount(10),                 &
           hirs1b_d%ele(48)%rCount(11),                 &
           hirs1b_d%ele(48)%rCount(12),                 &
           hirs1b_d%ele(48)%rCount(13),                 &
           hirs1b_d%ele(48)%rCount(14),                 &
           hirs1b_d%ele(48)%rCount(15),                 &
           hirs1b_d%ele(48)%rCount(16),                 &
           hirs1b_d%ele(48)%rCount(17),                 &
           hirs1b_d%ele(48)%rCount(18),                 &
           hirs1b_d%ele(48)%rCount(19),                 &
           hirs1b_d%ele(48)%rCount(20),                 &
           hirs1b_d%ele(48)%flagElem,                   &
           hirs1b_d%ele(48)%zeroFill,                   &
           hirs1b_d%ele(49)%headElem,                   &
           hirs1b_d%ele(49)%rCount(1),                  &
           hirs1b_d%ele(49)%rCount(2),                  &
           hirs1b_d%ele(49)%rCount(3),                  &
           hirs1b_d%ele(49)%rCount(4),                  &
           hirs1b_d%ele(49)%rCount(5),                  &
           hirs1b_d%ele(49)%rCount(6),                  &
           hirs1b_d%ele(49)%rCount(7),                  &
           hirs1b_d%ele(49)%rCount(8),                  &
           hirs1b_d%ele(49)%rCount(9),                  &
           hirs1b_d%ele(49)%rCount(10),                 &
           hirs1b_d%ele(49)%rCount(11),                 &
           hirs1b_d%ele(49)%rCount(12),                 &
           hirs1b_d%ele(49)%rCount(13),                 &
           hirs1b_d%ele(49)%rCount(14),                 &
           hirs1b_d%ele(49)%rCount(15),                 &
           hirs1b_d%ele(49)%rCount(16),                 &
           hirs1b_d%ele(49)%rCount(17),                 &
           hirs1b_d%ele(49)%rCount(18),                 &
           hirs1b_d%ele(49)%rCount(19),                 &
           hirs1b_d%ele(49)%rCount(20),                 &
           hirs1b_d%ele(49)%flagElem,                   &
           hirs1b_d%ele(49)%zeroFill,                   &
           hirs1b_d%ele(50)%headElem,                   &
           hirs1b_d%ele(50)%rCount(1),                  &
           hirs1b_d%ele(50)%rCount(2),                  &
           hirs1b_d%ele(50)%rCount(3),                  &
           hirs1b_d%ele(50)%rCount(4),                  &
           hirs1b_d%ele(50)%rCount(5),                  &
           hirs1b_d%ele(50)%rCount(6),                  &
           hirs1b_d%ele(50)%rCount(7),                  &
           hirs1b_d%ele(50)%rCount(8),                  &
           hirs1b_d%ele(50)%rCount(9),                  &
           hirs1b_d%ele(50)%rCount(10),                 &
           hirs1b_d%ele(50)%rCount(11),                 &
           hirs1b_d%ele(50)%rCount(12),                 &
           hirs1b_d%ele(50)%rCount(13),                 &
           hirs1b_d%ele(50)%rCount(14),                 &
           hirs1b_d%ele(50)%rCount(15),                 &
           hirs1b_d%ele(50)%rCount(16),                 &
           hirs1b_d%ele(50)%rCount(17),                 &
           hirs1b_d%ele(50)%rCount(18),                 &
           hirs1b_d%ele(50)%rCount(19),                 &
           hirs1b_d%ele(50)%rCount(20),                 &
           hirs1b_d%ele(50)%flagElem,                   &
           hirs1b_d%ele(50)%zeroFill,                   &
           hirs1b_d%ele(51)%headElem,                   &
           hirs1b_d%ele(51)%rCount(1),                  &
           hirs1b_d%ele(51)%rCount(2),                  &
           hirs1b_d%ele(51)%rCount(3),                  &
           hirs1b_d%ele(51)%rCount(4),                  &
           hirs1b_d%ele(51)%rCount(5),                  &
           hirs1b_d%ele(51)%rCount(6),                  &
           hirs1b_d%ele(51)%rCount(7),                  &
           hirs1b_d%ele(51)%rCount(8),                  &
           hirs1b_d%ele(51)%rCount(9),                  &
           hirs1b_d%ele(51)%rCount(10),                 &
           hirs1b_d%ele(51)%rCount(11),                 &
           hirs1b_d%ele(51)%rCount(12),                 &
           hirs1b_d%ele(51)%rCount(13),                 &
           hirs1b_d%ele(51)%rCount(14),                 &
           hirs1b_d%ele(51)%rCount(15),                 &
           hirs1b_d%ele(51)%rCount(16),                 &
           hirs1b_d%ele(51)%rCount(17),                 &
           hirs1b_d%ele(51)%rCount(18),                 &
           hirs1b_d%ele(51)%rCount(19),                 &
           hirs1b_d%ele(51)%rCount(20),                 &
           hirs1b_d%ele(51)%flagElem,                   &
           hirs1b_d%ele(51)%zeroFill,                   &
           hirs1b_d%ele(52)%headElem,                   &
           hirs1b_d%ele(52)%rCount(1),                  &
           hirs1b_d%ele(52)%rCount(2),                  &
           hirs1b_d%ele(52)%rCount(3),                  &
           hirs1b_d%ele(52)%rCount(4),                  &
           hirs1b_d%ele(52)%rCount(5),                  &
           hirs1b_d%ele(52)%rCount(6),                  &
           hirs1b_d%ele(52)%rCount(7),                  &
           hirs1b_d%ele(52)%rCount(8),                  &
           hirs1b_d%ele(52)%rCount(9),                  &
           hirs1b_d%ele(52)%rCount(10),                 &
           hirs1b_d%ele(52)%rCount(11),                 &
           hirs1b_d%ele(52)%rCount(12),                 &
           hirs1b_d%ele(52)%rCount(13),                 &
           hirs1b_d%ele(52)%rCount(14),                 &
           hirs1b_d%ele(52)%rCount(15),                 &
           hirs1b_d%ele(52)%rCount(16),                 &
           hirs1b_d%ele(52)%rCount(17),                 &
           hirs1b_d%ele(52)%rCount(18),                 &
           hirs1b_d%ele(52)%rCount(19),                 &
           hirs1b_d%ele(52)%rCount(20),                 &
           hirs1b_d%ele(52)%flagElem,                   &
           hirs1b_d%ele(52)%zeroFill,                   &
           hirs1b_d%ele(53)%headElem,                   &
           hirs1b_d%ele(53)%rCount(1),                  &
           hirs1b_d%ele(53)%rCount(2),                  &
           hirs1b_d%ele(53)%rCount(3),                  &
           hirs1b_d%ele(53)%rCount(4),                  &
           hirs1b_d%ele(53)%rCount(5),                  &
           hirs1b_d%ele(53)%rCount(6),                  &
           hirs1b_d%ele(53)%rCount(7),                  &
           hirs1b_d%ele(53)%rCount(8),                  &
           hirs1b_d%ele(53)%rCount(9),                  &
           hirs1b_d%ele(53)%rCount(10),                 &
           hirs1b_d%ele(53)%rCount(11),                 &
           hirs1b_d%ele(53)%rCount(12),                 &
           hirs1b_d%ele(53)%rCount(13),                 &
           hirs1b_d%ele(53)%rCount(14),                 &
           hirs1b_d%ele(53)%rCount(15),                 &
           hirs1b_d%ele(53)%rCount(16),                 &
           hirs1b_d%ele(53)%rCount(17),                 &
           hirs1b_d%ele(53)%rCount(18),                 &
           hirs1b_d%ele(53)%rCount(19),                 &
           hirs1b_d%ele(53)%rCount(20),                 &
           hirs1b_d%ele(53)%flagElem,                   &
           hirs1b_d%ele(53)%zeroFill,                   &
           hirs1b_d%ele(54)%headElem,                   &
           hirs1b_d%ele(54)%rCount(1),                  &
           hirs1b_d%ele(54)%rCount(2),                  &
           hirs1b_d%ele(54)%rCount(3),                  &
           hirs1b_d%ele(54)%rCount(4),                  &
           hirs1b_d%ele(54)%rCount(5),                  &
           hirs1b_d%ele(54)%rCount(6),                  &
           hirs1b_d%ele(54)%rCount(7),                  &
           hirs1b_d%ele(54)%rCount(8),                  &
           hirs1b_d%ele(54)%rCount(9),                  &
           hirs1b_d%ele(54)%rCount(10),                 &
           hirs1b_d%ele(54)%rCount(11),                 &
           hirs1b_d%ele(54)%rCount(12),                 &
           hirs1b_d%ele(54)%rCount(13),                 &
           hirs1b_d%ele(54)%rCount(14),                 &
           hirs1b_d%ele(54)%rCount(15),                 &
           hirs1b_d%ele(54)%rCount(16),                 &
           hirs1b_d%ele(54)%rCount(17),                 &
           hirs1b_d%ele(54)%rCount(18),                 &
           hirs1b_d%ele(54)%rCount(19),                 &
           hirs1b_d%ele(54)%rCount(20),                 &
           hirs1b_d%ele(54)%flagElem,                   &
           hirs1b_d%ele(54)%zeroFill,                   &
           hirs1b_d%ele(55)%headElem,                   &
           hirs1b_d%ele(55)%rCount(1),                  &
           hirs1b_d%ele(55)%rCount(2),                  &
           hirs1b_d%ele(55)%rCount(3),                  &
           hirs1b_d%ele(55)%rCount(4),                  &
           hirs1b_d%ele(55)%rCount(5),                  &
           hirs1b_d%ele(55)%rCount(6),                  &
           hirs1b_d%ele(55)%rCount(7),                  &
           hirs1b_d%ele(55)%rCount(8),                  &
           hirs1b_d%ele(55)%rCount(9),                  &
           hirs1b_d%ele(55)%rCount(10),                 &
           hirs1b_d%ele(55)%rCount(11),                 &
           hirs1b_d%ele(55)%rCount(12),                 &
           hirs1b_d%ele(55)%rCount(13),                 &
           hirs1b_d%ele(55)%rCount(14),                 &
           hirs1b_d%ele(55)%rCount(15),                 &
           hirs1b_d%ele(55)%rCount(16),                 &
           hirs1b_d%ele(55)%rCount(17),                 &
           hirs1b_d%ele(55)%rCount(18),                 &
           hirs1b_d%ele(55)%rCount(19),                 &
           hirs1b_d%ele(55)%rCount(20),                 &
           hirs1b_d%ele(55)%flagElem,                   &
           hirs1b_d%ele(55)%zeroFill,                   &
           hirs1b_d%ele(56)%headElem,                   &
           hirs1b_d%ele(56)%rCount(1),                  &
           hirs1b_d%ele(56)%rCount(2),                  &
           hirs1b_d%ele(56)%rCount(3),                  &
           hirs1b_d%ele(56)%rCount(4),                  &
           hirs1b_d%ele(56)%rCount(5),                  &
           hirs1b_d%ele(56)%rCount(6),                  &
           hirs1b_d%ele(56)%rCount(7),                  &
           hirs1b_d%ele(56)%rCount(8),                  &
           hirs1b_d%ele(56)%rCount(9),                  &
           hirs1b_d%ele(56)%rCount(10),                 &
           hirs1b_d%ele(56)%rCount(11),                 &
           hirs1b_d%ele(56)%rCount(12),                 &
           hirs1b_d%ele(56)%rCount(13),                 &
           hirs1b_d%ele(56)%rCount(14),                 &
           hirs1b_d%ele(56)%rCount(15),                 &
           hirs1b_d%ele(56)%rCount(16),                 &
           hirs1b_d%ele(56)%rCount(17),                 &
           hirs1b_d%ele(56)%rCount(18),                 &
           hirs1b_d%ele(56)%rCount(19),                 &
           hirs1b_d%ele(56)%rCount(20),                 &
           hirs1b_d%ele(56)%flagElem,                   &
           hirs1b_d%ele(56)%zeroFill,                   &
           hirs1b_d%ele(57)%headElem,                   &
           hirs1b_d%ele(57)%rCount(1),                  &
           hirs1b_d%ele(57)%rCount(2),                  &
           hirs1b_d%ele(57)%rCount(3),                  &
           hirs1b_d%ele(57)%rCount(4),                  &
           hirs1b_d%ele(57)%rCount(5),                  &
           hirs1b_d%ele(57)%rCount(6),                  &
           hirs1b_d%ele(57)%rCount(7),                  &
           hirs1b_d%ele(57)%rCount(8),                  &
           hirs1b_d%ele(57)%rCount(9),                  &
           hirs1b_d%ele(57)%rCount(10),                 &
           hirs1b_d%ele(57)%rCount(11),                 &
           hirs1b_d%ele(57)%rCount(12),                 &
           hirs1b_d%ele(57)%rCount(13),                 &
           hirs1b_d%ele(57)%rCount(14),                 &
           hirs1b_d%ele(57)%rCount(15),                 &
           hirs1b_d%ele(57)%rCount(16),                 &
           hirs1b_d%ele(57)%rCount(17),                 &
           hirs1b_d%ele(57)%rCount(18),                 &
           hirs1b_d%ele(57)%rCount(19),                 &
           hirs1b_d%ele(57)%rCount(20),                 &
           hirs1b_d%ele(57)%flagElem,                   &
           hirs1b_d%ele(57)%zeroFill,                   &
           hirs1b_d%ele(58)%headElem,                   &
           hirs1b_d%ele(58)%rCount(1),                  &
           hirs1b_d%ele(58)%rCount(2),                  &
           hirs1b_d%ele(58)%rCount(3),                  &
           hirs1b_d%ele(58)%rCount(4),                  &
           hirs1b_d%ele(58)%rCount(5),                  &
           hirs1b_d%ele(58)%rCount(6),                  &
           hirs1b_d%ele(58)%rCount(7),                  &
           hirs1b_d%ele(58)%rCount(8),                  &
           hirs1b_d%ele(58)%rCount(9),                  &
           hirs1b_d%ele(58)%rCount(10),                 &
           hirs1b_d%ele(58)%rCount(11),                 &
           hirs1b_d%ele(58)%rCount(12),                 &
           hirs1b_d%ele(58)%rCount(13),                 &
           hirs1b_d%ele(58)%rCount(14),                 &
           hirs1b_d%ele(58)%rCount(15),                 &
           hirs1b_d%ele(58)%rCount(16),                 &
           hirs1b_d%ele(58)%rCount(17),                 &
           hirs1b_d%ele(58)%rCount(18),                 &
           hirs1b_d%ele(58)%rCount(19),                 &
           hirs1b_d%ele(58)%rCount(20),                 &
           hirs1b_d%ele(58)%flagElem,                   &
           hirs1b_d%ele(58)%zeroFill,                   &
           hirs1b_d%head58,                             &
           hirs1b_d%wtts1(1),                           &
           hirs1b_d%wtts1(2),                           &
           hirs1b_d%wtts1(3),                           &
           hirs1b_d%wtts1(4),                           &
           hirs1b_d%wtts1(5),                           &
           hirs1b_d%wtts2(1),                           &
           hirs1b_d%wtts2(2),                           &
           hirs1b_d%wtts2(3),                           &
           hirs1b_d%wtts2(4),                           &
           hirs1b_d%wtts2(5),                           &
           hirs1b_d%wtts3(1),                           &
           hirs1b_d%wtts3(2),                           &
           hirs1b_d%wtts3(3),                           &
           hirs1b_d%wtts3(4),                           &
           hirs1b_d%wtts3(5),                           &
           hirs1b_d%wtts4(1),                           &
           hirs1b_d%wtts4(2),                           &
           hirs1b_d%wtts4(3),                           &
           hirs1b_d%wtts4(4),                           &
           hirs1b_d%wtts4(5),                           &
           hirs1b_d%flag58,                             &
           hirs1b_d%byte4287,                           &
           hirs1b_d%head59,                             &
           hirs1b_d%space1(1),                          &
           hirs1b_d%space1(2),                          &
           hirs1b_d%space1(3),                          &
           hirs1b_d%space1(4),                          &
           hirs1b_d%space1(5),                          &
           hirs1b_d%space2(1),                          &
           hirs1b_d%space2(2),                          &
           hirs1b_d%space2(3),                          &
           hirs1b_d%space2(4),                          &
           hirs1b_d%space2(5),                          &
           hirs1b_d%space3(1),                          &
           hirs1b_d%space3(2),                          &
           hirs1b_d%space3(3),                          &
           hirs1b_d%space3(4),                          &
           hirs1b_d%space3(5),                          &
           hirs1b_d%space4(1),                          &
           hirs1b_d%space4(2),                          &
           hirs1b_d%space4(3),                          &
           hirs1b_d%space4(4),                          &
           hirs1b_d%space4(5),                          &
           hirs1b_d%flag59,                             &
           hirs1b_d%byte4335,                           &
           hirs1b_d%ele60(1)%headElem,                  &
           hirs1b_d%ele60(1)%rCount(1),                 &
           hirs1b_d%ele60(1)%rCount(2),                 &
           hirs1b_d%ele60(1)%rCount(3),                 &
           hirs1b_d%ele60(1)%rCount(4),                 &
           hirs1b_d%ele60(1)%rCount(5),                 &
           hirs1b_d%ele60(1)%rCount(6),                 &
           hirs1b_d%ele60(1)%rCount(7),                 &
           hirs1b_d%ele60(1)%rCount(8),                 &
           hirs1b_d%ele60(1)%rCount(9),                 &
           hirs1b_d%ele60(1)%rCount(10),                &
           hirs1b_d%ele60(1)%rCount(11),                &
           hirs1b_d%ele60(1)%rCount(12),                &
           hirs1b_d%ele60(1)%rCount(13),                &
           hirs1b_d%ele60(1)%rCount(14),                &
           hirs1b_d%ele60(1)%rCount(15),                &
           hirs1b_d%ele60(1)%rCount(16),                &
           hirs1b_d%ele60(1)%rCount(17),                &
           hirs1b_d%ele60(1)%rCount(18),                &
           hirs1b_d%ele60(1)%rCount(19),                &
           hirs1b_d%ele60(1)%rCount(20),                &
           hirs1b_d%ele60(1)%flagElem,                  &
           hirs1b_d%ele60(1)%zeroFill,                  &
           hirs1b_d%ele60(2)%headElem,                  &
           hirs1b_d%ele60(2)%rCount(1),                 &
           hirs1b_d%ele60(2)%rCount(2),                 &
           hirs1b_d%ele60(2)%rCount(3),                 &
           hirs1b_d%ele60(2)%rCount(4),                 &
           hirs1b_d%ele60(2)%rCount(5),                 &
           hirs1b_d%ele60(2)%rCount(6),                 &
           hirs1b_d%ele60(2)%rCount(7),                 &
           hirs1b_d%ele60(2)%rCount(8),                 &
           hirs1b_d%ele60(2)%rCount(9),                 &
           hirs1b_d%ele60(2)%rCount(10),                &
           hirs1b_d%ele60(2)%rCount(11),                &
           hirs1b_d%ele60(2)%rCount(12),                &
           hirs1b_d%ele60(2)%rCount(13),                &
           hirs1b_d%ele60(2)%rCount(14),                &
           hirs1b_d%ele60(2)%rCount(15),                &
           hirs1b_d%ele60(2)%rCount(16),                &
           hirs1b_d%ele60(2)%rCount(17),                &
           hirs1b_d%ele60(2)%rCount(18),                &
           hirs1b_d%ele60(2)%rCount(19),                &
           hirs1b_d%ele60(2)%rCount(20),                &
           hirs1b_d%ele60(2)%flagElem,                  &
           hirs1b_d%ele60(2)%zeroFill,                  &
           hirs1b_d%head62,                             &
           hirs1b_d%instTemp(1),                        &
           hirs1b_d%instTemp(2),                        &
           hirs1b_d%instTemp(3),                        &
           hirs1b_d%instTemp(4),                        &
           hirs1b_d%instTemp(5),                        &
           hirs1b_d%instTemp(6),                        &
           hirs1b_d%instTemp(7),                        &
           hirs1b_d%instTemp(8),                        &
           hirs1b_d%byte4453(1),                        &
           hirs1b_d%byte4453(2),                        &
           hirs1b_d%byte4453(3),                        &
           hirs1b_d%byte4453(4),                        &
           hirs1b_d%byte4453(5),                        &
           hirs1b_d%byte4453(6),                        &
           hirs1b_d%byte4453(7),                        &
           hirs1b_d%byte4453(8),                        &
           hirs1b_d%byte4453(9),                        &
           hirs1b_d%byte4453(10),                       &
           hirs1b_d%byte4453(11),                       &
           hirs1b_d%byte4453(12),                       &
           hirs1b_d%byte4453(13),                       &
           hirs1b_d%byte4453(14),                       &
           hirs1b_d%head63,                             &
           hirs1b_d%lineCount,                          &
           hirs1b_d%byte4487(1),                        &
           hirs1b_d%byte4487(2),                        &
           hirs1b_d%byte4487(3),                        &
           hirs1b_d%byte4487(4),                        &
           hirs1b_d%byte4487(5),                        &
           hirs1b_d%byte4487(6),                        &
           hirs1b_d%byte4487(7),                        &
           hirs1b_d%byte4487(8),                        &
           hirs1b_d%byte4487(9),                        &
           hirs1b_d%byte4487(10),                       &
           hirs1b_d%byte4487(11),                       &
           hirs1b_d%byte4487(12),                       &
           hirs1b_d%byte4487(13),                       &
           hirs1b_d%byte4487(14),                       &
           hirs1b_d%byte4487(15),                       &
           hirs1b_d%byte4487(16),                       &
           hirs1b_d%byte4487(17),                       &
           hirs1b_d%byte4487(18),                       &
           hirs1b_d%byte4487(19),                       &
           hirs1b_d%byte4487(20),                       &
           hirs1b_d%byte4487(21),                       &
           hirs1b_d%byte4487(22),                       &
           hirs1b_d%byte4487(23),                       &
           hirs1b_d%byte4487(24),                       &
           hirs1b_d%byte4487(25),                       &
           hirs1b_d%byte4487(26),                       &
           hirs1b_d%byte4487(27),                       &
           hirs1b_d%byte4541(1),                        &
           hirs1b_d%byte4541(2),                        &
           hirs1b_d%byte4541(3),                        &
           hirs1b_d%byte4541(4),                        &
           hirs1b_d%byte4541(5),                        &
           hirs1b_d%byte4541(6),                        &
           hirs1b_d%byte4541(7),                        &
           hirs1b_d%byte4541(8),                        &
           hirs1b_d%byte4541(9),                        &
           hirs1b_d%byte4541(10),                       &
           hirs1b_d%byte4541(11),                       &
           hirs1b_d%byte4541(12),                       &
           hirs1b_d%byte4541(13),                       &
           hirs1b_d%byte4541(14),                       &
           hirs1b_d%byte4541(15),                       &
           hirs1b_d%byte4541(16),                       &
           hirs1b_d%byte4541(17),                       &
           hirs1b_d%byte4541(18),                       &
           hirs1b_d%byte4541(19),                       &
           hirs1b_d%byte4541(20),                       &
           hirs1b_d%byte4541(21),                       &
           hirs1b_d%byte4541(22),                       &
           hirs1b_d%byte4541(23),                       &
           hirs1b_d%byte4541(24),                       &
           hirs1b_d%byte4541(25),                       &
           hirs1b_d%byte4541(26),                       &
           hirs1b_d%byte4541(27),                       &
           hirs1b_d%byte4541(28),                       &
           hirs1b_d%byte4541(29),                       &
           hirs1b_d%byte4541(30),                       &
           hirs1b_d%byte4541(31),                       &
           hirs1b_d%byte4541(32),                       &
           hirs1b_d%byte4541(33),                       &
           hirs1b_d%byte4541(34),                       &
           hirs1b_d%byte4541(35),                       &
           hirs1b_d%byte4541(36),                       &
           hirs1b_d%byte4541(37),                       &
           hirs1b_d%byte4541(38),                       &
           hirs1b_d%byte4541(39),                       &
           hirs1b_d%byte4541(40),                       &
           hirs1b_d%byte4541(41),                       &
           hirs1b_d%byte4541(42),                       &
           hirs1b_d%byte4541(43),                       &
           hirs1b_d%byte4541(44),                       &
           hirs1b_d%byte4541(45),                       &
           hirs1b_d%byte4541(46),                       &
           hirs1b_d%byte4541(47),                       &
           hirs1b_d%byte4541(48),                       &
           hirs1b_d%byte4541(49),                       &
           hirs1b_d%byte4541(50),                       &
           hirs1b_d%byte4541(51),                       &
           hirs1b_d%byte4541(52),                       &
           hirs1b_d%byte4541(53),                       &
           hirs1b_d%byte4541(54),                       &
           hirs1b_d%byte4541(55),                       &
           hirs1b_d%byte4541(56),                       &
           hirs1b_d%byte4541(57),                       &
           hirs1b_d%byte4541(58),                       &
           hirs1b_d%byte4541(59),                       &
           hirs1b_d%byte4541(60),                       &
           hirs1b_d%byte4541(61),                       &
           hirs1b_d%byte4541(62),                       &
           hirs1b_d%byte4541(63),                       &
           hirs1b_d%byte4541(64),                       &
           hirs1b_d%byte4541(65),                       &
           hirs1b_d%byte4541(66),                       &
           hirs1b_d%byte4541(67),                       &
           hirs1b_d%byte4541(68)                        

      goto 400

  300 nerror = 300    

  400 return
      end
