!========================================================================================
!@***h* Daily OLR CDR/get_hirs_HIRS4.f90
! 
! NAME         
!   get_hirs_HIRS4.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx, xx=18, 19, 20
!
! PURPOSE
!   Performs HIRS radiance calibration
!
! DESCRIPTION
!   This F90 subroutine reads in HIRS Level-1b data, performs HIRS radiance calibration
!	using McMillin method (NOAA POES Users Guide, 1998).
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!  type_def.f90
!	superdata.cmn.f90
!	instrument.cmn.f90
!	hirs_cali.f90
!
! INPUTS
!   onehir - one superswath of HIRS level 1b data passed in through common block
!
! OUTPUTS
!   hirsdat(35,56,40) - containing calibrated radiance and geolocation, lza, & timing info
!
! HISTORY
!   2003-01-01   Original Code (atovmain.f) obtained from L. McMillin
!   2003-08-26   Hai-Tien Lee for NOAA-KLM
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

! 8/26/03 Hai-Tien Lee
! modified to use with level 1b data from NOAA-KLM

      subroutine  get_hirs

!C    
!C
!C*******************************************************************
!C    this sub calculate the hirs BT for 
!C    one superswath of data , this version is
!c    for NOAA16                       020522 
!     called by OLR_retrieval.f90
!     call:  chirs16cali.f90 cao's algorithm
! or  call:   hirs16cali.f90  our algorithm
!
! modified to output radiance for a s.s   04/17/02
!C******************************************************************* 

!***************************************************************
!   key local parameters-
!      variable             type       function
!      --------             ----       --------
!     band,bandc            real        Temperature correction coeff
!                                        the attached is NOAA12's
!       iord                int*2       The order of channels in 
!                                        1b data
!        mfq                byte        Quality info of spot data
!       onehir              struc_1b    One sacnline of 1b data
!     mclcf,nrmcf           int*2       Original calibration info 
!                                        saved in 1b data
!     clcfh,rmcfh           real*4      Calibration coeff from
!                                        mclcf,nrmcf
!      nflags               int*4       Scan quality flag
!     pslope, pintcpt       real*4      New calibration coeff
!                                        for a superswath
!                  
!c***************************************************************
!c*
      USE type_def
      implicit none
      include 'superdata.cmn.f90'
      include 'instrument.cmn.f90'

      Type(struc_1b) onehir
      
      integer i,j,k
      integer*2 c,cc
      character imfq 
      integer*4 jyr,jday,jhr,jmn,jsec,msec,nflags 
      integer*4 mclcf(3,20),nrmcf(3,20)
      real*4 clcfh(3,20),rmcfh(3,20)   
      real*4  pslope(42,19),pintcpt(42,19)
      real*4 radiance(19,40,56),oradiance(19,40,56)
      real*4  pslp,picpt,r,or,temp,brightn
      integer is,m

      real*4 scale(3)
      data scale/1.0e-12 , 1.0e-9, 1.0e-6/
      

!C first get the calibration *********************************

      call hirs_cali(pslope,pintcpt)

!C init the output array of hirs data
      do k=1,40
       do j=1,56
        do i=1,35
        hirsdat(i,j,k)=-9999.9
        enddo
        hirsdat(1,j,k)=-1.0   !flags
        hirsdat(33,j,k)=1.0   !Cali flags
       enddo
      enddo

      do 120 is=1,40        !40 scanlines 

        onehir = suphirs(is)

!C first check the scan quality
      if(btest(onehir%qualField,31)) goto 120

!C pull the original calibration info out of the dataset
!C If little endian platform, do switching bytes
 
!C      print *, 'cali info from data:'
      do  j=1,20
!c...   find the corresponding radiometric channel number
        k=iord(j)
        do  i=1,3
           clcfh(i,j) = onehir%PrimCali(i,k)*scale(i)
        enddo
!C      print*,(rmcfh(im,j),im=1,3)
      enddo

!C Add here printout calibration info

!C      do k=1,19
!C        write(555,*) pslope(is,k),clcfh(2,k),pintcpt(is,k),clcfh(3,k)
!C      enddo


!C Since we only need ch20's info, ignore the correction of 
!C calibration for chan 1&2
!C 

! =====================================================
!c...  loop thru 56 spots in hirs line
!     for each spot check for mirror sequence error,
!     then loop through 20 channels and extract data.
!     convert the data to radiances and then to temps.
! =====================================================
      do 110 i=1,56
!c...  check mirror sequence error flag
      imfq=onehir%frameQual(i)

!N20      if (btest(ichar(imfq),2)) go to 90

!c...   loop thru 20 channels for each spot
      do 80 k=1,19
!c...   find corresponding radiometric channel number
        m=iord(k)
        c=onehir%ele(i)%rCount(m)
!c...  check for missing data
        if (c >32760 .or. c< -9990) go to 90
!deal with the sign bit, 1's compliment
        c = c - 4095
        if ( c .gt. 0 )  c = c - 1

        pslp=pslope(is,k)
        picpt=pintcpt(is,k)
     
!C      print *,'slope&intecept', is, k,pslp,picpt
      r=c*pslp+picpt
      or=c*clcfh(2,k)+clcfh(3,k)
      radiance(k,i,is) = r
      oradiance(k,i,is) = or

      if (is .eq. 1) then
      temp=r   ! save radiance instead of BT for space view 
      go to 80
      endif
!C      if (is .gt. 3) print *, 'is,k,r',is,k,r
      if (r .le. 0. ) then
! 20101216 Hai-Tien
! Most negative are occuring in Ch18 and 19. We will assign small radiance value to them so that
! measurements from other channels, especially 1-12, can still be used for OLR.
! If not conformtable, uncomment and go to 90 to skip this scan.
          r = 1.e-5
!         go to 90
      endif

      temp=brightn(r,k)

      temp =(temp-bandc(1,k))/bandc(2,k)
!C
!C      if (is .gt. 3) print *, 'BT form Hirs:',temp

!C  check the bt with limits
!?      if(temp.lt.tooloh(k).or.temp.gt.toohih(k)) go to 90

!C    assign temperature to the output array
!C 80   hirsdat(8+k,i,is)=temp
   80   hirsdat(8+k,i,is)=r


!C ADD channel 20's processing here, use original calibration data

!C calculate chan 20 albido
!? should use noaa16ch20.txt???
      m=iord(20)
      cc=onehir%ele(i)%rCount(m)
!c...  check for missing data
      if (cc >32760 .or. cc< -9990) go to 110  
                                !bad of ch20 will not affect other channel
      !deal with the sign bit, 1's compliment
               cc = cc - 4095
               if ( cc .gt. 0 )  cc = cc - 1
!c...  calculate radiance
!C      print *, 'chan20 cc',i,cc
!      c=rmcfh(1,20)+cc*(rmcfh(2,20)+cc*rmcfh(3,20))
      c= cc *1.0
      r=c*(clcfh(1,20)*c+clcfh(2,20))+clcfh(3,20)

!      print *, 'chan20 r',i,r,clcfh(1,20),clcfh(2,20),clcfh(3,20)
      if (r.lt.0.) r=0. 
      hirsdat(8+20,i,is)=r
!CCCCC ch20 added

!C  assign different flags according to view
      if( is .eq. 1) then
         hirsdat(1,i,is)=2.0
      else if( is .eq. 2) then
         hirsdat(1,i,is)=3.0
      else if( is .eq. 3) then
         hirsdat(1,i,is)=4.0
      else
         hirsdat(1,i,is)=1.0
      endif

      hirsdat(2,i,is)= onehir%location(1,i)*1.e-4   !lat
      hirsdat(3,i,is)= onehir%location(2,i)*1.e-4   !lon
      hirsdat(4,i,is)= onehir%scanYr                !yrar
      hirsdat(5,i,is)= onehir%scanDay               !day
      hirsdat(6,i,is)= onehir%scanTime              !utc time
      hirsdat(7,i,is)= onehir%height                !height
!C      hirsdat(8,i,is)=onehir%angles(1,i)*1.e-2   !solar zenith angle
      hirsdat(8,i,is)=onehir%angles(2,i)*1.e-2   !local zenith angle
      goto 110     

 90   do k=1,20   ! if a channel is bad, every channel bad, incluing previous
       hirsdat(8+k,i,is)=-9999.0
      enddo
 110  continue
 
 120  continue

!C      write(666)is,radiance,oradiance
!C may do some output here?

      end
