#!/bin/sh

##########################################################################################
#@***h* Daily OLR CDR/OLR_CDR_Production.sh
# 
# NAME
#     OLR_CDR_Production.sh
#
# PURPOSE
# 		HIRS OLR CDR Production Script to be executed daily 
#
# DESCRIPTION
# 		This is the main script that drives the Daily OLR CDR production.
#
# USAGE
#     OLR_CDR_Production.sh $yyyymmdd_target $cdrtype 
#	   Default yyyymmdd_target is yesterday
#	   Default cdrtype is 3
#
# Script structure
# 0. Set up environment (user configurable)
# 1. Determine the days to be processed 
# 2. Stage HIRS1b data
# 3. Perform OLR retrieval for HIRS and Imager
# 4. Perform Gridding for HIRS OLR 
# 5. Perform Temporal integral
# 6. Perform NetCDF packing
# 7. Archive
#
# AUTHOR
#   Hai-Tien Lee
# 
# COPYRIGHT	
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
#   SUPPORT TO USERS.
# 
# INPUT
#  	<work>/HIRS1b/nXX/yyyy  - HIRS OLR level1b data for POES n$XX year $yyyy, XX=05, 06, ...20.
# 
# OUTPUT
#  	<work>/CDR/OLR_CDR/olr-daily_v${version}r${rev}_${yyyy1}${mm1}_${yyyy2}${mm2}.nc - HIRS Daily OLR CDR Product file 
# 
# HISTORY
#  	2013-09-12  Hai-Tien Lee Modified from Monthly production script for Daily OLR production
#     2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
#
#@*****
#########################################################################################

# =====================================================================
# 0. Set up environment 
# =====================================================================

# User configurable ------------------------------------------------
# OLR CDR Product version numbers
version='01'
revision='02'

# Target day is specified by the 2nd argument in <yyyymmdd>
target_day=$1
# cdrtype=[1,2,3] 1:Final CDR, 2:Final CDR updated from Preliminary 3:Preliminary
cdrtype=$2

Production_home='/Volumes/Data7/Daily_OLR_v01r02'
HIRS1b=/Volumes/Data15/HIRS_1b
Production_work=${Production_home}/Work

# Satellites to be processed
# ; all possible since 1979.01 
satids='N05 N06 N07 N08 N09 N10 N11 N12 N14 N15 N16 N17 N18 N19 N20 N21'

# End of user configuration ----------------------------------------

# change into working directory
if test ! -r $Production_work
then
mkdir $Production_work
fi
cd $Production_work

# set up working directories
workdirs='OLR_fov Daily Daily_Interim OLR_CDR'
for workdir in $workdirs
do
if test ! -r $workdir
then
mkdir $workdir
fi
done

rm HIRS_OLR_CDR_home HIRS_OLR_CDR_work
ln -s $Production_home HIRS_OLR_CDR_home
ln -s $Production_work HIRS_OLR_CDR_work

src=$Production_home
work=$Production_work
cal_date2="$src/Utility/cal_date2.sh"
cal_julday2="$src/Utility/cal_julday2.sh"


# =====================================================================
# 1. Determine the day to be processed 
# =====================================================================
if test $# -eq 0
then
# find today
today=`$cal_date2`
yyyy_today=`echo $today | cut -c1-4`
mm_today=`echo $today | cut -c5-6`
dd_today=`echo $today | cut -c7-8`
yday_today=`$cal_julday2 $today`
echo "Today:    " $today $yyyy_today $mm_today $dd_today $yday_today
cal_date2="$src/Utility/cal_date2.sh"
cal_julday2="$src/Utility/cal_julday2.sh"
yesterday=`$cal_date2 -1`
yyyy_yesterday=`echo $yesterday | cut -c1-4`
mm_yesterday=`echo $yesterday | cut -c5-6`
dd_yesterday=`echo $yesterday | cut -c7-8`
yday_yesterday=`$cal_julday2 $yesterday`
echo Yesterday: $yesterday $yyyy_yesterday $mm_yesterday $dd_yesterday $yday_yesterday

# Find yyyy, mm, dd and yday for target day
yyyy_target=$yyyy_yesterday
mm_target=$mm_yesterday
dd_target=$dd_yesterday
yday_target=$yday_yesterday
echo target: $target $yyyy_target $mm_target $dd_target $yday_target

else
yyyy_target=`echo $target_day | cut -c1-4`
mm_target=`echo $target_day   | cut -c5-6`
dd_target=`echo $target_day   | cut -c7-8`
yday_target=`$cal_julday2 $target_day`
yyyymmdd_target=${yyyy_target}${mm_target}${dd_target}

echo '*** Specified target: '$target $yyyy_target

fi

# Set default cdrtype to 3 (assumed for ICDR production)
if test $# -ne 2
then
cdrtype=3
fi

# Only processing one year at a time
echo '*** Processing year' ${yyyy_target}
echo '*** Processing startes on' `date`

# =====================================================================
# 2. Stage HIRS1b data. 
# =====================================================================
# HIRS1b data should be stored in $data_1b/N<xx>/<yyyy> directories
# N<xx> = N05, N06, ..., N19, N20
# $yyyy = 1979, 1980, ..., 2010

# Define symbolic link data_1b to data directory
rm data_1b
ln -s $HIRS1b data_1b

# Add script here to ingest or link CLASS HIRS1b archive 

# =====================================================================
# 3. Perform OLR retrieval for each satellite
# =====================================================================

# 3a. Perform HIRS OLR retrieval for each satellite
# Loop through each satellite, output is in directory "OLR_fov"
for satid in $satids
do
# OLR_retrieval
echo $src/Scripts/OLR_retrieval.sh $satid ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}
$src/Scripts/OLR_retrieval.sh $satid ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}
done

# 3b. Perform Imager OLR retrieval using Gridsat data (for Full CDR production)
# script not available yet
# OLR_retrieval
# echo $src/Scripts/OLR_retrieval_Gridsat.sh $satid ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}
# $src/Scripts/OLR_retrieval_Gridsat.sh $satid ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}

# 3c. Perform Imager OLR extraction from GSIP product (for Interim CDR production)
# script not available yet
# echo $src/Scripts/OLR_retrieval_GSIP.sh ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}
# $src/Scripts/OLR_retrieval_GSIP.sh ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}

# =====================================================================
# 4a. Perform Gridding for Orbital Nodal Maps
# =====================================================================
# Loop through each satellite, output is in directory "Nodal"
for satid in $satids
do
# Grid daily OLR fov retreivals into 'nodal' mean maps (2 maps per day)
echo $src/Scripts/OLR_gridder_v2a.sh $satid ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}
$src/Scripts/OLR_gridder_v2a.sh $satid ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}
done

# =====================================================================
# 4b. Perform Gridding for hourly Maps
# =====================================================================
# Loop through each satellite, output is in directory "Hourly"
for satid in $satids
do
# Grid daily OLR fov retreivals into 'hourly' mean maps (24 maps per day)
echo $src/Scripts/OLR_gridder_v2b.sh $satid ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}
$src/Scripts/OLR_gridder_v2b.sh $satid ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}
done

# =====================================================================
# 5. Perform Temporal integral
# =====================================================================
echo $src/Scripts/OLR_daily_integral.sh ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}
$src/Scripts/OLR_Daily_integral.sh ${yyyy_target} ${mm_target} ${dd_target} ${yday_target}

# =====================================================================
# 6. Perform NetCDF packing
# =====================================================================
yyyy=${yyyy_target}

# invoke packing script to pack annual data
echo $src/Scripts/OLR_packer_batch.sh ${yyyy}0101 ${yyyy}1231 $version $revision $cdrtype
# Set the ending date for the Period of Record (POR)
case $cdrtype in
1 ) EndofPOR=${yyyy}1231 ;;
2 ) EndofPOR=${yyyy}1231 ;;
3 ) EndofPOR=${yyyymmdd_target} ;;
esac

$src/Scripts/OLR_packer_batch.sh ${yyyy}0101 $EndofPOR $version $revision $cdrtype


case $cdrtype in
1 | 2 ) Product_name="olr-daily_v${version}r${revision}_${yyyy}0101_${EndofPOR}.nc" ;;
3 ) Product_name="olr-daily_v${version}r${revision}-preliminary_${yyyy}0101_${EndofPOR}.nc" ;;
esac

mv $Product_name $work/OLR_CDR/
mv $Product_name.inventory.out $work/OLR_CDR/


# =====================================================================
# 7. Archive
# =====================================================================
# Add script here to copy OLR CDR Product to NCDC archive

# Define NCDC archive
NCDC_OLR_CDR_archive='direcotory1'
NCDC_OLR_fov_archive='direcotory2'

# Archive OLR CDR Time series NetCDF data file
# echo cp $Product_name $NCDC_OLR_CDR_archive
# cp $Product_name $NCDC_OLR_CDR_archive

# Archive OLR fov retrievals
# echo cp -r $work/OLR_fov/*/${yyyy_target}/${mm_target} $NCDC_OLR_fov_archive
# cp -r $work/OLR_fov/*/${yyyy_target}/${mm_target} $NCDC_OLR_fov_archive

# Done
echo End of OLR CDR Production for ${yyyy}0101_${EndofPOR}
echo `date`

exit
