#!/bin/sh

#########################################################################################
#@***h* Daily OLR CDR/OLR_packer_batch.sh
# 
# NAME
#     OLR_packer_batch.sh
#
# USAGE 
# 	   OLR_packer_batch.sh $yyyymmdd1 $yyyymmdd2 $version $revision $cdrtype
#
# PURPOSE
# 		NetCDF-4 Packer script
#  	Pack Final or Preliminary Daily OLR CDR data into a NetCDF4 data file.
#
# DESCRIPTION
# 		This script performs netCDF file packing for CDR product file for either of
#     the following three CDR types: 1. Final CDR, 2. Final CDR updated from 
#     Preliminary CDR, and 3. Preliminary CDR.
#
# AUTHOR
#   Hai-Tien Lee
# 
# COPYRIGHT	
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
#   SUPPORT TO USERS.
# 
# INPUT
#		$yyyymmdd1=beginning day of the OLR CDR time series (e.g. 19790101 for Jan 1, 1979)
#		$yyyymmdd2=ending day of the OLR CDR time series (e.g. 20121231 for Dec 31, 2012)
#		$version=OLR CDR Product Version number
#		$revision=OLR CDR Product Revision number
#  	<work>/Daily/$yyyy/OLR_daily_${yyyy}d${ddd}.dat - Daily OLR CDR data in binary format
#     $cdrtype=[1,2,3] 1:Final CDR, 2:Final CDR updated from Preliminary 3:Preliminary
# 
# OUTPUT
#  	<work>/OLR_CDR/olr-daily_v${version}r${revision}_${yyyymmdd1}_${yyyymmdd2}.nc - Daily OLR CDR Product file
# 
# HISTORY
#     2013-12-18  Hai-Tien Lee Created for Daily OLR CDR
#     2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
#
#@*****
#########################################################################################



# Configurable input ===================================================

# Period from $yyyy1 $yday1 to $yyyy2 $yday2
# $yyyymmdd1='19790101'
# $yyyymmdd2='20121231'
# version='00'
# revision='00'
yyyymmdd1=$1
yyyymmdd2=$2
version=$3
revision=$4
cdrtype=$5

# Specify Software ID and Append 'preliminary' to revision tag for ICDR production
SoftwarePackageID=Ver${version}Rev${revision}
if test $cdrtype -eq 3
then
revision=${revision}-preliminary
fi

# Modify the Global attribute variables if necessary


echo NetCDF Packing for OLR CDR ${yyyymmdd1}-${yyyymmdd2} Ver.$version Rev.$revision 

# Define directory paths and local variables
src='HIRS_OLR_CDR_home'
work='HIRS_OLR_CDR_work'
Packer="$work/Packer"
OLR_CDR="$work/OLR_CDR"

# Create output directory to hold OLR CDR product
if test ! -d $OLR_CDR
then
mkdir -p $OLR_CDR
fi

Product_name="olr-daily_v${version}r${revision}_${yyyymmdd1}_${yyyymmdd2}.nc"

# Define utility
cal_date2="$src/Utility/cal_date2.sh"
cal_yday2date="$src/Utility/cal_yday2date.sh"
cal_julday2="$src/Utility/cal_julday2.sh"
# scan_files="$src/Utility/parse_list_v3.exe"
scan_files="$src/Utility/scan_files.pl"

# Extract the year mon day
yyyy1=`echo $yyyymmdd1 | cut -c1-4`
mm1=`echo $yyyymmdd1 | cut -c5-6`
dd1=`echo $yyyymmdd1 | cut -c7-8`
yyyy2=`echo $yyyymmdd2 | cut -c1-4`
mm2=`echo $yyyymmdd2 | cut -c5-6`
dd2=`echo $yyyymmdd2 | cut -c7-8`
yyyy=$yyyy1

# Using Unix date command to convert date to epoch and then find number of days 
epoch1=`date -j -f "%Y%m%d" $yyyymmdd1 +%s`
epoch2=`date -j -f "%Y%m%d" $yyyymmdd2 +%s`
depoch=`expr $epoch2 - $epoch1`
time_len=`echo $depoch | awk '{print int($1/86400.+0.5) + 1}'`
echo TIME_LEN = $time_len

nday=${time_len}
echo '*** Number of days =' $nday

# Define time stamps
stamp_now=`date +%Y-%m-%dT%H:%M:%SZ`
stamp_begin=${yyyy1}-${mm1}-${dd1}T00:00:00.00Z
stamp_end=${yyyy2}-${mm2}-${dd2}T23:59:59.99Z


# Table GA1 CF Metadata Convention
g_conventions='CF-1.6'
g_title="Daily OLR CDR Product Ver${version}Rev${revision}"

case $cdrtype in
1 | 2 ) g_source="NOAA Archive of HIRS L1B data from TIROS-N Series and MetOp-A/B, Gridsat CDR" ;;
3 ) g_source="NOAA Archive of HIRS L1B data from TIROS-N Series and MetOp-A/B, GSIP Product" ;;
esac

g_reference='doi:10.1175/2007JTECHA989.1  doi:10.1175/1520-0426(1989)006<0706:ATFEOL>2.0.CO;2  doi:10.1175/1520-0426(1994)011<0357:VOATFE>2.0.CO;2'

g_history="${stamp_now} - generated by software package ${SoftwarePackageID}."

case $cdrtype in
1 ) g_comment="Final TCDR" ;;
2 ) g_comment="Final TCDR updated from ICDR" ;;
3 ) g_comment="ICDR" ;;
esac

# Table GA2 UNIDATA ACDD
g_Metadata_Conventions="Unidata Dataset Discovery v1.0, CF-1.6"
g_standard_name_vocabulary="CF Standard Name Table (v26, 26 November 2013)"
g_id=${Product_name}
g_naming_authority="gov.noaa.ncdc"
g_date_created=${stamp_now}
g_date_modified=${stamp_now}
g_license="Users must cite this dataset when used as a source. No other constraints on data access or use."
# g_date_issued="None"

case $cdrtype in
1 | 2 ) g_summary="The product contains the 1-degree by 1-degree daily mean outgoing longwave radiation flux at the top of the atmosphere derived from HIRS radiance observations onboard NOAA TIROS-N series and MetOp satellites. The OLR retrieval uses multispectral regression models (Ellingson et al., 1989, Lee, 2014). The CDR processing includes HIRS radiance calibration, inter-satellite HIRS OLR calibration, normalization of geostationary-based  OLR retrieval to HIRS, and grid-based 7-day boxcar temporal integration assisted with Imager-based OLR derived from Gridsat CDR data (Lee, 2014)." ;;
3 ) g_summary="This preliminary product contains the 1-degree by 1-degree daily mean outgoing longwave radiation flux at the top of the atmosphere derived from HIRS radiance observations onboard NOAA TIROS-N series and MetOp satellites. The OLR retrieval uses multispectral regression models (Ellingson et al., 1989, Lee, 2014). The CDR processing includes HIRS radiance calibration, inter-satellite HIRS OLR calibration, normalization of geostationary-based  OLR retrieval to HIRS, and grid-based 7-day boxcar temporal integration assisted with Imager-based OLR provided by GSIP product (Lee, 2014)." ;;
esac

g_keywords="Earth Science > Atmosphere >  Atmospheric Radiation > Outgoing Longwave Radiation"
g_keywords_vocabulary="NASA Global Change Master Directory (GCMD) Earth Science Keywords, Version 8.0.0.0"
g_cdm_data_type="Grid"
g_project="NOAA Daily OLR TCDR"
g_processing_level="NOAA Level 3"
g_creator_name="Hai-Tien Lee"
g_creator_URL="http://cicsmd.umd.edu/"
g_creator_email="lee@umd.edu"
g_institution="UMD/ESSIC > Earth System Science Interdisciplinary Center, University of Maryland"
g_geospatial_lat_min="-90.0"
g_geospatial_lat_max="90.0"
g_geospatial_lon_min="0.0"
g_geospatial_lon_max="360.0"
g_geospatial_lat_units="degree"
g_geospatial_lat_resolution="1.0"
g_geospatial_lon_units="degree"
g_geospatial_lon_resolution="1.0"
g_time_coverage_start="${stamp_begin}"
g_time_coverage_end="${stamp_end}"
g_time_coverage_duration="P${time_len}D"
g_time_coverage_resolution="P1D"
g_contributor_name="Hai-Tien Lee"
g_contributor_role="principalinvestigator"
g_acknowledgment="This project was supported in part by a grant from the NOAA Climate Data Record (CDR) Program for Satellites"


# Table GA3 CDR Attributes
g_cdr_program="NOAA Climate Data Record Program for satellites"
g_cdr_variable="olr"
g_software_version_id="${SoftwarePackageID}"
# example g_software_version_id="gov.noaa.ncdc:/svn-repos/rsad/CDR/HIRS-outgoing-LW-radiation/tags/${SoftwarePackageID}";

# Table GA4 GDS Attributes
g_metadata_link="gov.noaa.ncdc:C00875"
# Future with DOI:
# g_metadata_link="http://doi.org/10.7289/ToBeDetermined"

g_product_version="Ver${version}Rev${revision}"
g_platform="TIROS-N > Television Infrared Observation Satellite - N, NOAA-6 > National Oceanic Atmospheric Administration - 6, NOAA-7 > National Oceanic Atmospheric Administration - 7, NOAA-8 > National Oceanic Atmospheric Administration - 8, NOAA-9 > National Oceanic Atmospheric Administration - 9, NOAA-10 > National Oceanic Atmospheric Administration - 10, NOAA-11 > National Oceanic Atmospheric Administration - 11, NOAA-12 > National Oceanic Atmospheric Administration - 12, NOAA-14 > National Oceanic Atmospheric Administration - 14, NOAA-15 > National Oceanic Atmospheric Administration - 15, NOAA-16 > National Oceanic Atmospheric Administration - 16, NOAA-17 > National Oceanic Atmospheric Administration - 17, NOAA-18 > National Oceanic Atmospheric Administration - 18, NOAA-19 > National Oceanic Atmospheric Administration - 19, MetOp-A > Meteorological Operational Polar Satellite - A, MetOp-B > Meteorological Operational Polar Satellite - B"
g_sensor="HIRS-2 > High Resolution Infra-red Sounder/2, HIRS-2I > High Resolution Infra-red Sounder/2I, HIRS-3 > High Resolution Infra-red Sounder/3, HIRS-4 > High Resolution Infra-red Sounder/4"
g_spatial_resolution="1.0 by 1.0 degree equal angle"

# Note: Variable attributes are given in the Fortran program.

# Concatenate OLR ascii data file from archive
if test -r OLR_CDR_ascii_input.dat
then
rm OLR_CDR_ascii_input.dat
touch OLR_CDR_ascii_input.dat
fi

# Prepare OLR file list "OLR_CDR_ascii_input.dat" for netCDF packing
# $scan_files $yyyy > OLR_CDR_ascii_input.dat
case $cdrtype in
1 | 2 ) dailydir='Daily' ;;
3 ) dailydir='Daily_Interim' ;;
esac

perl $scan_files $yyyy $dailydir > OLR_CDR_ascii_input.dat
# Compile
# make -f Makefile.batch

# Execute
# For NCDC environment:
# $src/Codes/Packer/OLR_CDR_nc4_batch.exe -Wl,-T << EOF
# For CICS-MD environment:
$src/Codes/Packer/OLR_CDR_nc4_batch.exe << EOF
$time_len
$g_conventions
$g_title
$g_source
$g_reference
$g_history
$g_comment
$g_Metadata_Conventions
$g_standard_name_vocabulary
$g_id
$g_naming_authority
$g_date_created
$g_date_modified
$g_license
$g_summary
$g_keywords
$g_keywords_vocabulary
$g_cdm_data_type
$g_project
$g_processing_level
$g_creator_name
$g_creator_URL
$g_creator_email
$g_institution
$g_geospatial_lat_min
$g_geospatial_lat_max
$g_geospatial_lon_min
$g_geospatial_lon_max
$g_geospatial_lat_units
$g_geospatial_lat_resolution
$g_geospatial_lon_units
$g_geospatial_lon_resolution
$g_time_coverage_start
$g_time_coverage_end
$g_time_coverage_duration
$g_time_coverage_resolution
$g_contributor_name
$g_contributor_role
$g_acknowledgment
$g_cdr_program
$g_cdr_variable
$g_software_version_id
$g_metadata_link
$g_product_version
$g_platform
$g_sensor
$g_spatial_resolution
EOF

# Move product file
echo Product filename=$Product_name
mv OLR_CDR_output.nc $Product_name

ncdump -c $Product_name > $Product_name.inventory.out

exit

