#!/bin/sh

#########################################################################################
#@***h* Daily OLR CDR/OLR_retrieval_GSIP.sh
# 
# NAME:
#     OLR_retrieval_GSIP.sh
#
# USAGE 
# 	   OLR_retrieval_GSIP.sh <yyyy> <mm> <dd> <yday>
#     where <yyyy> is 4-digit year, <yday> is 3-digit days of the year 
#
# PURPOSE
#  	Extract Imager OLR from GSIP product
#
# DESCRIPTION
# 		This script extract and grid Imager OLR into 1x1 3hrly map
#
#
# AUTHOR
#   Hai-Tien Lee
# 
# COPYRIGHT	
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
#   SUPPORT TO USERS.
# 
# INPUT
#  	<work>/Gridsat/<satid>/<yyyy>/  - Gridsat CDR
# 
# OUTPUT
#  	<work>/OLR_Gridsat/<yyyy>/<mm> - 1x1 3hrly Imager OLR 
# 
# HISTORY
#     2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
#
#
#@*****
#########################################################################################



### THIS IS A  SCRIPT TEMPLATE ###





# Define variables
satid=$1
yyyy=$2
mm=$3
dd0=$4
yday_target=$5

echo Performing OLR retrieval for $satid $yyyy $mm $dd0 $yday_target

# Define directory paths and local variables
src='HIRS_OLR_CDR_home'
work='HIRS_OLR_CDR_work'
data_1b="$work/data_1b"
data_static="$src/Data_static"
OLR_fov="$work/OLR_fov"
data1b_list="$work/data1b_list.dat"
yy=`echo ${yyyy} | cut -c3-4`

target_day=$yyyy$mm$dd0

cal_date2="$src/Utility/cal_date2.sh"
cal_julday2="$src/Utility/cal_julday2.sh"
target_previous_day=`$cal_date2 $target_day -1`
yyyy1=`echo $target_previous_day | cut -c1-4`
yy1=`echo ${yyyy1} | cut -c3-4`
mm1=`echo $target_previous_day | cut -c5-6`
dd1=`echo $target_previous_day | cut -c7-8`
yday1=`$cal_julday2 $target_previous_day`
echo target_previous_day: $target_previous_day $yyyy1 $mm1 $dd1 $yday1

olr_coef_file="$src/Data_static/OLR_coef/coef_${satid}_305_a19.asc"
	 
# Copy anscillary data
rm band.txt pred_cali.txt prt.txt 
cp ${data_static}/cali_data/${satid}/${satid}_band.dat band.txt
cp ${data_static}/cali_data/${satid}/pred_cali_oper.dat pred_cali.txt
cp ${data_static}/cali_data/${satid}/${satid}_prt.dat prt.txt

# Create output directory to hold OLR retrievals
if test ! -d ${OLR_fov}/${satid}/${yyyy}
then
mkdir -p ${OLR_fov}/${satid}/${yyyy}
fi

# Define OLR_retrieval program
# Default
OLR_retrieval_prog=OLR_retrieval.exe

# For HIRS2 post 1995
if test $satid == "N11" && test $yyyy -ge 1995
then
OLR_retrieval_prog='OLR_retrieval_1995.exe'
fi
if test $satid == "N12"  &&  test $yyyy -ge 1995
then
OLR_retrieval_prog='OLR_retrieval_1995.exe'
fi
if test $satid == "N14"  &&  test $yyyy -ge 1995
then
OLR_retrieval_prog='OLR_retrieval_1995.exe'
fi

############################################################ 
yday=${yday_target}

# Search available Level-1b data. File list is collected in ${data1b_list} for processing
rm ${data1b_list}

# list files in previous day, only get the last one, e.g.,
# NSS.HIRX.M2.D12002.S2341.E0038.B2701112.SV
# NSS.HIRX.NN.D12003.S2354.E0135.B3412526.GC
touch ${data1b_list}
ls ${data_1b}/${satid}/${yyyy1}/NSS*D${yy1}${yday1}.S2???.E0???.* ${data_1b}/${satid}/${yyyy1}/nss*d${yy1}${yday1}.S2???.E0???.*  >> ${data1b_list}
ls ${data_1b}/${satid}/${yyyy}/NSS*D${yy}${yday}* ${data_1b}/${satid}/${yyyy}/nss*d${yy}${yday}*  >> ${data1b_list}

# Fix data1b_list for 1995 format change issue, don't include previous day (since the decoder is different)
# So for these satellites, 19950101 will miss those that are embedded in 19941231 with different format.
if test $satid == "N11" && test $yyyy -ge 1995 && test $yday -eq 1
then
rm ${data1b_list}
ls ${data_1b}/${satid}/${yyyy}/NSS*D${yy}${yday}* ${data_1b}/${satid}/${yyyy}/nss*d${yy}${yday}*  > ${data1b_list}
fi
if test $satid == "N12"  &&  test $yyyy -ge 1995 && test $yday -eq 1
then
rm ${data1b_list}
ls ${data_1b}/${satid}/${yyyy}/NSS*D${yy}${yday}* ${data_1b}/${satid}/${yyyy}/nss*d${yy}${yday}*  > ${data1b_list}
fi
if test $satid == "N14"  &&  test $yyyy -ge 1995 && test $yday -eq 1
then
rm ${data1b_list}
ls ${data_1b}/${satid}/${yyyy}/NSS*D${yy}${yday}* ${data_1b}/${satid}/${yyyy}/nss*d${yy}${yday}*  > ${data1b_list}
fi

cat ${data1b_list}

nameout=${OLR_fov}/${satid}/${yyyy}/${satid}.d${yy}${yday}.out

# Determine number of data_1b files
nfile=`wc -l ${data1b_list} | awk '{print $1}'`

# Invoke OLR_retrieval program to retrieval OLR for all the given Level1b data
if test $nfile -gt 0
then
satid_num=`echo $satid | cut -c2-3`
echo Retrieving $satid_num $data1b_list $olr_coef $olr_coef_file $nameout $nfile

# 2011-3-30 Hai-Tien
# Define variations of OLR_retrieval programs for N11, N12 and N14
# to handle Level1b format change in 1995

# 2013-09-12 Hai-Tien
# Add $yday_target to pass into retrieval program

ls -l $src/Codes/OLR_retrieval/$satid/${OLR_retrieval_prog}
$src/Codes/OLR_retrieval/$satid/${OLR_retrieval_prog} << EOF
${satid_num}
${data1b_list}
${olr_coef_file}
${nameout}
${yday_target}
EOF
# List output file status and size
ls -l $nameout
fi



exit

